@@ -47,6 +47,14 @@
 #define TAU_MULTSTORAGE(type, variable) type variable[TAU_MAX_THREADS][MAX_TAU_COUNTERS]
 #endif//TAU_MULTIPLE_COUNTERS
 
+#if defined(TAUKTAU) && defined(TAUKTAU_MERGE)
+#include <Profile/KtauFuncInfo.h>
+#endif /* TAUKTAU && TAUKTAU_MERGE */
+
+#ifdef RENCI_STFF
+#include "Profile/RenciSTFF.h"
+#endif //RENCI_STFF
+
 class TauUserEvent; 
 
 class FunctionInfo
@@ -77,7 +85,11 @@ public:
 
 	void FunctionInfoInit(TauGroup_t PGroup, const char *PGroupName, 
 	  bool InitData, int tid );
-        
+
+#if defined(TAUKTAU) && defined(TAUKTAU_MERGE)
+	KtauFuncInfo* GetKtauFuncInfo(int tid) { return &(KernelFunc[tid]); }
+#endif /* TAUKTAU && TAUKTAU_MERGE */
+
 #ifndef TAU_MULTIPLE_COUNTERS 
 	// Tell it about a function call finishing.
 	inline void ExcludeTime(double t, int tid);
@@ -118,8 +130,24 @@ public:
 	TauUserEvent * GetHeadroomEvent(void) { return HeadroomEvent; }
 #endif // TAU_PROFILEHEADROOM
 
-
-
+#ifdef RENCI_STFF
+#ifndef TAU_MULTIPLE_COUNTERS
+    // signatures for inclusive time for each thread
+    TAU_STORAGE(ApplicationSignature*, Signatures);
+    ApplicationSignature* GetSignature(int tid) {
+        return Signatures[tid];
+}
+    void SetSignature(ApplicationSignature *sig, int tid) {
+        Signatures[tid] = sig;
+}
+#else // TAU_MULTIPLE_COUNTERS
+    // signatures for inclusive time for each counter in each thread
+    TAU_MULTSTORAGE(ApplicationSignature*, Signatures);
+    ApplicationSignature** GetSignature(int tid) {
+        return Signatures[tid];
+}
+#endif // TAU_MULTIPLE_COUNTERS
+#endif //RENCI_STFF
 
 #ifdef PROFILE_CALLSTACK 
   	double InclTime_cs;
@@ -129,6 +157,11 @@ public:
 private:
 	// A record of the information unique to this function.
 	// Statistics about calling this function.
+	
+#if defined(TAUKTAU) && defined(TAUKTAU_MERGE)
+	TAU_STORAGE(KtauFuncInfo, KernelFunc);
+#endif /* KTAU && KTAU_MERGE */
+
 	TAU_STORAGE(long, NumCalls);
 	TAU_STORAGE(long, NumSubrs);
 #ifndef TAU_MULTIPLE_COUNTERS
@@ -149,6 +182,7 @@ public:
 	string GroupName;
 	string AllGroups;
 	long   FunctionId;
+
 	// Cough up the information about this function.
 	void SetName(string& str) { Name = str; }
 	const char* GetName() const { return Name.c_str(); }
@@ -172,7 +206,7 @@ public:
 	void SetCalls(int tid, long calls) { NumCalls[tid] = calls; }
 	long GetSubrs(int tid) { return NumSubrs[tid]; }
 	void SetSubrs(int tid, long subrs) { NumSubrs[tid] = subrs; }
-	void FunctionInfo::ResetExclTimeIfNegative(int tid);
+	void ResetExclTimeIfNegative(int tid);
 
 #ifndef TAU_MULTIPLE_COUNTERS
 	double GetExclTime(int tid) { return ExclTime[tid]; }
@@ -189,7 +223,7 @@ public:
 	}
 	void SetExclTimeZero(int tid) {
           for(int i=0;i<MAX_TAU_COUNTERS;i++)
-            InclTime[tid][i] = 0;
+            ExclTime[tid][i] = 0;
         }
 
 
@@ -211,7 +245,7 @@ public:
 #endif//TAU_MULTIPLE_COUNTERS
 
 	TauGroup_t GetProfileGroup(int tid = RtsLayer::myThread()) const {return MyProfileGroup_[tid]; }
-	void SetProfileGroup(TauGroup_t gr, int tid) {MyProfileGroup_[tid] = gr; }
+	void SetProfileGroup(TauGroup_t gr, int tid = RtsLayer::myThread()) {MyProfileGroup_[tid] = gr; }
 #ifdef PROFILE_STATS 
 	double GetSumExclSqr(int tid) { return SumExclSqr[tid]; }
 	void SetSumExclSqr(int tid, double s) { SumExclSqr[tid] = s; }
@@ -226,6 +260,7 @@ private:
 // Global variables
 TAU_STD_NAMESPACE vector<FunctionInfo*>& TheFunctionDB(void); 
 int& TheSafeToDumpData(void);
+int& TheUsingDyninst(void);
 
 //
 // For efficiency, make the timing updates inline.
@@ -280,7 +315,6 @@ FunctionInfo::IncrNumCalls(int tid)
 	NumCalls[tid] ++; // Increment number of calls
 } 
 
-
 inline void
 FunctionInfo::IncrNumSubrs(int tid)
 {
@@ -312,7 +346,7 @@ void tauCreateFI(FunctionInfo **ptr, const string& name, const string& type,
 
 #endif /* _FUNCTIONINFO_H_ */
 /***************************************************************************
- * $RCSfile: FunctionInfo.h,v $   $Author: sameer $
- * $Revision: 1.36 $   $Date: 2005/11/11 18:22:46 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.36 2005/11/11 18:22:46 sameer Exp $ 
+ * $RCSfile: FunctionInfo.h,v $   $Author: amorris $
+ * $Revision: 1.42 $   $Date: 2007/01/19 19:21:52 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.42 2007/01/19 19:21:52 amorris Exp $ 
  ***************************************************************************/
