@@ -66,15 +66,18 @@ int tau_pthread_create (pthread_t *threadp,
 #endif /* TAU_LIBRARY_SOURCE */
 
 
+/* This is to get TAU_START/TAU_STOP since some codes just #include <Profile/Profiler.h> */
+#include <TAU.h>
+
 #if (defined (__cplusplus ) && !defined (TAU_USE_C_API))
 
 #include <Profile/ProfileGroups.h>
 
 #ifdef TAU_MULTIPLE_COUNTERS
 #define MAX_TAU_COUNTERS 25
-#endif//TAU_MULTIPLE_COUNTERS
+#endif /* TAU_MULTIPLE_COUNTERS */
 
-#if (defined(PTHREADS) || defined(TULIPTHREADS) || defined(JAVA) || defined(TAU_WINDOWS) || defined (TAU_OPENMP) || defined (TAU_SPROC))
+#if (defined(PTHREADS) || defined(TULIPTHREADS) || defined(JAVA) || defined(TAU_WINDOWS) || defined (TAU_OPENMP) || defined (TAU_SPROC) || defined(TAU_PAPI_THREADS))
 
 
 #ifndef TAU_MAX_THREADS
@@ -111,6 +114,8 @@ int tau_pthread_create (pthread_t *threadp,
 
 #include <Profile/SprocLayer.h>
 
+#include <Profile/PapiThreadLayer.h>
+
 #include <Profile/RtsLayer.h>
 
 #include <Profile/FunctionInfo.h>
@@ -141,6 +146,7 @@ class KtauProfiler;
 #endif /* defined(TAUKTAU) */
 
 
+/*
 //////////////////////////////////////////////////////////////////////
 //
 // class Profiler
@@ -153,6 +159,8 @@ class KtauProfiler;
 // turns on the timer, and the destructor turns it off.
 //
 //////////////////////////////////////////////////////////////////////
+*/
+namespace tau {
 class Profiler
 {
 public:
@@ -162,25 +170,25 @@ public:
 	void Start(int tid = RtsLayer::myThread());
 	Profiler(const Profiler& X);
 	Profiler& operator= (const Profiler& X);
-	// Clean up data from this invocation.
+	/* Clean up data from this invocation. */
 	void Stop(int tid = RtsLayer::myThread(), bool useLastTimeStamp = false);
 	~Profiler();
 #ifdef TAU_CALLPATH
         void CallPathStart(int tid);
 #ifdef TAU_MULTIPLE_COUNTERS
         void CallPathStop(double* totaltime, int tid);
-#else  // TAU_MULTIPLE_COUNTERS 
+#else  /* TAU_MULTIPLE_COUNTERS  */
         void CallPathStop(double totaltime, int tid);
-#endif // TAU_MULTIPLE_COUNTERS 
-#endif // TAU_CALLPATH 
+#endif /* TAU_MULTIPLE_COUNTERS  */
+#endif /* TAU_CALLPATH  */
 
 #ifdef TAU_PROFILEPARAM
 #ifdef TAU_MULTIPLE_COUNTERS
         void ProfileParamStop(double* totaltime, int tid);
-#else  // TAU_MULTIPLE_COUNTERS 
+#else  /* TAU_MULTIPLE_COUNTERS  */
         void ProfileParamStop(double totaltime, int tid);
-#endif // TAU_MULTIPLE_COUNTERS 
-#endif // TAU_PROFILEPARAM 
+#endif /* TAU_MULTIPLE_COUNTERS */
+#endif /* TAU_PROFILEPARAM */
 
   	static void ProfileExit(const char *message=0, 
 	  int tid = RtsLayer::myThread());
@@ -196,7 +204,7 @@ public:
 	static void dumpFunctionNames();
 #ifndef TAU_MULTIPLE_COUNTERS
 	static void theCounterList(const char ***inPtr, int *numOfCounters);
-#endif //TAU_MULTIPLE_COUNTERS
+#endif /* TAU_MULTIPLE_COUNTERS */
 
 	static void getFunctionValues(const char **inFuncs,
 				      int numOfFuncs,
@@ -222,27 +230,27 @@ public:
 
 #if ( defined(PROFILE_CALLS) || defined(PROFILE_STATS) || defined(PROFILE_CALLSTACK) ) 
 	int ExcludeTimeThisCall(double t);
-	double ExclTimeThisCall; // for this invocation of the function
+	double ExclTimeThisCall; /* for this invocation of the function */
 #endif /* PROFILE_CALLS || PROFILE_STATS */
 
 	static Profiler * CurrentProfiler[TAU_MAX_THREADS];
 #ifndef TAU_MULTIPLE_COUNTERS
 	double StartTime;
-#else //TAU_MULTIPLE_COUNTERS
+#else /* TAU_MULTIPLE_COUNTERS */
 	double StartTime[MAX_TAU_COUNTERS];
 	double CurrentTime[MAX_TAU_COUNTERS];
 	double TotalTime[MAX_TAU_COUNTERS];
-#endif//TAU_MULTIPLE_COUNTERS
+#endif /* TAU_MULTIPLE_COUNTERS */
 	FunctionInfo * ThisFunction;
 #ifdef TAU_CALLPATH
 	FunctionInfo * CallPathFunction;
 	bool 	       AddInclCallPathFlag; 
-#endif // TAU_CALLPATH
+#endif /* TAU_CALLPATH */
 #ifdef TAU_PROFILEPARAM
 	FunctionInfo * ProfileParamFunction; 
 	bool 	       AddInclProfileParamFlag; 
 	static void AddProfileParamData(long key, string& keyname);
-#endif // TAU_PROFILEPARAM
+#endif /* TAU_PROFILEPARAM */
 #ifdef TAU_COMPENSATE
 	/* Compensate for instrumentation overhead based on total number of 
 	child calls executed under the given timer */
@@ -299,18 +307,23 @@ private:
 	bool 	RecordEvent; /* true when an MPI call is in the callpath */
 #endif /* TAU_MPITRACE */
 };
+};
+#ifdef TAU_LIBRARY_SOURCE
+using tau::Profiler;
+#endif /* TAU_LIBRARY_SOURCE */
+
 
 
 #endif /* PROFILING_ON || TRACING_ON */
 #include <Profile/TauMapping.h>
-// included after class Profiler is defined.
+/* included after class Profiler is defined. */
 #else /* __cplusplus && ! TAU_USE_C_API */
 #include <Profile/TauCAPI.h> /* For C program */
 #endif /* __cplusplus && ! TAU_USE_C_API */
 
 #endif /* PROFILER_H */
 /***************************************************************************
- * $RCSfile: Profiler.h,v $   $Author: amorris $
- * $Revision: 1.73 $   $Date: 2006/12/27 02:50:21 $
- * POOMA_VERSION_ID: $Id: Profiler.h,v 1.73 2006/12/27 02:50:21 amorris Exp $ 
+ * $RCSfile: Profiler.h,v $   $Author: sameer $
+ * $Revision: 1.77 $   $Date: 2007/04/25 01:07:04 $
+ * POOMA_VERSION_ID: $Id: Profiler.h,v 1.77 2007/04/25 01:07:04 sameer Exp $ 
  ***************************************************************************/
