@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1999  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -24,7 +24,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 /* TAU Mappings */
 #ifndef _TAU_MAPPING_H_
@@ -33,18 +33,44 @@
 #if (PROFILING_ON || TRACING_ON)
 // For Mapping, global variables used between layers
 FunctionInfo *& TheTauMapFI(TauGroup_t ProfileGroup=TAU_DEFAULT);
+
+
+#if (TAU_MAX_THREADS == 1)
+// If we're not multi-threaded, just use the non-thread-safe static initializer
+
 #define TAU_MAPPING(stmt, group)   \
   { \
     static FunctionInfo TauMapFI(#stmt, " " , group, #group); \
-    static Profiler *TauMapProf = new Profiler(&TauMapFI, group, true); \
+    static tau::Profiler *TauMapProf = new tau::Profiler(&TauMapFI, group, true); \
     TheTauMapFI(group) = &TauMapFI; \
     TauMapProf->Start(); \
     stmt; \
     TauMapProf->Stop(); \
+  }
+
+#else
+// Multithreaded, we should use thread-safe tauCreateFI to create the FunctionInfo object
+// Note: It's still not absolutely theoretically 100% thread-safe, since the static 
+// initializer is not in a lock, but we don't want to pay that price for every function call 
+
+#define TAU_MAPPING(stmt, group)   \
+  { \
+    static FunctionInfo *TauMapFI = NULL; \
+    tauCreateFI(&TauMapFI, #stmt, " " , group, #group); \
+    static tau::Profiler *TauMapProf = new tau::Profiler(TauMapFI, group, true); \
+    TheTauMapFI(group) = TauMapFI; \
+    TauMapProf->Start(); \
+    stmt; \
+    TauMapProf->Stop(); \
+    delete TauMapProf; \
   } 
 
-#define TAU_MAPPING_REGISTER(stmt, group)  { static FunctionInfo TauMapFI(stmt, " " , group, #group); \
-    TheTauMapFI(group) = &TauMapFI; \
+#endif
+
+#define TAU_MAPPING_REGISTER(stmt, group)  { \
+    static FunctionInfo *TauMapFI = NULL; \
+    tauCreateFI(&TauMapFI,stmt, " " , group, #group); \
+    TheTauMapFI(group) = TauMapFI; \
   } 
 
 #define TAU_MAPPING_CREATE(name, type, key, groupname, tid)  { FunctionInfo *TauMapFI = new FunctionInfo(name, type, key, groupname, true, tid); \
@@ -81,7 +107,7 @@ This error should be reported when FuncInfoVar is NULL
 	  //printf("ERROR: TAU_MAPPING_LINK map returns NULL FunctionInfo *\n"); \
 There's no error when FunctionInfo * is NULL. A region may not be active.
 */
-/* OLD --> did a return. Instead Profiler should check for Null. */
+/* OLD --> did a return. Instead tau::Profiler should check for Null. */
 /*
 #define TAU_MAPPING_LINK(FuncInfoVar, Group) FuncInfoVar = TheTauMapFI(Group); \
 	if (FuncInfoVar == (FunctionInfo *)NULL) { \
@@ -94,15 +120,15 @@ There's no error when FunctionInfo * is NULL. A region may not be active.
    and this behaves pretty much like TAU_PROFILE macro, except this gives in the
    FunctionInfo object pointer instead of name and type strings. 
 */
-#define TAU_MAPPING_PROFILE(FuncInfoVar) Profiler FuncInfoVar##Prof(FuncInfoVar, FuncInfoVar != (FunctionInfo *) 0 ? FuncInfoVar->GetProfileGroup() : TAU_DEFAULT, false);
+#define TAU_MAPPING_PROFILE(FuncInfoVar) tau::Profiler FuncInfoVar##Prof(FuncInfoVar, FuncInfoVar != (FunctionInfo *) 0 ? FuncInfoVar->GetProfileGroup() : TAU_DEFAULT, false);
 
 /* TAU_MAPPING_PROFILE_TIMER acts like TAU_PROFILE_TIMER by creating a profiler
    object that can be subsequently used with TAU_PROFILE_START and 
    TAU_PROFILE_STOP
 */
-#define TAU_MAPPING_PROFILE_TIMER(Timer, FuncInfoVar, tid) Profiler *Timer; \
-   Timer = new Profiler(FuncInfoVar,  FuncInfoVar != (FunctionInfo *) 0 ? FuncInfoVar->GetProfileGroup() : TAU_DEFAULT, true, tid); \
-   if (Timer == (Profiler *) NULL) {\
+#define TAU_MAPPING_PROFILE_TIMER(Timer, FuncInfoVar, tid) tau::Profiler *Timer; \
+   Timer = new tau::Profiler(FuncInfoVar,  FuncInfoVar != (FunctionInfo *) 0 ? FuncInfoVar->GetProfileGroup() : TAU_DEFAULT, true, tid); \
+   if (Timer == (tau::Profiler *) NULL) {\
      printf("ERROR: TAU_MAPPING_PROFILE_TIMER: new returns NULL Profiler *\n");\
    }
    
@@ -113,10 +139,10 @@ There's no error when FunctionInfo * is NULL. A region may not be active.
 
 /* TAU_MAPPING_PROFILE_STOP acts like TAU_PROFILE_STOP by stopping the timer 
 */
-#define TAU_MAPPING_PROFILE_STOP(tid) Profiler::CurrentProfiler[tid]->Stop(tid);
-#define TAU_MAPPING_PROFILE_EXIT(msg, tid)  Profiler::ProfileExit(msg, tid); 
-#define TAU_MAPPING_DB_DUMP(tid)  Profiler::DumpData(tid); 
-#define TAU_MAPPING_DB_PURGE(tid)  Profiler::PurgeData(tid); 
+#define TAU_MAPPING_PROFILE_STOP(tid) { tau::Profiler *cur = tau::Profiler::CurrentProfiler[tid]; cur->Stop(tid); delete cur; }
+#define TAU_MAPPING_PROFILE_EXIT(msg, tid)  tau::Profiler::ProfileExit(msg, tid); 
+#define TAU_MAPPING_DB_DUMP(tid)  tau::Profiler::DumpData(tid); 
+#define TAU_MAPPING_DB_PURGE(tid)  tau::Profiler::PurgeData(tid); 
 #define TAU_MAPPING_PROFILE_SET_NODE(node, tid)  RtsLayer::setMyNode(node, tid); 
 #define TAU_MAPPING_PROFILE_SET_GROUP_NAME(timer, name) timer->SetPrimaryGroupName(name);
 #define TAU_MAPPING_PROFILE_GET_GROUP_NAME(timer) timer->GetPrimaryGroup();
