@@ -1,6 +1,6 @@
 #****************************************************************************
 #*			TAU Portable Profiling Package			   **
-#*			http://www.acl.lanl.gov/tau		           **
+#*			http://www.cs.uoregon.edu/research/tau	           **
 #****************************************************************************
 #*    Copyright 1997-99						   	   **
 #*    Department of Computer and Information Science, University of Oregon **
