@@ -11,6 +11,16 @@
 //-----------------------------------------------------------------------------
 //
 // $Log: PyDatabase.cpp,v $
+// Revision 1.6  2007/03/02 02:36:51  amorris
+// Added snapshot API for python.
+//
+// Revision 1.5  2006/02/03 03:03:08  amorris
+// Fixed error with PyArg_ParseTuple:
+//
+// Exception exceptions.TypeError: 'function takes exactly 1 argument (0 given)' in 'garbage collection' ignored
+// Fatal Python error: unexpected exception during garbage collection
+// Aborted (core dumped)
+//
 // Revision 1.4  2003/07/18 18:48:19  sameer
 // Added support for TAU_DB_DUMP(prefix). In python you can optionally specify
 // an argument:
@@ -55,6 +65,26 @@
 #include "Profile/Profiler.h"
 
 
+char pytau_snapshot__name__[] = "snapshot";
+char pytau_snapshot__doc__[] = "take a snapshot of the current profile";
+PyObject * pytau_snapshot(PyObject *self, PyObject *args) { 
+
+  char *name = NULL;
+  int number = -1;
+
+    if (PyArg_ParseTuple(args, "s|i", &name, &number)) {
+      if (number == -1) {
+	TAU_PROFILE_SNAPSHOT(name);
+      } else {
+	TAU_PROFILE_SNAPSHOT_1L(name,number);
+      }
+    }
+
+    // return
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 char pytau_dbDump__name__[] = "dbDump";
 char pytau_dbDump__doc__[] = "dump the Tau Profiler statistics";
 PyObject * pytau_dbDump(PyObject *self, PyObject *args)
@@ -63,12 +93,7 @@ PyObject * pytau_dbDump(PyObject *self, PyObject *args)
     int len = 4;
 
     // Check to see if a prefix is specified
-    if (!PyArg_ParseTuple(args, "s#", &prefix, &len))
-    {
-      // No arguments are specified. Call Dump routine
-      TAU_DB_DUMP(); 
-    }
-    else 
+    if (PyArg_ParseTuple(args, "|s", &prefix, &len))
     {
       // extracted the prefix, call dump routine
 #ifdef DEBUG
@@ -77,7 +102,6 @@ PyObject * pytau_dbDump(PyObject *self, PyObject *args)
       TAU_DB_DUMP_PREFIX(prefix);
     }
 
-
     // return
     Py_INCREF(Py_None);
     return Py_None;
@@ -306,7 +330,7 @@ PyObject * pytau_dumpFuncValsIncr(PyObject *, PyObject * args)
 
 
 // version
-// $Id: PyDatabase.cpp,v 1.4 2003/07/18 18:48:19 sameer Exp $
+// $Id: PyDatabase.cpp,v 1.6 2007/03/02 02:36:51 amorris Exp $
 
 // End of file
   
