@@ -426,46 +426,39 @@ double getUserTimeInSec(void)
 #ifdef TAU_LINUX_TIMERS
 
 ///////////////////////////////////////////////////////////////////////////
-int TauReadFullLine(char ** line, FILE *fp)
-{
+int TauReadFullLine(char *line, FILE *fp) {
   int ch, i;
   i = 0; 
-  while ( (ch = fgetc(fp)) && ch != EOF && ch != (int) '\n')
-  {
-    line[0][i++] = (unsigned char) ch;
+  while ( (ch = fgetc(fp)) && ch != EOF && ch != (int) '\n') {
+    line[i++] = (unsigned char) ch;
+  }
+  line[i] = '\0'; 
+  if (ch == EOF) {
+    return -1;
   }
-  line[0][i] = '\0'; 
   return i; 
 }
 
 ///////////////////////////////////////////////////////////////////////////
-double TauGetMHzRatings(void)
-{
-  float ret;
-  char *line;
+double TauGetMHzRatings(void) {
+  float ret = 0;
+  char line[2048];
+  FILE *fp = fopen("/proc/cpuinfo", "r");
 
-  FILE *fp;
-  ret = 0;
-  line = new char[1024]; 
-  fp = fopen("/proc/cpuinfo", "r");
-
-  if (fp)
-  {
-    while(TauReadFullLine(&line, fp))
-    {
-      if (strncmp(line, "cpu MHz", 7) == 0)
-      {
+  if (fp) {
+    while (TauReadFullLine(line, fp) != -1) {
+      if (strncmp(line, "cpu MHz", 7) == 0) {
         sscanf(line,"cpu MHz         : %f", &ret);
-        delete line; 
         return (double) ret; 
       }
+      if (strncmp(line, "timebase", 8) == 0) {
+        sscanf(line,"timebase        : %f", &ret);
+        return (double) ret / 1.0e6; 
+      }
     }
-  }
-  else
-  {
+  } else {
     perror("/proc/cpuinfo file not found:");
   }
-  delete line; 
   return (double) ret;
 }
   
@@ -481,7 +474,7 @@ extern "C" unsigned long long getLinuxHighResolutionTscCounter(void);
 
 #endif /* TAU_LINUX_TIMERS */
 
-#if defined(TAUKTAU) || defined(TAUKTAU_MERGE)
+#if defined(TAUKTAU) || defined(TAUKTAU_MERGE) || defined(TAUKTAU_SHCTR)
 ///////////////////////////////////////////////////////////////////////////
 double KTauGetMHz(void)
 {
@@ -586,17 +579,17 @@ double TauWindowsUsecD(void)
 
 #ifdef TAU_MULTIPLE_COUNTERS
 void RtsLayer::getUSecD (int tid, double *values){
-#if (defined(TAU_EPILOG) && !defined(PROFILING_ON)) 
+#if ((defined(TAU_EPILOG) && !defined(PROFILING_ON)) || (defined(TAU_VAMPIRTRACE) && !defined(PROFILING_ON)))
   return;
-#endif /* TAU_EPILOG, PROFILING_ON */
+#endif /* TAU_EPILOG/VAMPIRTRACE, PROFILING_ON */
   MultipleCounterLayer::getCounters(tid, values);
 }
 #else //TAU_MULTIPLE_COUNTERS
 double RtsLayer::getUSecD (int tid) {
 
-#if (defined(TAU_EPILOG) && !defined(PROFILING_ON)) 
+#if ((defined(TAU_EPILOG) && !defined(PROFILING_ON)) || (defined(TAU_VAMPIRTRACE) && !defined(PROFILING_ON)))
   return 0;
-#endif /* TAU_EPILOG, PROFILING_ON */
+#endif /* TAU_EPILOG/VAMPIRTRACE, PROFILING_ON */
 
 
 #ifdef TAU_PCL
@@ -895,6 +888,7 @@ int RtsLayer::setAndParseProfileGroups(char *prog, char *str)
 	  */
  	case '0' :
 	  RtsLayer::enableProfileGroup(TAU_GROUP_0);
+	  printf("ENABLING 0!\n");
 	  break;
 	case '1' : // User1
 	  switch (str[1])
@@ -1406,7 +1400,7 @@ std::string RtsLayer::GetRTTI(const char *name)
 }
 
 /***************************************************************************
- * $RCSfile: RtsLayer.cpp,v $   $Author: sameer $
- * $Revision: 1.81 $   $Date: 2007/02/13 02:20:45 $
- * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.81 2007/02/13 02:20:45 sameer Exp $ 
+ * $RCSfile: RtsLayer.cpp,v $   $Author: anataraj $
+ * $Revision: 1.85 $   $Date: 2007/04/19 03:21:45 $
+ * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.85 2007/04/19 03:21:45 anataraj Exp $ 
  ***************************************************************************/
