@@ -54,6 +54,9 @@ void TraceCallStack(int tid, Profiler *current);
 #ifdef TAUKTAU_MERGE
 #include <Profile/KtauFuncInfo.h>
 #endif //TAUKTAU_MERGE
+#ifdef TAUKTAU_SHCTR
+#include <Profile/KtauCounters.h>
+#endif //TAUKTAU_SHCTR
 #endif //TAUKTAU
 
 //////////////////////////////////////////////////////////////////////
@@ -94,6 +97,8 @@ int RtsLayer::myThread(void)
 	// C++ app shouldn't use this unless there's a VM
 #elif TAU_OPENMP
   return OpenMPLayer::GetThreadId();
+#elif TAU_PAPI_THREADS
+  return PapiThreadLayer::GetThreadId();
 #else  // if no other thread package is available 
   return 0;
 #endif // PTHREADS
@@ -125,6 +130,8 @@ void RtsLayer::RegisterThread()
   TulipThreadLayer::RegisterThread();
 #elif TAU_OPENMP
   OpenMPLayer::RegisterThread();
+#elif TAU_PAPI_THREADS
+  PapiThreadLayer::RegisterThread();
 #endif // PTHREADS
 // Note: Java thread registration is done at the VM layer in TauJava.cpp
   return;
@@ -157,6 +164,10 @@ void RtsLayer::RegisterFork(int nodeid, enum TauFork_t opcode)
   PapiLayer::reinitializePAPI();
 #endif
 
+#ifdef TAUKTAU_SHCTR
+     KtauCounters::RegisterFork(opcode);//forking needs to be tested further
+#endif	// TAUKTAU_SHCTR
+
   TAU_PROFILE_SET_NODE(nodeid);
   // First, set the new id 
   if (opcode == TAU_EXCLUDE_PARENT_DATA)
@@ -270,6 +281,8 @@ void RtsLayer::LockDB(void)
   JavaThreadLayer::LockDB();
 #elif TAU_OPENMP
   OpenMPLayer::LockDB();
+#elif TAU_PAPI_THREADS
+  PapiThreadLayer::LockDB();
 #endif // PTHREADS
   return ; // do nothing if threads are not used
 }
@@ -292,6 +305,8 @@ void RtsLayer::UnLockDB(void)
   JavaThreadLayer::UnLockDB();
 #elif TAU_OPENMP
   OpenMPLayer::UnLockDB();
+#elif TAU_PAPI_THREADS
+  PapiThreadLayer::UnLockDB();
 #endif // PTHREADS
   return;
 }
@@ -314,6 +329,8 @@ void RtsLayer::LockEnv(void)
   JavaThreadLayer::LockEnv();
 #elif TAU_OPENMP
   OpenMPLayer::LockEnv();
+#elif TAU_PAPI_THREADS
+  PapiThreadLayer::LockEnv();
 #endif // PTHREADS
   return ; // do nothing if threads are not used
 }
@@ -336,6 +353,8 @@ void RtsLayer::UnLockEnv(void)
   JavaThreadLayer::UnLockEnv();
 #elif TAU_OPENMP
   OpenMPLayer::UnLockEnv();
+#elif TAU_PAPI_THREADS
+  PapiThreadLayer::UnLockEnv();
 #endif // PTHREADS
   return;
 }
@@ -343,8 +362,8 @@ void RtsLayer::UnLockEnv(void)
 
 /***************************************************************************
  * $RCSfile: RtsThread.cpp,v $   $Author: anataraj $
- * $Revision: 1.23 $   $Date: 2006/11/09 05:14:12 $
- * VERSION: $Id: RtsThread.cpp,v 1.23 2006/11/09 05:14:12 anataraj Exp $
+ * $Revision: 1.25 $   $Date: 2007/04/19 03:21:45 $
+ * VERSION: $Id: RtsThread.cpp,v 1.25 2007/04/19 03:21:45 anataraj Exp $
  ***************************************************************************/
 
 
