@@ -53,6 +53,14 @@ void tau_profile_exit_(char *msg)
 {
 }
 
+void tau_db_dump_(void)
+{
+}
+
+void tau_db_dump_prefix_(char *prefix)
+{
+}
+
 void tau_profile_init_(int *argc, char **argv)
 {
 }
@@ -87,6 +95,14 @@ void tau_profile_exit(char *msg)
 {
 }
 
+void tau_db_dump(void)
+{
+}
+
+void tau_db_dump_prefix(char *prefix)
+{
+}
+
 void tau_profile_init(int *argc, char **argv)
 {
 }
@@ -171,6 +187,14 @@ void TAU_PROFILE_EXIT(char *msg)
 {
 }
 
+void TAU_DB_DUMP(void)
+{
+}
+
+void TAU_DB_DUMP_PREFIX(char *prefix)
+{
+}
+
 void TAU_PROFILE_INIT()
 {
   _main();
@@ -372,6 +396,14 @@ void tau_profile_exit__(char *msg)
 {
 }
 
+void tau_db_dump__(void)
+{
+}
+
+void tau_db_dump_prefix__(char *prefix)
+{
+}
+
 void tau_profile_init__(int *argc, char **argv)
 {
 }
@@ -547,11 +579,87 @@ void TAU_SET_INTERRUPT_INTERVAL(int value)
 {
 } 
 
+void Tau_start_timer(void * timer, int phase) 
+{
+}
+
+void Tau_stop_timer(void *) 
+{
+}
+ 
+void Tau_create_top_level_timer_if_necessary(void)
+{
+}
+
+void Tau_stop_top_level_timer_if_necessary(void)
+{
+}
+
+void Tau_profile_c_timer(void **ptr, char *fname, char *type, TauGroup_t group, char *group_name)
+{
+}
+
+int tau_totalnodes(int set_or_get, int value)
+{
+  return 0;
+}
+
+void Tau_trace_recvmsg(int type, int source, int length)
+{
+}
+
+void Tau_trace_sendmsg(int type, int destination, int length)
+{
+}
+
+void Tau_set_node(int node)
+{
+}
+
+
+void Tau_bcast_data(int data)
+{
+}
+
+void Tau_reduce_data(int data)
+{
+}
+
+void Tau_alltoall_data(int data)
+{
+}
+
+void Tau_scatter_data(int data)
+{
+}
+
+void Tau_gather_data(int data)
+{
+}
+
+void Tau_allgather_data(int data) 
+{
+}
+
+void Tau_allreduce_data(int data)
+{
+}
+
+void Tau_scan_data(int data)
+{
+}
+
+void Tau_reducescatter_data(int data)
+{
+}
+
+
+
 ////////////////////////////////////////////////////////////////////////////
 } /* extern "C" */
 
 /***************************************************************************
- * $RCSfile: TauDisable.cpp,v $   $Author: amorris $
- * $Revision: 1.6 $   $Date: 2005/11/11 03:46:49 $
- * POOMA_VERSION_ID: $Id: TauDisable.cpp,v 1.6 2005/11/11 03:46:49 amorris Exp $ 
+ * $RCSfile: TauDisable.cpp,v $   $Author: sameer $
+ * $Revision: 1.8 $   $Date: 2007/03/26 21:53:05 $
+ * POOMA_VERSION_ID: $Id: TauDisable.cpp,v 1.8 2007/03/26 21:53:05 sameer Exp $ 
  ***************************************************************************/
