@@ -32,6 +32,8 @@
 #include <ctype.h>
 #include <string.h>
 #include "Profile/ProfileGroups.h"
+#include "Profile/TauMemory.h"
+
 
 
 
@@ -88,6 +90,9 @@ void Tau_mark_group_as_phase(void **ptr);
 void Tau_profile_callstack(void );
 void Tau_profile_snapshot(char *name);
 void Tau_profile_snapshot_1l(char *name, int number);
+void Tau_metadata(char *name, char *value);
+
+
   
 
 
@@ -222,6 +227,59 @@ void tau_pure_stop__(char *fname, int flen) {
   tau_pure_stop(fname, flen);
 }
 
+/* C API */
+void Tau_start(char *name)
+{
+  tau_pure_start(name, strlen(name));
+}
+
+
+void TAU_START(char *fname, int flen)
+{
+  tau_pure_start(fname, flen);
+}
+
+void tau_start(char *fname, int flen)
+{
+  tau_pure_start(fname, flen);
+}
+
+void tau_start_(char *fname, int flen)
+{
+  tau_pure_start(fname, flen);
+}
+
+void tau_start__(char *fname, int flen)
+{
+  tau_pure_start(fname, flen);
+}
+
+void TAU_STOP(char *fname, int flen)
+{
+  tau_pure_stop(fname, flen);
+}
+
+void tau_stop(char *fname, int flen)
+{
+  tau_pure_stop(fname, flen);
+}
+
+void tau_stop_(char *fname, int flen)
+{
+  tau_pure_stop(fname, flen);
+}
+
+void tau_stop__(char *fname, int flen)
+{
+  tau_pure_stop(fname, flen);
+}
+
+/* C API */
+void Tau_stop(char *name)
+{
+  tau_pure_stop(name, strlen(name));
+}
+
 void tau_profile_timer_(void **ptr, char *fname, int flen)
 {
   
@@ -1458,11 +1516,153 @@ void TAU_PROFILE_SNAPSHOT(char *name, int slen) {
 }
 
 
+//////////////////////////////////////////////////////////////////////
+// Metadata routines
+//////////////////////////////////////////////////////////////////////
+void tau_metadata_(char *name, char *value, int nlen, int vlen) {
+  char *fname = getFortranName(name, nlen);
+  char *fvalue = getFortranName(value, vlen);
+  Tau_metadata(fname, fvalue);
+  free (fname);
+  free (fvalue);
+}
+
+void tau_metadata(char *name, char *value, int nlen, int vlen) {
+  tau_metadata_(name, value, nlen, vlen);
+}
+
+void tau_metadata__(char *name, char *value, int nlen, int vlen) {
+  tau_metadata_(name, value, nlen, vlen);
+}
+
+void TAU_METADATA(char *name, char *value, int nlen, int vlen) {
+  tau_metadata_(name, value, nlen, vlen);
+}
+
+
+
+
+void tau_alloc_(void ** ptr, int* line, int *size, char *name, int slen) 
+{
+    char *localname = (char *) malloc((size_t)slen+1);
+    char *modname = (char *) malloc((size_t)slen+1);
+    char *tmp = localname;
+    char *tmp2 = modname;
+    int skipwhite = 1;
+    int idx = 0;
+    strncpy(localname, name, slen);
+    localname[slen] = '\0';
+
+    // check for unprintable characters
+    for(int i=0; i<strlen(localname); i++) {
+      if (!VALID_NAME_CHAR(localname[i])) {
+        localname[i] = '\0';
+        break;
+      }
+    }
+
+    // fix continuation lines
+    for(int j=0; j<strlen(localname); j++) {
+      if (localname[j] == '&') {
+        skipwhite = 1;
+      } else {
+        if (skipwhite && localname[j] == ' ') {
+          // nothing, skip over it
+        } else {
+          modname[idx++] = localname[j];
+          skipwhite = 0;
+        }
+      }
+    }
+    modname[idx] = 0;
+    localname = modname;
+
+#ifdef DEBUG_PROF
+  printf("ALLOCATE ptr %p *ptr %p line %d size %d\n", ptr, *ptr, *line, *size);
+#endif /* DEBUG_PROF */
+  Tau_track_memory_allocation(localname, *line, *size, ptr);
+  free(tmp);
+  free(tmp2);
+}
+
+void tau_alloc(void ** ptr, int* line, int *size, char *name, int slen) 
+{
+  tau_alloc_(ptr, line, size, name, slen);
+}
+
+void tau_alloc__(void ** ptr, int* line, int *size, char *name, int slen) 
+{
+  tau_alloc_(ptr, line, size, name, slen);
+}
+
+void TAU_ALLOC(void ** ptr, int* line, int *size, char *name, int slen) 
+{
+  tau_alloc_(ptr, line, size, name, slen);
+}
+
+void tau_dealloc_(void ** ptr, int* line, char *name, int slen) 
+{
+    char *localname = (char *) malloc((size_t)slen+1);
+    char *modname = (char *) malloc((size_t)slen+1);
+    char *tmp = localname;
+    char *tmp2 = modname;
+    int skipwhite = 1;
+    int idx = 0;
+    strncpy(localname, name, slen);
+    localname[slen] = '\0';
+
+    // check for unprintable characters
+    for(int i=0; i<strlen(localname); i++) {
+      if (!VALID_NAME_CHAR(localname[i])) {
+        localname[i] = '\0';
+        break;
+      }
+    }
+
+    // fix continuation lines
+    for(int j=0; j<strlen(localname); j++) {
+      if (localname[j] == '&') {
+        skipwhite = 1;
+      } else {
+        if (skipwhite && localname[j] == ' ') {
+          // nothing, skip over it
+        } else {
+          modname[idx++] = localname[j];
+          skipwhite = 0;
+        }
+      }
+    }
+    modname[idx] = 0;
+    localname = modname;
+
+#ifdef DEBUG_PROF
+  printf("DEALLOCATE ptr %p *ptr %p line %ld\n", ptr,  *ptr, *line);
+#endif /* DEBUG_PROF */
+  Tau_track_memory_deallocation(localname, *line, ptr);
+  free(tmp);
+  free(tmp2);
+}
+
+void tau_dealloc(void ** ptr, int* line, char *name, int slen) 
+{
+  tau_dealloc_(ptr, line, name, slen);
+}
+
+void tau_dealloc__(void ** ptr, int* line, char *name, int slen) 
+{
+  tau_dealloc_(ptr, line, name, slen);
+}
+
+void TAU_DEALLOC(void ** ptr, int* line, char *name, int slen) 
+{
+  tau_dealloc_(ptr, line, name, slen);
+}
+
 } /* extern "C" */
 
 
 /***************************************************************************
- * $RCSfile: TauFAPI.cpp,v $   $Author: amorris $
- * $Revision: 1.55 $   $Date: 2007/01/04 02:36:29 $
- * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.55 2007/01/04 02:36:29 amorris Exp $ 
+ * $RCSfile: TauFAPI.cpp,v $   $Author: sameer $
+ * $Revision: 1.60 $   $Date: 2007/03/30 22:43:12 $
+ * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.60 2007/03/30 22:43:12 sameer Exp $ 
  ***************************************************************************/
