@@ -27,6 +27,13 @@
 #include <signal.h>
 #include <Profile/Profiler.h>
 
+#if (defined(__QK_USER__) || defined(__LIBCATAMOUNT__ ))
+#ifndef TAU_CATAMOUNT
+#define TAU_CATAMOUNT 
+#endif /* TAU_CATAMOUNT */
+#include <catamount/catmalloc.h>
+#endif /* __QK_USER__ || __LIBCATAMOUNT__ */
+
 /* Which platforms support mallinfo? */
 #ifndef TAU_HASMALLINFO
 #if (defined (__linux__) || defined (_AIX) || defined(sgi) || \
@@ -150,9 +157,24 @@ double TauGetMaxRSS(void)
 #ifdef TAU_HASMALLINFO
   struct mallinfo minfo = mallinfo();
   /* compute the memory used */
-  double used = (double) (minfo.hblkhd + minfo.usmblks + minfo.uordblks);
+  double used = (double) ((unsigned int) minfo.hblkhd + 0.0 + (unsigned int) minfo.usmblks + (unsigned int) minfo.uordblks);
+#ifdef DEBUG_PROF
+  cout <<"minfo.hblkhd= "<<(unsigned int) minfo.hblkhd<<endl;
+  cout <<"minfo.hblkhd= "<<(unsigned int) minfo.usmblks<<endl;
+  cout <<"minfo.hblkhd= "<<(unsigned int) minfo.uordblks<<endl;
+  cout <<"used memory in bytes = "<<used<<endl;
+#endif /* DEBUG_PROF */
   /* This is in bytes, we need KB */
   return used/1024.0;
+#else 
+#ifdef TAU_CATAMOUNT
+  size_t fragments;
+  unsigned long total_free, largest_free, total_used;
+  if (heap_info(&fragments, &total_free, &largest_free, &total_used) == 0)
+  {
+    return  total_used/1024.0; 
+  }
+#endif /* TAU_CATAMOUNT */
 #endif /* TAU_HASMALLINFO */
 
 #if (! (defined (TAU_WINDOWS) || defined (CRAYCC)))
@@ -357,9 +379,9 @@ void TauTrackMuseEvents(void)
 }
   
 /***************************************************************************
- * $RCSfile: TauHandler.cpp,v $   $Author: amorris $
- * $Revision: 1.14 $   $Date: 2005/11/11 03:46:50 $
- * POOMA_VERSION_ID: $Id: TauHandler.cpp,v 1.14 2005/11/11 03:46:50 amorris Exp $ 
+ * $RCSfile: TauHandler.cpp,v $   $Author: sameer $
+ * $Revision: 1.16 $   $Date: 2007/01/10 18:24:23 $
+ * POOMA_VERSION_ID: $Id: TauHandler.cpp,v 1.16 2007/01/10 18:24:23 sameer Exp $ 
  ***************************************************************************/
 
 	
