@@ -4,6 +4,11 @@
 #include <stdlib.h>
 #define TAU_MAX_REQUESTS  4096
 
+#ifdef TAU_SYNCHRONIZE_CLOCKS
+extern void TauSyncClocks(int rank, int size);
+extern void TauSyncFinalClocks(int rank, int size);
+#endif
+
 
 /* This file uses the MPI Profiling Interface with TAU instrumentation.
    It has been adopted from the MPE Profiling interface wrapper generator
@@ -193,6 +198,7 @@ extern int tau_totalnodes(int set_or_get, int value);
 
 
 #ifdef TAU_TRACK_MSG
+
 void TauProcessRecv ( request, status, note )
 MPI_Request request;
 MPI_Status *status;
@@ -244,22 +250,110 @@ char *note;
     TAU_TRACE_RECVMSG(othertag, translateRankToWorld(rq->comm, otherid), rq->size);
   }
 
-  /* Remove the record from the request list */
-  if (last) {
-    if (rq == requests_tail_0) {
-      requests_tail_0 = last;
+  if (rq->is_persistent == 0) {
+    /* Remove the record from the request list */
+    if (last) {
+      if (rq == requests_tail_0) {
+	requests_tail_0 = last;
+      }
+      last->next = rq->next;
+    } else {
+      requests_head_0 = rq->next;
     }
-    last->next = rq->next;
-  } else {
-    requests_head_0 = rq->next;
+    free( rq );
   }
-  free( rq );
   
   return ; 
 }
 
+/* This routine traverses the list of requests and checks for RQ_SEND. The 
+   message is logged if this request matches */
 
 
+void TauProcessSend ( request, note )
+MPI_Request request;
+char *note;
+{
+  request_list *rq, *last;
+  int otherid, othertag;
+
+#ifdef DEBUG
+  int myrank;
+  PMPI_Comm_rank(MPI_COMM_WORLD, &myrank);
+#endif /* DEBUG */
+
+  /* look for request */
+  rq = requests_head_0;
+  last = 0;
+
+  /* first request */
+  while ((rq != NULL) && (rq->request != request)) {
+#ifdef DEBUG 
+   printf("Node %d: Comparing %lx %lx\n", myrank, rq->request, request);
+#endif /* DEBUG */
+
+    last = rq;
+    rq = rq->next;
+  }
+
+  if (!rq) {
+#ifdef DEBUG
+    fprintf( stderr, "Node %d: Request not found in '%s'.\n",myrank, note );
+#endif /* DEBUG */
+    return ;                /* request not found */
+  }
+#ifdef DEBUG
+  else
+  {
+    printf("Node %d: Request found %lx\n", myrank, request);
+  }
+#endif /* DEBUG */
+  if ((rq) && rq->status == RQ_SEND)
+  { 
+    otherid = translateRankToWorld(rq->comm, rq->otherParty);
+    othertag = rq->tag;
+    /* post the send message */
+    TAU_TRACE_SENDMSG(othertag, otherid, rq->size);
+  }
+
+  return ; 
+}
+
+
+
+
+request_list *TauGetRequest( MPI_Request request) {
+  request_list *rq;
+
+  rq = requests_head_0;
+
+  while ((rq != NULL) && (rq->request != request)) {
+    rq = rq->next;
+  }
+  return rq;
+}
+
+
+void TauAddRequest (int status, int count, MPI_Datatype datatype, int other, 
+		    int tag, MPI_Comm comm, MPI_Request *request, int returnVal, int persistent) {
+  int typesize;
+  request_list *newrq1;
+  if (other != MPI_PROC_NULL && returnVal == MPI_SUCCESS) {
+    if (newrq1 = (request_list*) malloc(sizeof( request_list ))) {
+      PMPI_Type_size( datatype, &typesize );
+      newrq1->request = *request;
+      newrq1->status = status;
+      newrq1->size = typesize * count;
+      newrq1->otherParty = other;
+      newrq1->comm = comm;
+      newrq1->tag = tag;
+      newrq1->is_persistent = persistent;
+      newrq1->next = 0;
+      rq_add( requests_head_0, requests_tail_0, newrq1 );
+    }
+  }
+}
+
 /* This routine traverses the list of requests and deletes the given request */
 void TauRemoveRequest ( request, note )
 MPI_Request request;
@@ -1328,10 +1422,18 @@ MPI_Errhandler errhandler;
 int  MPI_Finalize(  )
 {
   int  returnVal;
+  int size;
 
   TAU_PROFILE_TIMER(tautimer, "MPI_Finalize()",  " ", TAU_MESSAGE);
   TAU_PROFILE_START(tautimer);
   
+#ifdef TAU_SYNCHRONIZE_CLOCKS
+
+  PMPI_Comm_size( MPI_COMM_WORLD, &size );
+
+  TauSyncFinalClocks(procid_0, size);
+#endif
+
   returnVal = PMPI_Finalize(  );
 
   TAU_PROFILE_STOP(tautimer);
@@ -1378,6 +1480,10 @@ char *** argv;
   PMPI_Comm_size( MPI_COMM_WORLD, &size );
   tau_totalnodes(1, size); /* Set the totalnodes */
 
+#ifdef TAU_SYNCHRONIZE_CLOCKS
+  TauSyncClocks(procid_0, size);
+#endif
+
 #ifdef TAU_TRACK_MSG
   requests_head_0 = requests_tail_0 = 0;
 #endif /* TAU_TRACK_MSG */
@@ -1410,6 +1516,10 @@ int *provided;
   PMPI_Comm_size( MPI_COMM_WORLD, &size );
   tau_totalnodes(1, size); /* Set the totalnodes */
 
+#ifdef TAU_SYNCHRONIZE_CLOCKS
+  TauSyncClocks(procid_0, size);
+#endif
+
 #ifdef TAU_TRACK_MSG
   requests_head_0 = requests_tail_0 = 0;
 #endif /* TAU_TRACK_MSG */
@@ -1526,27 +1636,18 @@ MPI_Comm comm;
 MPI_Request * request;
 {
   int  returnVal;
-#ifdef TAU_TRACK_MSG
-  int typesize3;
-#endif /* TAU_TRACK_MSG */
 
-  
-  
 /* fprintf( stderr, "MPI_Bsend_init call on %d\n", procid_0 ); */
   
   TAU_PROFILE_TIMER(tautimer, "MPI_Bsend_init()",  " ", TAU_MESSAGE);
   TAU_PROFILE_START(tautimer);
-  
-#ifdef TAU_TRACK_MSG
-
-  if (dest != MPI_PROC_NULL) {
-    PMPI_Type_size( datatype, &typesize3 );
-    TAU_TRACE_SENDMSG(tag, translateRankToWorld(comm, dest), count*typesize3);
-  }
-#endif /* TAU_TRACK_MSG */
 
   returnVal = PMPI_Bsend_init( buf, count, datatype, dest, tag, comm, request );
 
+#ifdef TAU_TRACK_MSG
+  TauAddRequest(RQ_SEND, count, datatype, dest, tag, comm, request, returnVal, 1);
+#endif /* TAU_TRACK_MSG */
+
   TAU_PROFILE_STOP(tautimer);
 
   return returnVal;
@@ -1639,12 +1740,6 @@ MPI_Comm comm;
 MPI_Request * request;
 {
   int  returnVal;
-#ifdef TAU_TRACK_MSG
-  request_list *newrq1;
-  int typesize;
-#endif /* TAU_TRACK_MSG */
-
-  
   
   TAU_PROFILE_TIMER(tautimer, "MPI_Recv_init()",  " ", TAU_MESSAGE);
   TAU_PROFILE_START(tautimer);
@@ -1654,18 +1749,7 @@ MPI_Request * request;
   TAU_PROFILE_STOP(tautimer);
 
 #ifdef TAU_TRACK_MSG
-  PMPI_Type_size( datatype, &typesize );
-  if (source != MPI_PROC_NULL && returnVal == MPI_SUCCESS) {
-    if (newrq1 = (request_list*) malloc(sizeof( request_list ))) {
-      newrq1->request = *request;
-      newrq1->status = RQ_RECV;
-      newrq1->tag = tag;
-      newrq1->size = count * typesize;
-      newrq1->comm = comm;
-      newrq1->next = 0;
-      rq_add( requests_head_0, requests_tail_0, newrq1 );
-    }
-  }
+  TauAddRequest(RQ_RECV, count, datatype, source, tag, comm, request, returnVal, 1);
 #endif /* TAU_TRACK_MSG */
 
   return returnVal;
@@ -1681,26 +1765,21 @@ MPI_Comm comm;
 MPI_Request * request;
 {
   int  returnVal;
-#ifdef TAU_TRACK_MSG
-  int typesize3;
-#endif /* TAU_TRACK_MSG */
 
-  
-  
-  /* fprintf( stderr, "MPI_Send_init call on %d\n", procid_0 ); */
+#ifdef DEBUG
+  fprintf( stderr, "MPI_Send_init call on %d\n", procid_0 ); 
+#endif /* DEBUG */
   
   TAU_PROFILE_TIMER(tautimer, "MPI_Send_init()",  " ", TAU_MESSAGE);
   TAU_PROFILE_START(tautimer);
   
-#ifdef TAU_TRACK_MSG
-  if (dest != MPI_PROC_NULL) {
-    PMPI_Type_size( datatype, &typesize3 );
-    TAU_TRACE_SENDMSG(tag, translateRankToWorld(comm, dest), count * typesize3);
-  }
-#endif /* TAU_TRACK_MSG */
-
   returnVal = PMPI_Send_init( buf, count, datatype, dest, tag, comm, request );
 
+  /* we need to store the request and associate it with the size/tag so MPI_Start can 
+     retrieve it and log the TAU_TRACE_SENDMSG */
+#ifdef TAU_TRACK_MSG
+  TauAddRequest(RQ_SEND, count, datatype, dest, tag, comm, request, returnVal, 1);
+#endif /* TAU_TRACK_MSG */
 
   TAU_PROFILE_STOP(tautimer);
 
@@ -1843,6 +1922,7 @@ MPI_Request * request;
       newrq1->otherParty = source;
       newrq1->comm = comm;
       newrq1->tag = tag;
+      newrq1->is_persistent = 0;
       newrq1->next = 0;
       rq_add( requests_head_0, requests_tail_0, newrq1 );
     }
@@ -2102,11 +2182,6 @@ MPI_Comm comm;
 MPI_Request * request;
 {
   int  returnVal;
-#ifdef TAU_TRACK_MSG
-  int typesize3;
-#endif /* TAU_TRACK_MSG */
-
-  
   
 /* fprintf( stderr, "MPI_Rsend_init call on %d\n", procid_0 ); */
   
@@ -2115,13 +2190,10 @@ MPI_Request * request;
   
   returnVal = PMPI_Rsend_init( buf, count, datatype, dest, tag, comm, request );
 
-
 #ifdef TAU_TRACK_MSG
-  if (dest != MPI_PROC_NULL) {
-    PMPI_Type_size( datatype, &typesize3 );
-    TAU_TRACE_SENDMSG(tag, translateRankToWorld(comm, dest), count * typesize3);
-  }
+  TauAddRequest(RQ_SEND, count, datatype, dest, tag, comm, request, returnVal, 1);
 #endif /* TAU_TRACK_MSG */
+
   TAU_PROFILE_STOP(tautimer);
 
   return returnVal;
@@ -2313,11 +2385,6 @@ MPI_Comm comm;
 MPI_Request * request;
 {
   int  returnVal;
-#ifdef TAU_TRACK_MSG
-  int typesize3;
-#endif /* TAU_TRACK_MSG */
-
-  
   
 /* fprintf( stderr, "MPI_Ssend_init call on %d\n", procid_0 ); */
   
@@ -2326,13 +2393,10 @@ MPI_Request * request;
   
   returnVal = PMPI_Ssend_init( buf, count, datatype, dest, tag, comm, request );
 
-
 #ifdef TAU_TRACK_MSG
-  if (dest != MPI_PROC_NULL) {
-    PMPI_Type_size( datatype, &typesize3 );
-    TAU_TRACE_SENDMSG(tag, translateRankToWorld(comm, dest), count * typesize3);
-  }
+  TauAddRequest(RQ_SEND, count, datatype, dest, tag, comm, request, returnVal, 1);
 #endif /* TAU_TRACK_MSG */
+
   TAU_PROFILE_STOP(tautimer);
 
   return returnVal;
@@ -2341,13 +2405,32 @@ MPI_Request * request;
 int  MPI_Start( request )
 MPI_Request * request;
 {
+  request_list *rq;
   int  returnVal;
 
   TAU_PROFILE_TIMER(tautimer, "MPI_Start()",  " ", TAU_MESSAGE);
   TAU_PROFILE_START(tautimer);
-  
+
+
+
+
+#ifdef TAU_TRACK_MSG
+  rq = TauGetRequest(*request);
+  TauProcessSend(*request, "MPI_Start");
+#endif /* TAU_TRACK_MSG */
+
+
   returnVal = PMPI_Start( request );
 
+
+#ifdef TAU_TRACK_MSG
+  // fix up the request since MPI_Start may (will) change it
+  rq->request = *request;
+#endif /* TAU_TRACK_MSG */
+
+
+
+
   TAU_PROFILE_STOP(tautimer);
 
   return returnVal;
@@ -2534,7 +2617,7 @@ MPI_Status * array_of_statuses;
 #ifdef TAU_TRACK_MSG
   for (i=0; i < *outcount; i++) {
     TauProcessRecv( (saverequest [array_of_indices[i]]),
-			        &(array_of_statuses [array_of_indices[i]]),
+			        &(array_of_statuses[i]),
 			        "MPI_Testsome" );
   }
   if (need_to_free) {
@@ -2928,7 +3011,7 @@ MPI_Status * array_of_statuses;
 #ifdef TAU_TRACK_MSG
   for (i=0; i < *outcount; i++) {
     TauProcessRecv( (saverequest [array_of_indices[i]]),
-			        &(array_of_statuses [array_of_indices[i]]),
+			        &(array_of_statuses[i]),
 			        "MPI_Waitsome" );
   }
   if (need_to_free) {
