@@ -32,6 +32,15 @@
 # include <Profile/Profiler.h>
 
 
+#ifdef TAU_LARGEFILE
+  #define LARGEFILE_OPTION O_LARGEFILE
+#else
+  #define LARGEFILE_OPTION 0
+#endif
+
+#ifdef TAU_SYNCHRONIZE_CLOCKS
+extern double TauSyncAdjustTimeStamp(double timestamp);
+#endif
 
 # define PCXX_EVENT_SRC 
 # include "Profile/pcxx_events.h"
@@ -55,7 +64,7 @@ static PCXX_EV TraceBuffer[TAU_MAX_THREADS][TAU_MAX_RECORDS];
 // static int  TauEventMax[TAU_MAX_THREADS] = {TAU_MAX_RECORDS - 1 };
 
 /* -- current record pointer for each thread -- */
-static int  TauCurrentEvent[TAU_MAX_THREADS] = {0}; 
+static int TauCurrentEvent[TAU_MAX_THREADS] = {0}; 
 
 /* -- event trace file descriptor ---------------------------- */
 static int TraceFd[TAU_MAX_THREADS] = {0};
@@ -83,13 +92,24 @@ x_uint64 pcxx_GetUSecLong(int tid)
   //assumes that counter1 contains the tracing metric.
   //Thus, if you want gettimeofday, make sure that you
   //define counter1 to be GETTIMEOFDAY.
-  RtsLayer::getUSecD(tid, tracerValues);
   //Just return values[0] as that is the position of counter1 (whether it
   //is active or not).
-  return (unsigned long long) tracerValues[0];
+
+// THE SLOW WAY!
+//   RtsLayer::getUSecD(tid, tracerValues);
+//   double value = tracerValues[0];
+
+  x_uint64 value = MultipleCounterLayer::getSingleCounter(tid, 0);
+
 #else //TAU_MULTIPLE_COUNTERS
-  return (x_uint64) RtsLayer::getUSecD(tid);
+  x_uint64 value = RtsLayer::getUSecD(tid);
 #endif // TAU_MULTIPLE_COUNTERS
+
+#ifdef TAU_SYNCHRONIZE_CLOCKS
+  return (x_uint64) TauSyncAdjustTimeStamp(value);
+#else 
+  return (x_uint64) value;
+#endif
 }
 
 /* -- write event to buffer only [without overflow check] ---- */
@@ -221,16 +241,16 @@ int TraceEvInit(int tid)
 
     char *dirname, tracefilename[1024];
     if ((dirname = getenv("TRACEDIR")) == NULL) {
-    // Use default directory name .
-    dirname  = new char[8];
-    strcpy (dirname,".");
+      // Use default directory name .
+      dirname  = new char[8];
+      strcpy (dirname,".");
     }
     sprintf(tracefilename, "%s/tautrace.%d.%d.%d.trc",dirname, 
-      RtsLayer::myNode(), RtsLayer::myContext(), tid);
+	    RtsLayer::myNode(), RtsLayer::myContext(), tid);
 
     init_wrap_up ();
 
-    if ((TraceFd[tid] = open (tracefilename, O_WRONLY|O_CREAT|O_TRUNC|O_APPEND|O_BINARY, 0600)) < 0)
+    if ((TraceFd[tid] = open (tracefilename, O_WRONLY|O_CREAT|O_TRUNC|O_APPEND|O_BINARY|LARGEFILE_OPTION, 0600)) < 0)
     {
       fprintf (stderr, "TraceEvInit[open]: ");
       perror (tracefilename);
@@ -297,6 +317,8 @@ void TraceUnInitialize(int tid)
    TraceEventOnly(PCXX_EV_INIT, pcxx_ev_class, tid);
 }
 
+
+
 /* -- write event to buffer ---------------------------------- */
 void TraceEvent(long int ev, x_int64 par, int tid, x_uint64 ts, int use_ts)
 {
@@ -304,6 +326,10 @@ void TraceEvent(long int ev, x_int64 par, int tid, x_uint64 ts, int use_ts)
   int records_created = TraceEvInit(tid);
   PCXX_EV * pcxx_ev_ptr = &TraceBuffer[tid][TauCurrentEvent[tid]] ;  
 
+#ifdef TAU_SYNCHRONIZE_CLOCKS
+  ts = (x_uint64) TauSyncAdjustTimeStamp((double)ts);
+#endif
+
   if (records_created)
   {
 #ifdef DEBUG
