@@ -1,7 +1,5 @@
 package edu.uoregon.tau.paraprof;
 
-import edu.uoregon.tau.perfdmf.Thread;
-
 import java.awt.*;
 import java.awt.event.*;
 import java.awt.geom.Point2D;
@@ -19,13 +17,13 @@ import javax.swing.event.ChangeListener;
 import org.jgraph.JGraph;
 import org.jgraph.graph.*;
 
+import edu.uoregon.tau.common.ImageExport;
 import edu.uoregon.tau.paraprof.enums.CallGraphOption;
-import edu.uoregon.tau.paraprof.interfaces.ImageExport;
 import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
 import edu.uoregon.tau.perfdmf.CallPathUtilFuncs;
 import edu.uoregon.tau.perfdmf.Function;
-import edu.uoregon.tau.perfdmf.Thread;
 import edu.uoregon.tau.perfdmf.FunctionProfile;
+import edu.uoregon.tau.perfdmf.Thread;
 
 /**
  * CallGraphWindow.java
@@ -35,9 +33,9 @@ import edu.uoregon.tau.perfdmf.FunctionProfile;
  *       be implemented.  Plenty of other things could be done as well, such
  *       as using box height as another metric.
  *       
- * <P>CVS $Id: CallGraphWindow.java,v 1.1 2005/09/26 21:12:02 amorris Exp $</P>
+ * <P>CVS $Id: CallGraphWindow.java,v 1.6 2007/02/03 01:40:11 amorris Exp $</P>
  * @author	Alan Morris
- * @version	$Revision: 1.1 $
+ * @version	$Revision: 1.6 $
  */
 public class CallGraphWindow extends JFrame implements ActionListener, KeyListener,
         ChangeListener, Observer, ImageExport, Printable, ParaProfWindow {
@@ -266,7 +264,7 @@ public class CallGraphWindow extends JFrame implements ActionListener, KeyListen
 
     }
 
-    public CallGraphWindow(ParaProfTrial ppTrial, edu.uoregon.tau.perfdmf.Thread thread, Component invoker) {
+    public CallGraphWindow(ParaProfTrial ppTrial, Thread thread, Component invoker) {
         this.ppTrial = ppTrial;
         ppTrial.addObserver(this);
         this.colorMetricID = ppTrial.getDefaultMetricID();
@@ -283,13 +281,14 @@ public class CallGraphWindow extends JFrame implements ActionListener, KeyListen
 
         //Now set the title.
         if (thread.getNodeID() == -1) {
-            this.setTitle("Mean Call Graph - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+            this.setTitle("TAU: ParaProf: Mean Call Graph - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
         } else if (thread.getNodeID() == -3) {
-            this.setTitle("Standard Deviation Call Graph - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+            this.setTitle("TAU: ParaProf: Standard Deviation Call Graph - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
         } else {
-            this.setTitle("Call Graph for n,c,t, " + thread.getNodeID() + "," + thread.getContextID() + ","
+            this.setTitle("TAU: ParaProf: Call Graph for n,c,t, " + thread.getNodeID() + "," + thread.getContextID() + ","
                     + thread.getThreadID() + " - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
         }
+        ParaProfUtils.setFrameIcon(this);
 
         //Add some window listener code
         addWindowListener(new java.awt.event.WindowAdapter() {
@@ -299,7 +298,7 @@ public class CallGraphWindow extends JFrame implements ActionListener, KeyListen
         });
 
         //Set the help window text if required.
-        if (ParaProf.helpWindow.isVisible()) {
+        if (ParaProf.getHelpWindow().isVisible()) {
             this.help(false);
         }
 
@@ -1789,21 +1788,21 @@ public class CallGraphWindow extends JFrame implements ActionListener, KeyListen
 
     public void help(boolean display) {
         //Show the ParaProf help window.
-        ParaProf.helpWindow.clearText();
+        ParaProf.getHelpWindow().clearText();
         if (display)
-            ParaProf.helpWindow.show();
-        ParaProf.helpWindow.writeText("This is the Call Graph Window");
-        ParaProf.helpWindow.writeText("");
-        ParaProf.helpWindow.writeText("This window shows you a graph of call paths present in the profile data.");
-        ParaProf.helpWindow.writeText("");
-        ParaProf.helpWindow.writeText("Click on a box to highlight paths that go through that function.");
-        ParaProf.helpWindow.writeText("");
-        ParaProf.helpWindow.writeText("Right-click on a box to access the Function Data Window for that function.");
-        ParaProf.helpWindow.writeText("");
-        ParaProf.helpWindow.writeText("Experiment with the \"Box Width by...\" and \"Box Color by...\" menus (under Options) to display different types of data.");
-        ParaProf.helpWindow.writeText("");
-        ParaProf.helpWindow.writeText("If you only see a single line of boxes (no edges connecting them), it probably means that your profile data does not contain call path data.  If you believe this to be incorrect please contact us with the data at tau-bugs@cs.uoregon.edu");
-        ParaProf.helpWindow.writeText("");
+            ParaProf.getHelpWindow().show();
+        ParaProf.getHelpWindow().writeText("This is the Call Graph Window");
+        ParaProf.getHelpWindow().writeText("");
+        ParaProf.getHelpWindow().writeText("This window shows you a graph of call paths present in the profile data.");
+        ParaProf.getHelpWindow().writeText("");
+        ParaProf.getHelpWindow().writeText("Click on a box to highlight paths that go through that function.");
+        ParaProf.getHelpWindow().writeText("");
+        ParaProf.getHelpWindow().writeText("Right-click on a box to access the Function Data Window for that function.");
+        ParaProf.getHelpWindow().writeText("");
+        ParaProf.getHelpWindow().writeText("Experiment with the \"Box Width by...\" and \"Box Color by...\" menus (under Options) to display different types of data.");
+        ParaProf.getHelpWindow().writeText("");
+        ParaProf.getHelpWindow().writeText("If you only see a single line of boxes (no edges connecting them), it probably means that your profile data does not contain call path data.  If you believe this to be incorrect please contact us with the data at tau-bugs@cs.uoregon.edu");
+        ParaProf.getHelpWindow().writeText("");
     }
 
     public Dimension getViewportSize() {
@@ -1859,13 +1858,14 @@ public class CallGraphWindow extends JFrame implements ActionListener, KeyListen
 
     public void keyTyped(KeyEvent evt) {
         try {
+            char key = evt.getKeyChar();
             // zoom in and out on +/-
-            if (evt.getKeyChar() == '+') {
+            if (key == '+' || key == '=') {
                 scale = scale + 0.10;
                 if (scale > 5.0)
                     scale = 5.0;
                 graph.setScale(scale);
-            } else if (evt.getKeyChar() == '-') {
+            } else if (key == '-' || key == '_') {
                 scale = scale - 0.10;
                 if (scale < 0.10)
                     scale = 0.10;
