@@ -14,22 +14,12 @@ import javax.swing.*;
 import edu.uoregon.tau.perfdmf.*;
 
 import java.util.*;
+import edu.uoregon.tau.perfdmf.Thread;
+
 
 public class DerivedMetrics {
 
-    
-    private static void incrementStorage (edu.uoregon.tau.perfdmf.Thread thread) {
-        thread.incrementStorage();
 
-        Iterator l = thread.getFunctionProfileIterator();
-        while (l.hasNext()) {
-            FunctionProfile functionProfile = (FunctionProfile) l.next();
-            if (functionProfile != null) {
-                functionProfile.incrementStorage();
-            }
-        }
-    }
-    
     public static ParaProfMetric applyOperation(ParaProfMetric operand1, Object operand2, String inOperation) {
 
         try {
@@ -56,8 +46,7 @@ public class DerivedMetrics {
             //We do not support metric from different trials yet. Check for this.
             if ((!constant) && (trialOpA != trialOpB)) {
                 JOptionPane.showMessageDialog(ParaProf.paraProfManagerWindow,
-                        "Sorry, please select metrics from the same trial!", "ParaProf Error",
-                        JOptionPane.ERROR_MESSAGE);
+                        "Sorry, please select metrics from the same trial!", "ParaProf Error", JOptionPane.ERROR_MESSAGE);
                 return null;
             }
 
@@ -83,8 +72,7 @@ public class DerivedMetrics {
             }
 
             if (constant)
-                newMetricName = ((ParaProfMetric) trialOpA.getMetrics().get(opA)).getName() + newMetricName
-                        + constantValue;
+                newMetricName = ((ParaProfMetric) trialOpA.getMetrics().get(opA)).getName() + newMetricName + constantValue;
             else
                 newMetricName = ((ParaProfMetric) trialOpA.getMetrics().get(opA)).getName() + newMetricName
                         + ((ParaProfMetric) trialOpA.getMetrics().get(opB)).getName();
@@ -99,9 +87,6 @@ public class DerivedMetrics {
             Iterator l = trialOpA.getDataSource().getFunctions();
 
             
-            incrementStorage(trialOpA.getDataSource().getMeanData());
-            incrementStorage(trialOpA.getDataSource().getTotalData());
-            incrementStorage(trialOpA.getDataSource().getStdDevData());
 
             //######
             //Calculate the raw values.
@@ -112,14 +97,13 @@ public class DerivedMetrics {
             //######
 
             for (Iterator it = trialOpA.getDataSource().getAllThreads().iterator(); it.hasNext();) {
-                edu.uoregon.tau.perfdmf.Thread thread = (edu.uoregon.tau.perfdmf.Thread) it.next();
-                thread.incrementStorage();
+                Thread thread = (Thread) it.next();
+                thread.addMetric();
                 l = thread.getFunctionProfileIterator();
                 while (l.hasNext()) {
                     FunctionProfile functionProfile = (FunctionProfile) l.next();
                     if (functionProfile != null) {
                         Function function = functionProfile.getFunction();
-                        functionProfile.incrementStorage();
 
                         double d1 = 0.0;
                         double d2 = 0.0;
@@ -143,9 +127,6 @@ public class DerivedMetrics {
 
                         functionProfile.setInclusive(metric, result);
 
-                        //functionProfile.setInclusivePerCall(metric,
-                        //        functionProfile.getInclusive(metric) / functionProfile.getNumCalls());
-
                     }
                 }
                 thread.setThreadData(metric);
@@ -161,8 +142,7 @@ public class DerivedMetrics {
             return newMetric;
         } catch (NumberFormatException e) {
             //Display an error
-            JOptionPane.showMessageDialog(ParaProf.paraProfManagerWindow,
-                    "Did not recognize arguments! Note: DB apply not supported.", "Argument Error!",
+            JOptionPane.showMessageDialog(ParaProf.paraProfManagerWindow, "Did not recognize arguments! ", "Argument Error!",
                     JOptionPane.ERROR_MESSAGE);
             return null;
         }
