@@ -11,9 +11,7 @@ import javax.swing.event.*;
 import edu.uoregon.tau.paraprof.barchart.*;
 import edu.uoregon.tau.paraprof.enums.SortType;
 import edu.uoregon.tau.paraprof.enums.ValueType;
-import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
-import edu.uoregon.tau.paraprof.interfaces.SearchableOwner;
-import edu.uoregon.tau.paraprof.interfaces.UnitListener;
+import edu.uoregon.tau.paraprof.interfaces.*;
 import edu.uoregon.tau.perfdmf.Function;
 import edu.uoregon.tau.perfdmf.Thread;
 import edu.uoregon.tau.perfdmf.UtilFncs;
@@ -26,14 +24,14 @@ import edu.uoregon.tau.perfdmf.UtilFncs;
  * 1) Need to replace constructors with a factory, get rid of "changeToPhase..."
  * 2) Need to track all ppTrials (Observers) for comparisonChart 
  * 
- * <P>CVS $Id: FunctionBarChartWindow.java,v 1.3 2005/10/18 22:50:34 amorris Exp $</P>
+ * <P>CVS $Id: FunctionBarChartWindow.java,v 1.15 2007/02/06 02:12:15 amorris Exp $</P>
  * @author  Robert Bell, Alan Morris
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.15 $
  * @see     FunctionBarChartModel
  * @see     ThreadBarChartModel
  */
 public class FunctionBarChartWindow extends JFrame implements KeyListener, SearchableOwner, ActionListener, MenuListener,
-        Observer, ChangeListener, ParaProfWindow, UnitListener {
+        Observer, ChangeListener, ParaProfWindow, UnitListener, SortListener {
 
     private ParaProfTrial ppTrial;
     private DataSorter dataSorter;
@@ -43,8 +41,6 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
     private JMenu optionsMenu;
     private JMenu unitsSubMenu;
 
-    private JCheckBoxMenuItem sortByNCTCheckbox;
-    private JCheckBoxMenuItem sortByNameCheckBox;
     private JCheckBoxMenuItem descendingOrderCheckBox;
     private JCheckBoxMenuItem showValuesAsPercent;
     private JCheckBoxMenuItem showMetaData;
@@ -60,7 +56,6 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
     private BarChartModel model;
 
     // Phase support
-    private Thread phaseThread;
     private boolean phaseDisplay;
 
     private SearchPanel searchPanel;
@@ -70,6 +65,12 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
 
     private boolean comparisonChart;
 
+    private boolean defaultPercentValue;
+
+    private FunctionBarChartWindow() {
+    // disable default constructor
+    }
+
     // Initializes Chart as a single function across threads
     public FunctionBarChartWindow(ParaProfTrial ppTrial, Function function, Component parent) {
         this.ppTrial = ppTrial;
@@ -80,7 +81,10 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
         panel = new BarChartPanel(model, null);
         initialize(parent);
 
-        this.setTitle("Function Data Window: " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+        setTitle("TAU: ParaProf: Function Data Window: "
+                + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+        ParaProfUtils.setFrameIcon(this);
+
     }
 
     // Initializes Chart as a single thread across functions
@@ -90,7 +94,6 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
         this.phase = phase;
         dataSorter = new DataSorter(ppTrial);
         dataSorter.setPhase(phase);
-
         barLengthSlider.setValue(250);
         model = new ThreadBarChartModel(this, dataSorter, ppThread);
         panel = new BarChartPanel(model, null);
@@ -103,28 +106,18 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
             phaseString = " Phase: " + phase.getName();
         }
 
-        if (thread.getNodeID() == -1) {
-            this.setTitle("Mean Data - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse())
-                    + phaseString);
-        } else if (thread.getNodeID() == -2) {
-            this.setTitle("Total Data - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse())
-                    + phaseString);
-        } else if (thread.getNodeID() == -3) {
-            this.setTitle("Standard Deviation Data - "
-                    + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()) + phaseString);
-        } else {
-            this.setTitle(ppThread.getName() + " - "
-                    + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()) + phaseString);
-        }
-    }
+        this.setTitle("TAU: ParaProf: " + ppThread.getFullName() + " - "
+                + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()) + phaseString);
+        ParaProfUtils.setFrameIcon(this);
 
-    private FunctionBarChartWindow() {
     }
 
     public static FunctionBarChartWindow CreateComparisonWindow(ParaProfTrial ppTrial, Thread thread, Component invoker) {
         FunctionBarChartWindow window = new FunctionBarChartWindow();
 
-        window.setTitle("Comparison Window");
+        window.setTitle("ParaProf: Comparison Window");
+        ParaProfUtils.setFrameIcon(window);
+
         window.dataSorter = new DataSorter(ppTrial);
         window.ppTrial = ppTrial;
         window.comparisonChart = true;
@@ -152,6 +145,7 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
 
     private void initialize(Component parent) {
 
+        defaultPercentValue = ParaProf.preferences.getShowValuesAsPercent();
         ppTrial.addObserver(this);
 
         panel.getBarChart().setBarLength(barLengthSlider.getValue());
@@ -169,10 +163,13 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
 
         // Set up the data sorter
         dataSorter.setSelectedMetricID(ppTrial.getDefaultMetricID());
-        dataSorter.setValueType(ValueType.EXCLUSIVE_PERCENT);
+        dataSorter.setSortMetric(ppTrial.getDefaultMetricID());
+        dataSorter.setSortByVisible(true);
+        dataSorter.setSortType(SortType.VALUE);
+        //dataSorter.setValueType(ValueType.EXCLUSIVE_PERCENT);
 
         //Set the help window text if required.
-        if (ParaProf.helpWindow.isVisible()) {
+        if (ParaProf.getHelpWindow().isVisible()) {
             this.help(false);
         }
 
@@ -183,9 +180,9 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
 
         BarChart barChart = panel.getBarChart();
 
-//        if (function != null) {
-//            barChart.setLeftJustified(true);
-//        }
+        //        if (function != null) {
+        //            barChart.setLeftJustified(true);
+        //        }
 
         JScrollBar vScrollBar = panel.getVerticalScrollBar();
         vScrollBar.setUnitIncrement(35);
@@ -212,15 +209,16 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
         gbc.weighty = 100;
         addCompItem(panel, gbc, 0, 0, 1, 1);
         ParaProf.incrementNumWindows();
-
     }
 
     public void changeToPhaseDisplay(Thread thread) {
-        phaseThread = thread;
+
+        this.ppThread = new PPThread(thread, ppTrial);
         phaseDisplay = true;
 
-        this.setTitle(ParaProfUtils.getThreadIdentifier(thread) + " - Function Data: "
+        this.setTitle("TAU: ParaProf: " + ParaProfUtils.getThreadIdentifier(thread) + " - Function Data: "
                 + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+        ParaProfUtils.setFrameIcon(this);
 
         // in case we were opened on "main => foo", switch to foo
         this.function = ppTrial.getDataSource().getFunction(UtilFncs.getLeftSide(function.getName()));
@@ -228,70 +226,43 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
         // we're no longer in a phase
         this.phase = null;
         setHeader();
-        sortByNCTCheckbox.setSelected(false);
-        optionsMenu.remove(sortByNCTCheckbox);
+        //sortByNCTCheckbox.setSelected(false);
+        //optionsMenu.remove(sortByNCTCheckbox);
         descendingOrderCheckBox.setSelected(true);
 
         sortLocalData();
     }
 
-    private Component createMetricMenu(final ValueType valueType, boolean enabled, ButtonGroup group) {
-        JRadioButtonMenuItem button = null;
+    public void setMetricID(int id) {
+        dataSorter.setSelectedMetricID(id);
+        sortLocalData();
+        panel.repaint();
+    }
 
-        if (ppTrial.getNumberOfMetrics() == 1) {
-            button = new JRadioButtonMenuItem(valueType.toString(), enabled);
+    public int getMetricID() {
+        return dataSorter.getSelectedMetricID();
+    }
 
-            button.addActionListener(new ActionListener() {
-                public void actionPerformed(ActionEvent evt) {
-                    dataSorter.setValueType(valueType);
-                    sortLocalData();
-                    panel.repaint();
-                }
-            });
-            group.add(button);
-            return button;
-        } else {
-            JMenu subSubMenu = new JMenu(valueType.toString() + "...");
-            for (int i = 0; i < ppTrial.getNumberOfMetrics(); i++) {
+    public void setValueType(ValueType type) {
+        dataSorter.setValueType(type);
+        sortLocalData();
+        panel.repaint();
+    }
 
-                if (i == dataSorter.getSelectedMetricID() && enabled) {
-                    button = new JRadioButtonMenuItem(ppTrial.getMetric(i).getName(), true);
-                } else {
-                    button = new JRadioButtonMenuItem(ppTrial.getMetric(i).getName());
-                }
-                final int metricID = i;
-
-                button.addActionListener(new ActionListener() {
-
-                    public void actionPerformed(ActionEvent evt) {
-                        dataSorter.setSelectedMetricID(metricID);
-                        dataSorter.setValueType(valueType);
-                        sortLocalData();
-                        panel.repaint();
-                    }
-                });
-                group.add(button);
-                subSubMenu.add(button);
-            }
-            return subSubMenu;
-        }
+    public ValueType getValueType() {
+        return dataSorter.getValueType();
     }
 
     private void setupMenus() {
         JMenuBar mainMenu = new JMenuBar();
         mainMenu.addKeyListener(this);
-        JMenu subMenu = null;
-        JMenuItem menuItem = null;
+        JCheckBoxMenuItem box;
 
         optionsMenu = new JMenu("Options");
 
-        JCheckBoxMenuItem box = null;
-        ButtonGroup group = null;
-        JRadioButtonMenuItem button = null;
-
         box = new JCheckBoxMenuItem("Show Width Slider", false);
         box.addActionListener(this);
-        optionsMenu.add(box);
+        //optionsMenu.add(box);
 
         showFindPanelBox = new JCheckBoxMenuItem("Show Find Panel", false);
         showFindPanelBox.addActionListener(this);
@@ -310,63 +281,22 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
             }
         };
 
-        if (function != null) {
-            sortByNCTCheckbox = new JCheckBoxMenuItem("Sort By N,C,T", false);
-            sortByNCTCheckbox.addActionListener(sortData);
-            optionsMenu.add(sortByNCTCheckbox);
-        } else {
-            sortByNameCheckBox = new JCheckBoxMenuItem("Sort By Name", false);
-            sortByNameCheckBox.addActionListener(sortData);
-            optionsMenu.add(sortByNameCheckBox);
-        }
-
-        descendingOrderCheckBox = new JCheckBoxMenuItem("Descending Order", true);
+        descendingOrderCheckBox = new JCheckBoxMenuItem("Descending Order", dataSorter.getDescendingOrder());
         descendingOrderCheckBox.addActionListener(sortData);
         optionsMenu.add(descendingOrderCheckBox);
 
-        showValuesAsPercent = new JCheckBoxMenuItem("Show Values as Percent", ParaProf.preferences.getShowValuesAsPercent());
+        showValuesAsPercent = new JCheckBoxMenuItem("Show Values as Percent", defaultPercentValue);
         showValuesAsPercent.addActionListener(sortData);
         optionsMenu.add(showValuesAsPercent);
 
         unitsSubMenu = ParaProfUtils.createUnitsMenu(this, units, true);
         optionsMenu.add(unitsSubMenu);
 
-        //Set the value type options.
-        subMenu = new JMenu("Select Metric...");
-        group = new ButtonGroup();
+        optionsMenu.add(ParaProfUtils.createMetricSelectionMenu(ppTrial, "Select Metric...", false, function != null, dataSorter,
+                this, true));
+        optionsMenu.add(ParaProfUtils.createMetricSelectionMenu(ppTrial, "Sort by...", true, function != null, dataSorter, this,
+                true));
 
-        subMenu.add(createMetricMenu(ValueType.EXCLUSIVE, dataSorter.getValueType() == ValueType.EXCLUSIVE
-                || dataSorter.getValueType() == ValueType.EXCLUSIVE_PERCENT, group));
-        subMenu.add(createMetricMenu(ValueType.INCLUSIVE, dataSorter.getValueType() == ValueType.INCLUSIVE
-                || dataSorter.getValueType() == ValueType.INCLUSIVE_PERCENT, group));
-        subMenu.add(createMetricMenu(ValueType.INCLUSIVE_PER_CALL, dataSorter.getValueType() == ValueType.INCLUSIVE_PER_CALL,
-                group));
-        subMenu.add(createMetricMenu(ValueType.EXCLUSIVE_PER_CALL, dataSorter.getValueType() == ValueType.EXCLUSIVE_PER_CALL,
-                group));
-
-        button = new JRadioButtonMenuItem("Number of Calls", dataSorter.getValueType() == ValueType.NUMCALLS);
-        button.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent evt) {
-                dataSorter.setValueType(ValueType.NUMCALLS);
-                sortLocalData();
-                panel.repaint();
-            }
-        });
-        group.add(button);
-        subMenu.add(button);
-
-        button = new JRadioButtonMenuItem("Number of Child Calls", dataSorter.getValueType() == ValueType.NUMSUBR);
-        button.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent evt) {
-                dataSorter.setValueType(ValueType.NUMSUBR);
-                sortLocalData();
-                panel.repaint();
-            }
-        });
-        group.add(button);
-        subMenu.add(button);
-
-        optionsMenu.add(subMenu);
         optionsMenu.addMenuListener(this);
 
         //Now, add all the menus to the main menu.
@@ -432,10 +362,11 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
 
                     String metricName = ppTrial.getMetricName(dataSorter.getSelectedMetricID());
                     metricName = metricName.toUpperCase();
-                    if (dataSorter.isTimeMetric())
+                    if (dataSorter.isTimeMetric()) {
                         unitsSubMenu.setEnabled(true);
-                    else
+                    } else {
                         unitsSubMenu.setEnabled(false);
+                    }
                 }
             } else {
                 showValuesAsPercent.setEnabled(false);
@@ -454,11 +385,9 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
         }
     }
 
-    public void menuDeselected(MenuEvent evt) {
-    }
+    public void menuDeselected(MenuEvent evt) {}
 
-    public void menuCanceled(MenuEvent evt) {
-    }
+    public void menuCanceled(MenuEvent evt) {}
 
     public void update(Observable o, Object arg) {
         String tmpString = (String) arg;
@@ -481,33 +410,33 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
 
     public void help(boolean display) {
         //Show the ParaProf help window.
-        ParaProf.helpWindow.clearText();
+        ParaProf.getHelpWindow().clearText();
         if (display) {
-            ParaProf.helpWindow.show();
+            ParaProf.getHelpWindow().setVisible(true);
         }
 
         if (function != null) {
-            ParaProf.helpWindow.writeText("This is the function data window for:");
-            ParaProf.helpWindow.writeText(ParaProfUtils.getFunctionName(function));
-            ParaProf.helpWindow.writeText("");
-            ParaProf.helpWindow.writeText("This window shows you this function's statistics across all the threads.");
-            ParaProf.helpWindow.writeText("");
-            ParaProf.helpWindow.writeText("Use the options menu to select different ways of displaying the data.");
-            ParaProf.helpWindow.writeText("");
-            ParaProf.helpWindow.writeText("Right click anywhere within this window to bring up a popup");
-            ParaProf.helpWindow.writeText("menu. In this menu you can change or reset the default color");
-            ParaProf.helpWindow.writeText("for this function.");
+            ParaProf.getHelpWindow().writeText("This is the function data window for:");
+            ParaProf.getHelpWindow().writeText(ParaProfUtils.getDisplayName(function));
+            ParaProf.getHelpWindow().writeText("");
+            ParaProf.getHelpWindow().writeText("This window shows you this function's statistics across all the threads.");
+            ParaProf.getHelpWindow().writeText("");
+            ParaProf.getHelpWindow().writeText("Use the options menu to select different ways of displaying the data.");
+            ParaProf.getHelpWindow().writeText("");
+            ParaProf.getHelpWindow().writeText("Right click anywhere within this window to bring up a popup");
+            ParaProf.getHelpWindow().writeText("menu. In this menu you can change or reset the default color");
+            ParaProf.getHelpWindow().writeText("for this function.");
         } else {
-            ParaProf.helpWindow.writeText("This is the thread data window");
-            ParaProf.helpWindow.writeText("");
-            ParaProf.helpWindow.writeText("This window shows you the values for all functions on this thread.");
-            ParaProf.helpWindow.writeText("");
-            ParaProf.helpWindow.writeText("Use the options menu to select different ways of displaying the data.");
-            ParaProf.helpWindow.writeText("");
-            ParaProf.helpWindow.writeText("Right click on any function within this window to bring up a popup");
-            ParaProf.helpWindow.writeText("menu. In this menu you can change or reset the default color");
-            ParaProf.helpWindow.writeText("for the function, or to show more details about the function.");
-            ParaProf.helpWindow.writeText("You can also left click any function to highlight it in the system.");
+            ParaProf.getHelpWindow().writeText("This is the thread data window");
+            ParaProf.getHelpWindow().writeText("");
+            ParaProf.getHelpWindow().writeText("This window shows you the values for all functions on this thread.");
+            ParaProf.getHelpWindow().writeText("");
+            ParaProf.getHelpWindow().writeText("Use the options menu to select different ways of displaying the data.");
+            ParaProf.getHelpWindow().writeText("");
+            ParaProf.getHelpWindow().writeText("Right click on any function within this window to bring up a popup");
+            ParaProf.getHelpWindow().writeText("menu. In this menu you can change or reset the default color");
+            ParaProf.getHelpWindow().writeText("for the function, or to show more details about the function.");
+            ParaProf.getHelpWindow().writeText("You can also left click any function to highlight it in the system.");
         }
     }
 
@@ -518,20 +447,20 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
     public void sortLocalData() {
         dataSorter.setDescendingOrder(descendingOrderCheckBox.isSelected());
 
-        if (function != null) { // function
-            if (sortByNCTCheckbox.isSelected()) {
-                dataSorter.setSortType(SortType.NCT);
-            } else {
-                dataSorter.setSortType(SortType.VALUE);
-            }
-
-        } else { // thread
-            if (sortByNameCheckBox.isSelected()) {
-                dataSorter.setSortType(SortType.NAME);
-            } else {
-                dataSorter.setSortType(SortType.VALUE);
-            }
-        }
+        //        if (function != null) { // function
+        //            if (sortByNCTCheckbox.isSelected()) {
+        //                dataSorter.setSortType(SortType.NCT);
+        //            } else {
+        //                dataSorter.setSortType(SortType.VALUE);
+        //            }
+        //
+        //        } else { // thread
+        //            if (sortByNameCheckBox.isSelected()) {
+        //                dataSorter.setSortType(SortType.NAME);
+        //            } else {
+        //                dataSorter.setSortType(SortType.VALUE);
+        //            }
+        //        }
 
         if (showValuesAsPercent.isSelected()) {
             if (dataSorter.getValueType() == ValueType.EXCLUSIVE) {
@@ -589,9 +518,10 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
             jTextArea.setFont(ParaProf.preferencesWindow.getFont());
             jTextArea.append(this.getHeaderString());
             jTextArea.addKeyListener(this);
-            jTextArea.setMargin(new Insets(3,3,3,3));
+            jTextArea.setMargin(new Insets(3, 3, 3, 3));
+
             if (comparisonChart) {
-                
+                jTextArea.setSize(new Dimension(250, 200));
                 JPanel legendPanel = new LegendPanel(((ComparisonBarChartModel) model).getLegendModel());
                 JPanel holder = new JPanel();
                 holder.setLayout(new GridBagLayout());
@@ -600,12 +530,12 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
                 gbc.anchor = GridBagConstraints.WEST;
                 gbc.weightx = 0;
                 gbc.weighty = 1;
-                ParaProfUtils.addCompItem(holder, jTextArea, gbc, 0,0,1,1);
+                ParaProfUtils.addCompItem(holder, jTextArea, gbc, 0, 0, 1, 1);
                 gbc.weightx = 1;
                 gbc.weighty = 1;
-                gbc.anchor = GridBagConstraints.WEST;
-                ParaProfUtils.addCompItem(holder, legendPanel, gbc, 1,0,1,1);
-                
+                gbc.anchor = GridBagConstraints.EAST;
+                ParaProfUtils.addCompItem(holder, legendPanel, gbc, 1, 0, 1, 1);
+
                 panel.setColumnHeaderView(holder);
             } else {
                 panel.setColumnHeaderView(jTextArea);
@@ -734,25 +664,29 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
     public void closeThisWindow() {
         try {
             setVisible(false);
-            
+
             if (comparisonChart) {
                 ParaProf.theComparisonWindow = null;
-                List trialList = ((ComparisonBarChartModel)model).getPpTrials();
-                for (Iterator it=trialList.iterator(); it.hasNext();) {
-                    ParaProfTrial trial = (ParaProfTrial)it.next();
+                List trialList = ((ComparisonBarChartModel) model).getPpTrials();
+                for (Iterator it = trialList.iterator(); it.hasNext();) {
+                    ParaProfTrial trial = (ParaProfTrial) it.next();
                     trial.deleteObserver(this);
                 }
             } else {
                 ppTrial.deleteObserver(this);
             }
             ParaProf.decrementNumWindows();
-            
+
         } catch (Exception e) {
             // do nothing
         }
         dispose();
     }
 
+    public int getUnits() {
+        return units;
+    }
+
     public void setUnits(int units) {
         this.units = units;
         this.setHeader();
@@ -768,8 +702,8 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
         return ppTrial;
     }
 
-    public Thread getPhaseThread() {
-        return phaseThread;
+    public Thread getThread() {
+        return ppThread.getThread();
     }
 
     public void keyPressed(KeyEvent e) {
@@ -778,14 +712,31 @@ public class FunctionBarChartWindow extends JFrame implements KeyListener, Searc
         }
     }
 
-    public void keyReleased(KeyEvent e) {
-    }
+    public void keyReleased(KeyEvent e) {}
 
-    public void keyTyped(KeyEvent e) {
-    }
+    public void keyTyped(KeyEvent e) {}
 
     public Function getPhase() {
         return phase;
     }
 
+    public Function getFunction() {
+        return function;
+    }
+
+    public void setDescendingOrder(boolean order) {
+        descendingOrderCheckBox.setSelected(order);
+        sortLocalData();
+        panel.repaint();
+    }
+
+    public boolean getDescendingOrder() {
+        return descendingOrderCheckBox.isSelected();
+    }
+
+    public void resort() {
+        sortLocalData();
+        panel.repaint();
+    }
+
 }
\ No newline at end of file
