@@ -37,7 +37,9 @@ public class HelpWindow extends JFrame implements ActionListener, Observer {
 
         //Set the preferend initial size for this window.
         setSize(new java.awt.Dimension(windowWidth, windowHeight));
-        setTitle("ParaProf Help Window");
+        setTitle("TAU: ParaProf: Help Window");
+        ParaProfUtils.setFrameIcon(this);
+
 
         JMenuBar mainMenu = new JMenuBar();
 
@@ -76,7 +78,7 @@ public class HelpWindow extends JFrame implements ActionListener, Observer {
         helpJTextArea = new JTextArea();
         helpJTextArea.setLineWrap(true);
         helpJTextArea.setWrapStyleWord(true);
-        helpJTextArea.setMargin(new Insets(3,3,3,3));
+        helpJTextArea.setMargin(new Insets(3, 3, 3, 3));
         helpJTextArea.setSize(new java.awt.Dimension(windowWidth, windowHeight));
         helpJTextAreaDocument = helpJTextArea.getDocument();
 
