@@ -20,14 +20,13 @@ import org.jfree.chart.axis.NumberAxis;
 import org.jfree.chart.axis.NumberTickUnit;
 import org.jfree.chart.labels.XYToolTipGenerator;
 import org.jfree.chart.plot.PlotOrientation;
-import org.jfree.chart.renderer.xy.ClusteredXYBarRenderer;
 import org.jfree.chart.renderer.xy.XYBarRenderer;
 import org.jfree.chart.renderer.xy.XYItemRenderer;
 import org.jfree.data.statistics.HistogramDataset;
 import org.jfree.data.xy.XYDataset;
 
+import edu.uoregon.tau.common.ImageExport;
 import edu.uoregon.tau.paraprof.enums.ValueType;
-import edu.uoregon.tau.paraprof.interfaces.ImageExport;
 import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
 import edu.uoregon.tau.paraprof.interfaces.UnitListener;
 import edu.uoregon.tau.perfdmf.Function;
@@ -37,9 +36,9 @@ import edu.uoregon.tau.perfdmf.UtilFncs;
  * HistogramWindow
  * This is the histogram window
  *  
- * <P>CVS $Id: HistogramWindow.java,v 1.2 2005/10/14 18:08:09 amorris Exp $</P>
+ * <P>CVS $Id: HistogramWindow.java,v 1.5 2006/11/08 23:17:58 amorris Exp $</P>
  * @author  Robert Bell, Alan Morris
- * @version $Revision: 1.2 $
+ * @version $Revision: 1.5 $
  * @see     HistogramWindowPanel
  */
 public class HistogramWindow extends JFrame implements ActionListener, MenuListener, Observer, ChangeListener, ParaProfWindow,
@@ -70,7 +69,8 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
         this.dataSorter = new DataSorter(ppTrial);
         this.function = function;
 
-        setTitle("Histogram: " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+        setTitle("TAU: ParaProf: Histogram: " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+        ParaProfUtils.setFrameIcon(this);
         setSize(ParaProfUtils.checkSize(new java.awt.Dimension(670, 630)));
         setLocation(WindowPlacer.getNewLocation(this, invoker));
 
@@ -82,7 +82,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
         });
 
         //Set the help window text if required.
-        if (ParaProf.helpWindow.isVisible()) {
+        if (ParaProf.getHelpWindow().isVisible()) {
             this.help(false);
         }
 
@@ -303,15 +303,15 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
     }
 
     public void help(boolean display) {
-        ParaProf.helpWindow.clearText();
+        ParaProf.getHelpWindow().clearText();
         if (display)
-            ParaProf.helpWindow.show();
-        ParaProf.helpWindow.writeText("This is the histogram window");
-        ParaProf.helpWindow.writeText("");
-        ParaProf.helpWindow.writeText("This window shows you a histogram of all of the values for this function.");
-        ParaProf.helpWindow.writeText("");
-        ParaProf.helpWindow.writeText("Use the options menu to select different types of data to display.");
-        ParaProf.helpWindow.writeText("");
+            ParaProf.getHelpWindow().show();
+        ParaProf.getHelpWindow().writeText("This is the histogram window");
+        ParaProf.getHelpWindow().writeText("");
+        ParaProf.getHelpWindow().writeText("This window shows you a histogram of all of the values for this function.");
+        ParaProf.getHelpWindow().writeText("");
+        ParaProf.getHelpWindow().writeText("Use the options menu to select different types of data to display.");
+        ParaProf.getHelpWindow().writeText("");
     }
 
     private void sortLocalData() {
@@ -341,10 +341,10 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
         } else {
             if (dataSorter.getValueType() == ValueType.NUMCALLS || dataSorter.getValueType() == ValueType.NUMSUBR) {
                 return "Metric Name: " + (ppTrial.getMetricName(ppTrial.getDefaultMetricID())) + "\n" + "Name: "
-                        + ParaProfUtils.getFunctionName(function) + "\n" + "Value Type: " + dataSorter.getValueType() + "\n";
+                        + ParaProfUtils.getDisplayName(function) + "\n" + "Value Type: " + dataSorter.getValueType() + "\n";
             } else {
                 return "Metric Name: " + (ppTrial.getMetricName(ppTrial.getDefaultMetricID())) + "\n" + "Name: "
-                        + ParaProfUtils.getFunctionName(function) + "\n" + "Value Type: " + dataSorter.getValueType() + "\n"
+                        + ParaProfUtils.getDisplayName(function) + "\n" + "Value Type: " + dataSorter.getValueType() + "\n"
                         + "Units: " + UtilFncs.getUnitsString(units, ppTrial.isTimeMetric(), ppTrial.isDerivedMetric()) + "\n";
             }
         }
