@@ -11,9 +11,9 @@ import java.awt.*;
  * This provides the ledger window classes a uniform interface to dealing with these objects.
  * It also holds draw coordinates for mouse events.
  * 
- * <P>CVS $Id: LedgerDataElement.java,v 1.2 2005/11/05 01:36:23 amorris Exp $</P>
+ * <P>CVS $Id: LedgerDataElement.java,v 1.4 2007/01/04 01:55:31 amorris Exp $</P>
  * @author	Alan Morris
- * @version	$Revision: 1.2 $
+ * @version	$Revision: 1.4 $
  * @see		LedgerWindow
  * @see		LedgerWindowPanel
  */
@@ -49,7 +49,7 @@ public class LedgerDataElement {
     
     public String getName() {
         if (elementType == FUNCTION) {
-            return ParaProfUtils.getFunctionName(function);
+            return ParaProfUtils.getDisplayName(function);
         } else if (elementType == GROUP) {
             return group.getName();
         } else if (elementType == USEREVENT) {
@@ -59,13 +59,25 @@ public class LedgerDataElement {
     }
     
     
-    public boolean isHighlighted(ParaProfTrial cc) {
+    public boolean isShown(ParaProfTrial ppTrial) {
         if (elementType == FUNCTION) {
-            return (cc.getHighlightedFunction() == function);
+            return (ppTrial.displayFunction(function));
         } else if (elementType == GROUP) {
-            return (cc.getHighlightedGroup() == group);
+            return true;
         } else if (elementType == USEREVENT) {
-            return (cc.getHighlightedUserEvent() == userEvent);
+            return true;
+        }
+        return true;
+    }
+    
+    
+    public boolean isHighlighted(ParaProfTrial ppTrial) {
+        if (elementType == FUNCTION) {
+            return (ppTrial.getHighlightedFunction() == function);
+        } else if (elementType == GROUP) {
+            return (ppTrial.getHighlightedGroup() == group);
+        } else if (elementType == USEREVENT) {
+            return (ppTrial.getHighlightedUserEvent() == userEvent);
         }
         return false;
     }
