@@ -15,15 +15,18 @@
 package edu.uoregon.tau.paraprof;
 
 import java.awt.EventQueue;
-import java.io.File;
+import java.io.*;
 import java.util.*;
 
 import javax.swing.tree.DefaultMutableTreeNode;
 import javax.swing.tree.TreePath;
 
+import edu.uoregon.tau.paraprof.script.ParaProfScript;
+import edu.uoregon.tau.paraprof.script.ParaProfTrialScript;
 import edu.uoregon.tau.paraprof.util.FileMonitor;
 import edu.uoregon.tau.paraprof.util.FileMonitorListener;
 import edu.uoregon.tau.perfdmf.*;
+import edu.uoregon.tau.perfdmf.Thread;
 
 public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObject {
 
@@ -48,13 +51,18 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     private int defaultMetricID = 0;
 
     private Group selectedGroup;
-    private int groupFilter = 0;
+    private Group groupInclude;
+    private Group groupExclude;
 
     private Trial trial;
 
+    private boolean functionMask[];
+
     private boolean monitored;
     //private Timer monitorTimer;
 
+    private List obs = new ArrayList();
+
     private FileMonitorListener fileMonitorListener;
 
     public ParaProfTrial() {
@@ -69,6 +77,14 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         this.trial = new Trial(trial);
     }
 
+    public Iterator getFunctions() {
+        return getDataSource().getFunctions();
+    }
+
+    public Thread getMeanThread() {
+        return getDataSource().getMeanData();
+    }
+
     public Trial getTrial() {
         return trial;
     }
@@ -171,13 +187,15 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     //Used in many ParaProf windows for the title of the window.
     public String getTrialIdentifier(boolean reverse) {
         if (path != null) {
-            if (reverse)
+            if (reverse) {
                 return pathReverse;
-            else
+            } else {
                 return path;
-        } else
+            }
+        } else {
             return "Application " + trial.getApplicationID() + ", Experiment " + trial.getExperimentID() + ", Trial "
                     + trial.getID() + ".";
+        }
     }
 
     //Sets both the path and the path reverse.
@@ -202,14 +220,10 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         }
     }
 
-    public void clearDefaultMutableTreeNodes() {
+    public void clearDefaultMutableTreeNode() {
         this.setDMTN(null);
     }
 
-    //####################################
-    //Functions that control the obtaining and the opening
-    //and closing of the static main window for this trial.
-    //####################################
     public GlobalDataWindow getFullDataWindow() {
         return fullDataWindow;
     }
@@ -217,7 +231,6 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     public void showMainWindow() {
         if (fullDataWindow == null) {
             fullDataWindow = new GlobalDataWindow(this, trial.getDataSource().getTopLevelPhase());
-            ParaProf.incrementNumWindows();
             fullDataWindow.setVisible(true);
 
         } else {
@@ -226,20 +239,6 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         }
     }
 
-    public void closeStaticMainWindow() {
-        if (fullDataWindow != null) {
-            this.deleteObserver(fullDataWindow);
-            fullDataWindow.setVisible(false);
-        }
-    }
-
-    //public SystemEvents getSystemEvents() {
-    //    return systemEvents;
-    //  }
-
-    //####################################
-    //Interface for ParaProfMetrics.
-    //####################################
     public void setDefaultMetricID(int selectedMetricID) {
         this.defaultMetricID = selectedMetricID;
     }
@@ -251,10 +250,11 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     public boolean isTimeMetric() {
         String metricName = this.getMetricName(this.getDefaultMetricID());
         metricName = metricName.toUpperCase();
-        if (metricName.indexOf("TIME") == -1)
+        if (metricName.indexOf("TIME") == -1) {
             return false;
-        else
+        } else {
             return true;
+        }
     }
 
     //    public boolean isTimeMetric(int metricID) {
@@ -280,6 +280,15 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         return trial.getDataSource().getMetrics();
     }
 
+    public int getMetricID(String name) {
+        Metric m = getDataSource().getMetric(name);
+        if (m == null) {
+            return -1;
+        } else {
+            return m.getID();
+        }
+    }
+
     public int getNumberOfMetrics() {
         return trial.getDataSource().getNumberOfMetrics();
     }
@@ -298,18 +307,6 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         return metric;
     }
 
-    //####################################
-    //End - Interface for ParaProfMetrics.
-    //####################################
-
-    //####################################
-    //Pass-though methods to the data session for this instance.
-    //####################################
-
-    //    public edu.uoregon.tau.dms.dss.Thread getThread(int nodeID, int contextID, int threadID) {
-    //        return dataSource.getThread(nodeID, contextID, threadID);
-    //    }
-
     public boolean groupNamesPresent() {
         return trial.getDataSource().getGroupNamesPresent();
     }
@@ -344,52 +341,131 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         return displayedFunctions;
     }
 
-    public boolean displayFunction(Function func) {
-        switch (groupFilter) {
-        case 0:
-            //No specific group selection is required.
-            return true;
-        case 1:
-            //Show this group only.
-            if (func.isGroupMember(this.selectedGroup))
-                return true;
-            else
-                return false;
-        case 2:
-            //Show all groups except this one.
-            if (func.isGroupMember(this.selectedGroup))
-                return false;
-            else
-                return true;
-        default:
-            //Default case behaves as case 0.
-            return true;
+    public boolean displayFunction(Function function) {
+        return functionMask[function.getID()];
+    }
+
+    public void showGroup(Group group) {
+        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = (Function) it.next();
+            if (function.isGroupMember(group)) {
+                functionMask[function.getID()] = true;
+            }
         }
+        groupInclude = null;
+        groupExclude = null;
+        updateRegisteredObjects("dataEvent");
+    }
+
+    public void hideGroup(Group group) {
+        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = (Function) it.next();
+            if (function.isGroupMember(group)) {
+                functionMask[function.getID()] = false;
+            }
+        }
+        groupInclude = null;
+        groupExclude = null;
+        updateRegisteredObjects("dataEvent");
+    }
+
+    public void showGroupOnly(Group group) {
+        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = (Function) it.next();
+            if (function.isGroupMember(group)) {
+                functionMask[function.getID()] = true;
+            } else {
+                functionMask[function.getID()] = false;
+            }
+        }
+        groupInclude = group;
+        groupExclude = null;
+        updateRegisteredObjects("dataEvent");
+    }
+
+    public void showAllExcept(Group group) {
+        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = (Function) it.next();
+            if (function.isGroupMember(group)) {
+                functionMask[function.getID()] = false;
+            } else {
+                functionMask[function.getID()] = true;
+            }
+        }
+        groupInclude = null;
+        groupExclude = group;
+        updateRegisteredObjects("dataEvent");
+    }
+
+    public void setFunctionMask(boolean mask[]) {
+        this.functionMask = mask;
+        groupInclude = null;
+        groupExclude = null;
+        updateRegisteredObjects("dataEvent");
+    }
+
+    public void showFunction(Function function) {
+        functionMask[function.getID()] = true;
+        updateRegisteredObjects("dataEvent");
+    }
+
+    public void hideFunction(Function function) {
+        functionMask[function.getID()] = false;
+        updateRegisteredObjects("dataEvent");
+    }
+
+    public void hideMatching(String string, boolean caseSensitive, boolean allExcept) {
+        maskMatching(string, false, caseSensitive, allExcept);
+    }
+
+    public void showMatching(String string, boolean caseSensitive, boolean allExcept) {
+        maskMatching(string, true, caseSensitive, allExcept);
+    }
+
+    public void maskMatching(String string, boolean value, boolean caseSensitive, boolean allExcept) {
+        if (caseSensitive) {
+            string = string.toUpperCase();
+        }
+
+        if (allExcept) {
+            value = !value;
+            for (int i = 0; i < functionMask.length; i++) {
+                functionMask[i] = !value;
+            }
+        }
+
+        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = (Function) it.next();
+            String name = function.getName();
+            if (caseSensitive) {
+                name = name.toUpperCase();
+            }
+
+            if (name.indexOf(string) != -1) {
+                functionMask[function.getID()] = value;
+            }
+        }
+        updateRegisteredObjects("dataEvent");
     }
 
     public void setSelectedGroup(Group group) {
         this.selectedGroup = group;
     }
 
+    public void closeTrialWindows() {
+        updateRegisteredObjects("subWindowCloseEvent");
+    }
+
     public Group getSelectedGroup() {
         return selectedGroup;
     }
 
-    public void setGroupFilter(int groupFilter) {
-        this.groupFilter = groupFilter;
-    }
-
-    public int getGroupFilter() {
-        return groupFilter;
-    }
-
-    //####################################
-    //end - Pass-though methods to the data session for this instance.
-    //####################################
-
     public void finishLoad() {
 
-        // The dataSource has accumulated edu.uoregon.tau.dms.dss.Metrics.
+        // assign the metadata from the datasource to the trial
+        trial.setMetaData(trial.getDataSource().getMetaData());
+        
+        // The dataSource has accumulated metrics.
         // Inside ParaProf, these need to be ParaProfMetrics.
 
         int numberOfMetrics = trial.getDataSource().getNumberOfMetrics();
@@ -414,7 +490,7 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
             }
         }
 
-        // Set the default metric to the first metric named "Time" (if it exists)
+        // Set the default metric to the first metric named "Time" (if it exists), higher priority than above
         for (int i = 0; i < numberOfMetrics; i++) {
             ParaProfMetric ppMetric = (ParaProfMetric) trial.getDataSource().getMetric(i);
             if (ppMetric.getName().equalsIgnoreCase("Time")) {
@@ -423,11 +499,34 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
             }
         }
 
+        // set the mask
+        functionMask = new boolean[getDataSource().getNumFunctions()];
+        for (int i = 0; i < functionMask.length; i++) {
+            functionMask[i] = true;
+        }
+
         // set the colors
         clrChooser.setColors(this, -1);
 
         //Set this trial's loading flag to false.
         this.setLoading(false);
+
+        Group derived = getGroup("TAU_CALLPATH_DERIVED");
+        if (derived != null) {
+            showAllExcept(derived);
+        }
+
+        // run any scripts
+        for (int i = 0; i < ParaProf.scripts.size(); i++) {
+            ParaProfScript pps = (ParaProfScript) ParaProf.scripts.get(i);
+            if (pps instanceof ParaProfTrialScript) {
+                try {
+                    ((ParaProfTrialScript) pps).trialLoaded(this);
+                } catch (Exception e) {
+                    new ParaProfErrorDialog("Exception while executing script: ", e);
+                }
+            }
+        }
     }
 
     public DatabaseAPI getDatabaseAPI() {
@@ -448,10 +547,11 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     }
 
     public void toggleHighlightedFunction(Function function) {
-        if (highlightedFunction == function)
+        if (highlightedFunction == function) {
             highlightedFunction = null;
-        else
+        } else {
             highlightedFunction = function;
+        }
         updateRegisteredObjects("colorEvent");
     }
 
@@ -473,8 +573,6 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         updateRegisteredObjects("colorEvent");
     }
 
-    //    private boolean uploading;
-
     public void setHighlightedUserEvent(UserEvent userEvent) {
         this.highlightedUserEvent = userEvent;
         updateRegisteredObjects("colorEvent");
@@ -546,28 +644,17 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
 
             fileMonitor.addListener(fileMonitorListener);
 
-            //            monitorTimer = new Timer();
-            //            monitorTimer.scheduleAtFixedRate(new TimerTask() {
-            //
-            //                public void run() {
-            //                    try {
-            //                        //                        System.err.println("Monitoring Profiles!");
-            //                        getDataSource().reloadData();
-            //
-            //                        EventQueue.invokeLater(new Runnable() {
-            //                            public void run() {
-            //                                updateRegisteredObjects("dataEvent");
-            //                            }
-            //                        });
-            //
-            //                    } catch (Exception e) {
-            //                        // eat it
-            //                    }
-            //                }
-            //            }, 5000, 5000);
         }
     }
 
+    public Function getFunction(String function) {
+        return getDataSource().getFunction(function);
+    }
+
+    public Thread getThread(int n, int c, int t) {
+        return getDataSource().getThread(n, c, t);
+    }
+
     public void updateRegisteredObjects(String inString) {
         //Set this object as changed.
         this.setChanged();
@@ -576,4 +663,30 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         this.notifyObservers(inString);
     }
 
+    public void addObserver(Observer o) {
+        super.addObserver(o);
+        obs.add(o);
+    }
+
+    public void deleteObserver(Observer o) {
+        super.deleteObserver(o);
+        obs.remove(o);
+    }
+
+    public List getObservers() {
+        return obs;
+    }
+
+    public Group getGroup(String name) {
+        return getDataSource().getGroup(name);
+    }
+
+    public Group getGroupInclude() {
+        return groupInclude;
+    }
+
+    public Group getGroupExclude() {
+        return groupExclude;
+    }
+
 }
\ No newline at end of file
