@@ -38,6 +38,7 @@ public class Preferences implements Serializable {
     private boolean generateIntermediateCallPathData = false;
     
     private ArrayList sourceLocations;
+    private boolean showSourceLocation = true;
     
     static final long serialVersionUID = 183442743456314793L;
 
@@ -215,4 +216,12 @@ public class Preferences implements Serializable {
 		this.sourceLocations = sourceLocations;
 	}
 
+    public boolean getShowSourceLocation() {
+        return showSourceLocation;
+    }
+
+    public void setShowSourceLocation(boolean showSourceLocation) {
+        this.showSourceLocation = showSourceLocation;
+    }
+
 }
\ No newline at end of file
