@@ -18,15 +18,14 @@ import javax.swing.JComponent;
 import edu.uoregon.tau.paraprof.interfaces.ScrollBarController;
 import edu.uoregon.tau.paraprof.interfaces.Searchable;
 
-
 /**
  * Searches text for ParaProf windows
  *    
  * TODO : ...
  *
- * <P>CVS $Id: Searcher.java,v 1.3 2005/10/14 18:59:32 amorris Exp $</P>
+ * <P>CVS $Id: Searcher.java,v 1.6 2007/01/04 01:55:32 amorris Exp $</P>
  * @author  Alan Morris
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.6 $
  */
 public class Searcher implements Searchable, MouseListener, MouseMotionListener, ClipboardOwner {
 
@@ -38,9 +37,9 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
     private boolean searchMatchCase;
     private boolean searchUp;
 
-    private int lineHeight;
+    private int lineHeight = 1; // initialize to 1 to eliminate the possiblility of divide by zero
     private int maxDescent;
-    
+
     private JComponent panel;
     private ScrollBarController scrollBarController;
 
@@ -50,12 +49,11 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
     private Graphics2D g2d;
     private int xOffset;
     private int topMargin;
-    
-    
+
     // for selection
     private String selectionString = "";
     private boolean selectionReversed;
-    private int selectionStartLine=-1, selectionEndLine=-1;
+    private int selectionStartLine = -1, selectionEndLine = -1;
     private int selectionStartX, selectionStartY;
     private int selectionEndX, selectionEndY;
 
@@ -218,6 +216,9 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
     }
 
     private void checkSearchStringVisibility() {
+        if (g2d == null) {
+            return;
+        }
         String localSearchString = searchString;
 
         // now determine if it is visible vertically
@@ -256,6 +257,9 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
         String text = (String) searchLines.get(line);
         String originalText = (String) searchLines.get(line);
 
+        if (text.length() < 1) {
+            return;
+        }
         TextLayout textLayout = new TextLayout(text, g2D.getFont(), g2D.getFontRenderContext());
 
         String localSearchString = searchString;
@@ -286,8 +290,9 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
             // the current incremental search line
 
             if (text.indexOf(localSearchString, searchColumn) != -1 && localSearchString.length() > 0) {
-                Shape base = textLayout.getLogicalHighlightShape(text.indexOf(localSearchString, searchColumn),
-                        text.indexOf(localSearchString, searchColumn) + localSearchString.length());
+                Shape base = textLayout.getLogicalHighlightShape(text.indexOf(localSearchString, searchColumn), text.indexOf(
+                        localSearchString, searchColumn)
+                        + localSearchString.length());
                 AffineTransform at = AffineTransform.getTranslateInstance(x, y);
                 Shape highlight = at.createTransformedShape(base);
                 g2D.setPaint(Searchable.searchColor);
@@ -340,8 +345,7 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
                     // the first line of a multi-line selection
                     TextHitInfo hit = textLayout.hitTestChar(localX - x, selectionStartY);
                     if (hit != null) {
-                        Shape base = textLayout.getLogicalHighlightShape(hit.getInsertionIndex(),
-                                textLayout.getCharacterCount());
+                        Shape base = textLayout.getLogicalHighlightShape(hit.getInsertionIndex(), textLayout.getCharacterCount());
                         AffineTransform at = AffineTransform.getTranslateInstance(x, y);
                         Shape highlight = at.createTransformedShape(base);
 
@@ -418,13 +422,17 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
 
     public void mousePressed(MouseEvent e) {
         selectionStartX = e.getX();
-        selectionStartY = e.getY()-topMargin;
-        selectionStartLine = (e.getY()-topMargin) / lineHeight;
+        selectionStartY = e.getY() - topMargin;
+        selectionStartLine = (e.getY() - topMargin) / lineHeight;
     }
 
     private void determineSelection() {
+        if (g2d == null) {
+            return;
+        }
+
         selectionString = "";
-        
+
         for (int line = selectionStartLine; line <= selectionEndLine; line++) {
             if (line >= searchLines.size()) {
                 break;
@@ -432,7 +440,7 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
             if (line < 0 || line >= searchLines.size()) {
                 return;
             }
-            
+
             String text = (String) searchLines.get(line);
 
             TextLayout textLayout = new TextLayout(text, g2d.getFont(), g2d.getFontRenderContext());
@@ -500,11 +508,8 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
     }
 
     public void mouseReleased(MouseEvent e) {
-        if (lineHeight == 0) {
-            return;
-        }
         selectionEndX = e.getX();
-        selectionEndY = e.getY()-topMargin;
+        selectionEndY = e.getY() - topMargin;
 
         if (selectionStartY < selectionEndY) {
             selectionStartLine = selectionStartY / lineHeight;
@@ -524,7 +529,7 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
 
     public void mouseDragged(MouseEvent e) {
         selectionEndX = e.getX();
-        selectionEndY = (e.getY()-topMargin) - maxDescent;
+        selectionEndY = (e.getY() - topMargin) - maxDescent;
 
         if (selectionStartY < selectionEndY) {
             selectionStartLine = selectionStartY / lineHeight;
@@ -565,7 +570,8 @@ public class Searcher implements Searchable, MouseListener, MouseMotionListener,
     }
 
     public void setLineHeight(int lineHeight) {
-        this.lineHeight = lineHeight;
+        // disallow less than one to eliminate divide by zero errors
+        this.lineHeight = Math.max(1, lineHeight);
     }
 
     public void setMaxDescent(int maxDescent) {
