@@ -6,10 +6,9 @@
   Description:  
 */
 
-package paraprof;
+package edu.uoregon.tau.paraprof;
 
 import java.util.*;
-import java.lang.*;
 
 public class SystemEvents extends Observable
 {
