@@ -6,13 +6,20 @@ import java.io.*;
 import java.math.BigDecimal;
 import java.sql.*;
 
+import javax.xml.parsers.DocumentBuilderFactory;
+import javax.xml.transform.*;
+import javax.xml.transform.dom.*;
+import javax.xml.transform.stream.*;
+import javax.xml.parsers.DocumentBuilder;
+import org.w3c.dom.*;
+
 /**
  * This class represents a data source.  After loading, data is availiable through the
  * public methods.
  *  
- * <P>CVS $Id: DataSource.java,v 1.13.2.1 2007/02/20 01:18:26 amorris Exp $</P>
+ * <P>CVS $Id: DataSource.java,v 1.18 2007/04/14 01:07:08 khuck Exp $</P>
  * @author  Robert Bell, Alan Morris
- * @version $Revision: 1.13.2.1 $
+ * @version $Revision: 1.18 $
  */
 public abstract class DataSource {
 
@@ -66,6 +73,9 @@ public abstract class DataSource {
     protected volatile boolean reloading;
 
     protected Map metaData;
+    private File metadataFile;
+    private Map masterMetaData = new TreeMap();
+    private StringBuffer metadataString = new StringBuffer();
 
     public DataSource() {
     // nothing
@@ -498,7 +508,7 @@ public abstract class DataSource {
     public void generateDerivedData() {
         //long time = System.currentTimeMillis();
 
-	// reset the list of all threads so that it will be recreated
+        // reset the list of all threads so that it will be recreated
         allThreads = null;
 
         if (CallPathUtilFuncs.checkCallPathsPresent(getFunctions())) {
@@ -845,8 +855,8 @@ public abstract class DataSource {
      * present. Adds do not have to be consecutive (ie., nodes can be added out of order).
      * The node created will have an id matching the given id.
      *
-     * @param	nodeID The id of the node to be added.
-     * @return	The Node that was added.
+     * @param    nodeID The id of the node to be added.
+     * @return    The Node that was added.
      */
     public Node addNode(int nodeID) {
         Object obj = nodes.get(new Integer(nodeID));
@@ -873,8 +883,8 @@ public abstract class DataSource {
     /**
      * Gets the node with the specified node id.  If the node is not found, the function returns null.
      *
-     * @param	nodeID The id of the node sought.
-     * @return	The node found (or null if it was not).
+     * @param    nodeID The id of the node sought.
+     * @return    The node found (or null if it was not).
      */
     public Node getNode(int nodeID) {
         return (Node) nodes.get(new Integer(nodeID));
@@ -883,7 +893,7 @@ public abstract class DataSource {
     /**
      * Returns the number of nodes in this NCT object.
      *
-     * @return	The number of nodes.
+     * @return    The number of nodes.
      */
     public int getNumberOfNodes() {
         return nodes.size();
@@ -892,7 +902,7 @@ public abstract class DataSource {
     /**
      * Returns the list of nodes in this object as an Iterator.
      *
-     * @return	An Iterator over node objects.
+     * @return    An Iterator over node objects.
      */
     public Iterator getNodes() {
         return nodes.values().iterator();
@@ -1112,53 +1122,211 @@ public abstract class DataSource {
         this.metaData = metaData;
     }
 
-    public void aggregateMetaData() {
+    public void buildXMLMetaData() {
+        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+        try {
+            // create the XML DOM document builder
+            DocumentBuilder builder = factory.newDocumentBuilder();
+            // create a new XML document
+            Document document = builder.newDocument();
 
-        metaData = new TreeMap();
-        
-        Thread node0 = (Thread) getAllThreads().get(0);
+            // create the root node.  Do it this way, because the level 1
+            // xerces DOM parser/write doesn't support namespaces. Grrr.
+            Element root = (Element) document.createElement("tau:metadata");
+            root.setAttribute("xmlns:tau", "http://www.cs.uoregon.edu/research/tau");
+            document.appendChild(root);
 
-        // must have at least one thread
-        if (node0 != null) {
+            Element master = null;
 
-            for (Iterator it = node0.getMetaData().keySet().iterator(); it.hasNext();) {
-                String name = (String) it.next();
-                String value = (String) node0.getMetaData().get(name);
-                metaData.put(name, value);
+            // create the common attribute node
+            if (metaData.size() > 0) {
+                master = (Element) document.createElement("tau:CommonProfileAttributes");
+                   root.appendChild(master);
+
+                // output the first thread of name / value pairs, like this:
+                // <attribute><name>xxx</name><value>yyy</value></attribute>
+                for (Iterator it2 = metaData.keySet().iterator(); it2.hasNext();) {
+                    String name = (String) it2.next();
+                    String value = (String) metaData.get(name);
+                    Element attribute = (Element) document.createElement("tau:attribute");
+                    master.appendChild(attribute);
+                    Element attrName = (Element) document.createElement("tau:name");
+                    attribute.appendChild(attrName);
+                    attrName.appendChild(document.createTextNode(name));
+                    Element attrValue = (Element) document.createElement("tau:value");
+                    attribute.appendChild(attrValue);
+                    attrValue.appendChild(document.createTextNode(value));
+                }
             }
 
+            // for all threads of execution, output the attributes
+            // that are different for one or more threads
             for (Iterator it = getAllThreads().iterator(); it.hasNext();) {
                 Thread thread = (Thread) it.next();
+                // output the first thread of name / value pairs, like this:
+                // <attribute><name>xxx</name><value>yyy</value></attribute>
+                Element delta = (Element) document.createElement("tau:ProfileAttributes");
+                // give the record attributes, so we know which thread of execution
+                // it belongs to
+                delta.setAttribute("node", Integer.toString(thread.getNodeID()));
+                delta.setAttribute("context", Integer.toString(thread.getContextID()));
+                delta.setAttribute("thread", Integer.toString(thread.getThreadID()));
+
+                boolean addit = false;
+
                 for (Iterator it2 = thread.getMetaData().keySet().iterator(); it2.hasNext();) {
                     String name = (String) it2.next();
                     String value = (String) thread.getMetaData().get(name);
-
-                    String trialValue = (String) metaData.get(name);
-                    if (trialValue == null || !value.equals(trialValue)) {
-                        metaData.remove(name);
+                    // if this name/value pair is not in the master, then 
+                    // append it to the tree.
+                    if (!metaData.containsKey(name)) {
+                        Element attribute = (Element) document.createElement("tau:attribute");
+                        delta.appendChild(attribute);
+                        Element attrName = (Element) document.createElement("tau:name");
+                        attribute.appendChild(attrName);
+                        attrName.appendChild(document.createTextNode(name));
+                        Element attrValue = (Element) document.createElement("tau:value");
+                        attribute.appendChild(attrValue);
+                        attrValue.appendChild(document.createTextNode(value));
+                        addit = true;
                     }
                 }
+
+                if (addit) {
+                    // don't add it to the tree, unless it has items that differ from
+                    // the master record
+                    root.appendChild(delta);
+                }
+
             }
 
-            for (Iterator it = getAllThreads().iterator(); it.hasNext();) {
-                Thread thread = (Thread) it.next();
-
-                for (Iterator it2 = metaData.keySet().iterator(); it2.hasNext();) {
-                    String name = (String) it2.next();
-                    thread.getMetaData().remove(name);
+            // if the user also specified an XML file on the command line
+            // with XML data, then merge that tree into our tree
+            if (this.metadataFile != null) {
+                Document oldDocument = builder.parse(metadataFile);
+                // get the root elements, so we can move it
+                Element oldRoot = oldDocument.getDocumentElement();
+                // here's the magic step!
+                org.w3c.dom.Node imported = document.importNode(oldRoot, true);
+                System.out.println(imported.getPrefix());
+                System.out.println(imported.getNodeName());
+                if (master != null 
+                    && imported.getNodeType() == org.w3c.dom.Node.ELEMENT_NODE 
+                    && imported.getNodeName().equals("tau:metadata")) {
+                    // extract it out, and add it to our tree!
+                    NodeList nodes = imported.getChildNodes();
+                    for (int i = 0 ; i < nodes.getLength() ; i++) {
+                        org.w3c.dom.Node cpa = nodes.item(i);
+                        // System.out.println("\t" + cpa.getNodeName());
+                        if (cpa.getNodeType() == org.w3c.dom.Node.ELEMENT_NODE 
+                            && cpa.getNodeName().equals("tau:CommonProfileAttributes")) {
+                            
+                            NodeList attrs = cpa.getChildNodes();
+                            // System.out.println("length: " + attrs.getLength());
+                            for (int j = 0 ; j < attrs.getLength() ; j++) {
+                                // System.out.println("\t\tj:" + j);
+                                org.w3c.dom.Node tmp = attrs.item(j);
+                                if (tmp.getNodeType() == org.w3c.dom.Node.ELEMENT_NODE 
+                                    && tmp.getNodeName().equals("tau:attribute")) {
+                                    // System.out.println("\t\tname:" + tmp.getNodeName());
+                                    master.appendChild(tmp);
+                                }
+                                // System.out.println("\t\tend j:" + j);
+                            }
+                            
+                            //root.appendChild(cpa);
+                        }
+                    }
+                } else {
+                    // add the root of the second document to our root
+                    root.appendChild(imported);
                 }
             }
 
-            // now add node0's different values
+            // normalize all whitespace in the file
+            document.getDocumentElement().normalize();
 
-//            for (Iterator it = node0.getMetaData().keySet().iterator(); it.hasNext();) {
-//                String name = (String) it.next();
-//                String value = (String) node0.getMetaData().get(name);
-//                if (metaData.get(name) == null) {
-//                    metaData.put(name + " (node 0)", value);
-//                }
-//            }
+            // Use a Transformer for output
+            TransformerFactory tFactory = TransformerFactory.newInstance();
+            Transformer transformer = tFactory.newTransformer();
+
+            // output the file to a string buffer.
+            DOMSource source = new DOMSource(document);
+            ByteArrayOutputStream stream = new ByteArrayOutputStream();
+            StreamResult result = new StreamResult(stream);
+            transformer.transform(source, result);
+            // don't output the XML if there isn't anything.
+            if (root.hasChildNodes()) {
+                metadataString.append(stream.toString());
+            }
+
+        } catch (Exception e) {
+            e.printStackTrace();
         }
+
     }
 
-}
+    public void aggregateMetaData() {
+
+        metaData = new TreeMap();
+        Thread node0 = (Thread) getAllThreads().get(0);
+
+        // must have at least one thread
+        if (node0 == null) {
+            return;
+        }
+
+        // First, add all name/value pairs from the first node (any node, really)
+        for (Iterator it = node0.getMetaData().keySet().iterator(); it.hasNext();) {
+            String name = (String) it.next();
+            String value = (String) node0.getMetaData().get(name);
+            metaData.put(name, value);
+        }
+
+        // Now iterate through all nodes and remove from the master set (metaData) any that differ
+        for (Iterator it = getAllThreads().iterator(); it.hasNext();) {
+            Thread thread = (Thread) it.next();
+            for (Iterator it2 = thread.getMetaData().keySet().iterator(); it2.hasNext();) {
+                String name = (String) it2.next();
+                String value = (String) thread.getMetaData().get(name);
+
+                String trialValue = (String) metaData.get(name);
+                if (trialValue == null || !value.equals(trialValue)) {
+                    metaData.remove(name);
+                }
+            }
+        }
+
+        // Now remove the normalized name/value pairs from the thread-specific structures
+        for (Iterator it = getAllThreads().iterator(); it.hasNext();) {
+            Thread thread = (Thread) it.next();
+            for (Iterator it2 = metaData.keySet().iterator(); it2.hasNext();) {
+                String name = (String) it2.next();
+                thread.getMetaData().remove(name);
+            }
+        }
+
+    }
+
+    /**
+     * If the user passes in a metadata file, parse it into the trial.
+     * 
+     * @param metadataFileName
+     * @throws IOException
+     */
+    public void setMetadataFile(String metadataFileName) throws IOException {
+        this.metadataFile = new File(metadataFileName);
+        if (!this.metadataFile.exists())
+            throw new FileNotFoundException("The file " + metadataFileName + " does not exist.");
+        if (!this.metadataFile.canRead())
+            throw new IOException("The file " + metadataFileName + " does not have read permission.");
+        if (!this.metadataFile.isFile())
+            throw new FileNotFoundException(metadataFileName + " is not a valid file.");
+        return;
+    }
+
+    public String getMetadataString() {
+        return metadataString.toString();
+    }
+
+}
\ No newline at end of file
