@@ -2,8 +2,12 @@
 package edu.uoregon.tau.perfdmf;
 
 
-public class DataSourceException extends Exception {
+public class DataSourceException extends RuntimeException {
 
+    private Exception exception; 
+    private String message;
+
+    
     public DataSourceException(String message) {
         this.message = message;
     }
@@ -20,7 +24,4 @@ public class DataSourceException extends Exception {
         return exception;
     }
     
-    Exception exception; 
-    
-    String message;
 }
