@@ -13,7 +13,6 @@ public class DynaprofDataSource extends DataSource {
 
     public DynaprofDataSource(File[] files) {
         super();
-        this.setMetrics(new Vector());
         this.files = files;
     }
 
@@ -197,10 +196,6 @@ public class DynaprofDataSource extends DataSource {
 
         this.generateDerivedData();
 
-        if (CallPathUtilFuncs.checkCallPathsPresent(getFunctions())) {
-            setCallPathDataPresent(true);
-        }
-
         time = (System.currentTimeMillis()) - time;
         //System.out.println("Done processing data!");
         //System.out.println("Time to process (in milliseconds): " + time);
