@@ -5,6 +5,7 @@ import java.sql.*;
 import java.util.*;
 import java.util.Date;
 
+import edu.uoregon.tau.common.Gzip;
 import edu.uoregon.tau.perfdmf.database.DB;
 import edu.uoregon.tau.perfdmf.database.DBConnector;
 
@@ -19,7 +20,7 @@ import edu.uoregon.tau.perfdmf.database.DBConnector;
  * number of threads per context and the metrics collected during the run.
  * 
  * <P>
- * CVS $Id: Trial.java,v 1.11 2007/02/13 21:56:02 amorris Exp $
+ * CVS $Id: Trial.java,v 1.18 2007/04/14 01:07:08 khuck Exp $
  * </P>
  * 
  * @author Kevin Huck, Robert Bell
@@ -35,7 +36,8 @@ import edu.uoregon.tau.perfdmf.database.DBConnector;
 public class Trial implements Serializable {
     private static String fieldNames[];
     private static int fieldTypes[];
-    private static final String XML_METADATA = new String("XML_METADATA");
+    public static final String XML_METADATA = new String("XML_METADATA");
+    public static final String XML_METADATA_GZ = new String("XML_METADATA_GZ");
 
     private int trialID;
     private int experimentID;
@@ -45,10 +47,8 @@ public class Trial implements Serializable {
     private String fields[];
 
     protected DataSource dataSource = null;
-    private File metadataFile = null;
-    private FileInputStream inStream = null;
 
-    private Map metaData = new TreeMap();
+    private Map metaData = null;
 
     public Trial() {
         if (Trial.fieldNames == null) {
@@ -441,7 +441,6 @@ public class Trial implements Serializable {
 
             Vector trials = new Vector();
 
-            //System.out.println(buf);
             ResultSet resultSet = db.executeQuery(buf.toString());
             while (resultSet.next() != false) {
                 Trial trial = new Trial();
@@ -453,7 +452,15 @@ public class Trial implements Serializable {
                 trial.setName(resultSet.getString(pos++));
 
                 for (int i = 0; i < Trial.fieldNames.length; i++) {
-                    trial.setField(i, resultSet.getString(pos++));
+					if (Trial.fieldNames[i].equalsIgnoreCase(XML_METADATA_GZ)) {
+						InputStream compressedStream = resultSet.getBinaryStream(pos++);
+						String tmp = Gzip.decompress(compressedStream);
+						//trial.setField(i, tmp);
+						if (tmp != null && tmp.length() > 0)
+							trial.setField(XML_METADATA, tmp);
+					} else {
+						trial.setField(i, resultSet.getString(pos++));
+					}
                 }
 
                 trials.addElement(trial);
@@ -485,9 +492,16 @@ public class Trial implements Serializable {
             // determine if we have a data meta-data item
             boolean haveDate = false;
             java.sql.Timestamp timestamp = null;
-            String dateString = (String) getMetaData().get("UTC Time");
+            String dateString = null;
+
+            if (getMetaData() != null) {
+                dateString = (String) getMetaData().get("UTC Time");
+            }
             if (dateString == null) {
-                dateString = (String) ((Thread)getDataSource().getAllThreads().get(0)).getMetaData().get("UTC Time");
+                if (getDataSource() != null && getDataSource().getAllThreads() != null
+                        && ((Thread) getDataSource().getAllThreads().get(0)).getMetaData() != null) {
+                    dateString = (String) ((Thread) getDataSource().getAllThreads().get(0)).getMetaData().get("UTC Time");
+                }
             }
             if (dateString != null) {
                 try {
@@ -501,6 +515,8 @@ public class Trial implements Serializable {
 
             // FIRST!  Check if the trial table has a metadata column
             checkForMetadataColumn(db);
+            // SECOND!  Check if the trial table has a zipped metadata column
+            checkForMetadataColumn2(db);
 
             // get the fields since this is an insert
             if (!itExists) {
@@ -516,6 +532,17 @@ public class Trial implements Serializable {
                 this.setField("threads_per_context", Integer.toString(1 + this.getDataSource().getMaxNCTNumbers()[2]));
             }
 
+            // set the other metadata, if it exists
+            // UNCOMMENT THIS WHEN WE KNOW FOR SURE WHAT THE TAU
+            // METADATA WILL LOOK LIKE 
+            if (getDataSource() != null) {
+                String tmp = getDataSource().getMetadataString();
+                if (tmp != null && tmp.length() > 0) {
+                    setField(XML_METADATA, null);
+                    setField(XML_METADATA_GZ, tmp);
+                }
+            }
+
             // Check if the date column exists and is a timestamp
             boolean dateColumnFound = false;
             for (int i = 0; i < this.getNumFields(); i++) {
@@ -570,11 +597,16 @@ public class Trial implements Serializable {
             statement.setInt(pos++, experimentID);
             for (int i = 0; i < this.getNumFields(); i++) {
                 if (DBConnector.isWritableType(this.getFieldType(i))) {
-                    if ((this.getFieldName(i).equalsIgnoreCase(Trial.XML_METADATA)) && (this.metadataFile != null)) {
-                        statement.setAsciiStream(pos++, inStream, (int) this.metadataFile.length());
-                    } else {
-                        statement.setString(pos++, this.getField(i));
-                    }
+					if (this.getFieldName(i).equalsIgnoreCase(XML_METADATA_GZ)) {
+						if (this.getField(i) == null) {
+							statement.setNull(pos++, this.getFieldType(i));
+						} else {
+							byte[] compressed = Gzip.compress(this.getField(i));
+							ByteArrayInputStream in = new ByteArrayInputStream(compressed);
+							statement.setBinaryStream(pos++, in, compressed.length);
+						}
+					} else
+                    	statement.setString(pos++, this.getField(i));
                 }
             }
 
@@ -588,15 +620,6 @@ public class Trial implements Serializable {
 
             statement.executeUpdate();
             statement.close();
-            if (this.metadataFile != null) {
-                try {
-                    inStream.close();
-                } catch (IOException e) {
-                    System.err.println("Unable to close file:");
-                    System.err.println(e.getMessage());
-                    e.printStackTrace();
-                }
-            }
 
             if (itExists) {
                 newTrialID = trialID;
@@ -816,61 +839,78 @@ public class Trial implements Serializable {
         fieldTypes = null;
     }
 
-    /**
-     * If the user passes in a metadata file, parse it into the trial.
-     * 
-     * @param metadataFileName
-     * @throws IOException
-     */
-    public void setMetadataFile(String metadataFileName) throws IOException {
-        this.metadataFile = new File(metadataFileName);
-        if (!this.metadataFile.exists())
-            throw new FileNotFoundException("The file " + metadataFileName + " does not exist.");
-        if (!this.metadataFile.canRead())
-            throw new IOException("The file " + metadataFileName + " does not have read permission.");
-        if (!this.metadataFile.isFile())
-            throw new FileNotFoundException(metadataFileName + " is not a valid file.");
-        inStream = new FileInputStream(this.metadataFile);
-        return;
-    }
-
     public void checkForMetadataColumn(DB db) {
-        if (this.metadataFile != null) {
-            String[] columns = Trial.getFieldNames(db);
-            boolean found = false;
-            // loop through the column names, and see if we have this column already
-            for (int i = 0; i < columns.length; i++) {
-                if (columns[i].equalsIgnoreCase(XML_METADATA)) {
-                    found = true;
-                    break;
-                }
+        String[] columns = Trial.getFieldNames(db);
+        boolean found = false;
+        // loop through the column names, and see if we have this column already
+        for (int i = 0; i < columns.length; i++) {
+            if (columns[i].equalsIgnoreCase(XML_METADATA)) {
+                found = true;
+                break;
+            }
+        }
+        if (!found) {
+            StringBuffer sql = new StringBuffer();
+            // create the column in the database
+            sql.append("ALTER TABLE " + db.getSchemaPrefix() + "trial ADD COLUMN ");
+            sql.append(XML_METADATA);
+            if (db.getDBType().equalsIgnoreCase("oracle")) {
+                sql.append(" CLOB"); // defaults to 4 GB max
+            } else if (db.getDBType().equalsIgnoreCase("derby")) {
+                sql.append(" CLOB"); // defaults to 1 MB max
+            } else if (db.getDBType().equalsIgnoreCase("db2")) {
+                sql.append(" CLOB"); // defaults to 1 GB max
+            } else if (db.getDBType().equalsIgnoreCase("mysql")) {
+                sql.append(" TEXT"); // defaults to 64 KB max
+            } else if (db.getDBType().equalsIgnoreCase("postgresql")) {
+                sql.append(" TEXT");  // defaults to 4 GB max
             }
-            if (!found) {
-                StringBuffer sql = new StringBuffer();
-                // create the column in the database
-                sql.append("ALTER TABLE " + db.getSchemaPrefix() + "trial ADD COLUMN ");
-                sql.append(XML_METADATA);
-                if ((db.getDBType().equalsIgnoreCase("oracle")) || (db.getDBType().equalsIgnoreCase("derby"))) {
-                    sql.append(" CLOB");
-                } else if (db.getDBType().equalsIgnoreCase("db2")) {
-                    sql.append(" CLOB");
-                } else if (db.getDBType().equalsIgnoreCase("mysql")) {
-                    sql.append(" TEXT");
-                } else if (db.getDBType().equalsIgnoreCase("postgresql")) {
-                    sql.append(" TEXT");
-                }
 
-                try {
-                    db.execute(sql.toString());
-                } catch (SQLException e) {
-                    System.err.println("Unable to add " + XML_METADATA + " column to trial table.");
-                    e.printStackTrace();
-                }
+            try {
+                db.execute(sql.toString());
+            } catch (SQLException e) {
+                System.err.println("Unable to add " + XML_METADATA + " column to trial table.");
+                e.printStackTrace();
+            }
+        }
+    }
+
+    public void checkForMetadataColumn2(DB db) {
+        String[] columns = Trial.getFieldNames(db);
+        boolean found = false;
+        // loop through the column names, and see if we have this column already
+        for (int i = 0; i < columns.length; i++) {
+            if (columns[i].equalsIgnoreCase(XML_METADATA_GZ)) {
+                found = true;
+                break;
+            }
+        }
+        if (!found) {
+            StringBuffer sql = new StringBuffer();
+            // create the column in the database
+            sql.append("ALTER TABLE " + db.getSchemaPrefix() + "trial ADD COLUMN ");
+            sql.append(XML_METADATA_GZ);
+            if (db.getDBType().equalsIgnoreCase("oracle")) {
+                sql.append(" BLOB"); // defaults to 4 GB max
+            } else if (db.getDBType().equalsIgnoreCase("derby")) {
+                sql.append(" BLOB"); // defaults to 1 MB max
+            } else if (db.getDBType().equalsIgnoreCase("db2")) {
+                sql.append(" BLOB"); // defaults to 1 GB max
+            } else if (db.getDBType().equalsIgnoreCase("mysql")) {
+                sql.append(" BLOB"); // defaults to 64 KB max
+            } else if (db.getDBType().equalsIgnoreCase("postgresql")) {
+                sql.append(" BYTEA");  // defaults to 4 GB max
+            }
+
+            try {
+                db.execute(sql.toString());
+            } catch (SQLException e) {
+                System.err.println("Unable to add " + XML_METADATA_GZ + " column to trial table.");
+                e.printStackTrace();
             }
         }
     }
 
-    
     public Map getMetaData() {
         return metaData;
     }
