@@ -17,9 +17,12 @@ import common.RMISortableIntervalEvent;
 import common.RMIPerfExplorerModel;
 import common.TransformationType;
 import common.PerfExplorerOutput;
+import java.io.File;
 
 public class PerfExplorerActionListener implements ActionListener {
 
+	public final static String LOADSCRIPT = "Load Analysis Script";
+	public final static String RERUNSCRIPT = "Re-run Analysis Script";
 	public final static String QUIT = "Quit PerfExplorer";
 	public final static String QUIT_SERVER = "Quit PerfExplorer (Shutdown Server)";
 	public final static String LOOK_AND_FEEL = "Set Look and Feel: ";
@@ -57,13 +60,16 @@ public class PerfExplorerActionListener implements ActionListener {
 	public final static String FRACTION_PHASE_CHART = "Phase Fraction of Total Runtime";
 	// arbitrary view menu items
 	public final static String CREATE_NEW_VIEW = "Create New View";
-	public final static String CREATE_NEW_SUB_VIEW = "Create New Sub-view";
+	public final static String CREATE_NEW_SUB_VIEW = "Create New Sub-View";
+	public final static String DELETE_CURRENT_VIEW = "Delete Selected View";
 	public final static String DO_IQR_BOXCHART = "Create BoxChart";
 	public final static String DO_HISTOGRAM = "Create Histograms";
 	public final static String DO_PROBABILITY_PLOT = "Create Normal Probability Plot";
 
 	private PerfExplorerClient mainFrame;
 
+	private String scriptName;
+
 	public PerfExplorerActionListener (PerfExplorerClient mainFrame) {
 		super();
 		this.mainFrame = mainFrame;
@@ -74,6 +80,7 @@ public class PerfExplorerActionListener implements ActionListener {
 			Object EventSrc = event.getSource();
 			if(EventSrc instanceof JMenuItem) {
 				String arg = event.getActionCommand();
+			// file menu items
 				if(arg.equals(QUIT)) {
 					System.exit(0);
 				} else if(arg.equals(QUIT_SERVER)) {
@@ -100,6 +107,10 @@ public class PerfExplorerActionListener implements ActionListener {
 							}
 						}
 					}
+				} else if (arg.equals(LOADSCRIPT)) {
+					loadScript();
+				} else if (arg.equals(RERUNSCRIPT)) {
+					runScript();
 			// help menu items
 				} else if (arg.equals(ABOUT)) {
 					createAboutWindow();
@@ -208,6 +219,8 @@ public class PerfExplorerActionListener implements ActionListener {
 					PerfExplorerViews.createNewView(mainFrame, parent);
 				} else if (arg.equals(CREATE_NEW_SUB_VIEW)) {
 					PerfExplorerViews.createNewSubView(mainFrame);
+				} else if (arg.equals(DELETE_CURRENT_VIEW)) {
+					PerfExplorerViews.deleteCurrentView(mainFrame);
 				} else {
 					System.out.println("unknown event! " + arg);
 				}
@@ -667,4 +680,27 @@ public class PerfExplorerActionListener implements ActionListener {
 		}
 		return (!forceIt && constantProblem == null) ? false : true;
 	}
+
+	private boolean loadScript () {
+		// open a file chooser dialog
+		JFileChooser fc = new JFileChooser(System.getProperty("user.dir"));
+		int returnVal = fc.showOpenDialog(mainFrame);
+		scriptName = fc.getSelectedFile().getAbsolutePath();
+		runScript();
+		return true;
+	}
+
+	private boolean runScript() {
+		if (scriptName == null) {
+			// make sure a script file has been loaded first
+			JOptionPane.showMessageDialog(mainFrame, 
+				"Please load a script first.",
+				"Script File Not Found", JOptionPane.ERROR_MESSAGE);
+			return false;
+		} else {
+			// run the script
+			edu.uoregon.tau.common.TauScripter.execfile(scriptName);
+			return true;
+		}
+	}
 }
