@@ -245,6 +245,14 @@ public class PerfExplorerConnection {
 	return viewID;
     }
 
+    public void deleteView (String id) {
+		try {
+	    	server.deleteView(id);
+		} catch (RemoteException e) {
+	    	handleError(e, "deleteView(" + id + ")");
+		}
+    }
+
     public List getViews(int parent) {
 	List views = null;
 	try {
@@ -314,4 +322,25 @@ public class PerfExplorerConnection {
 		}
 		return list;
 	}
+
+	public List getChartFieldNames() {
+		List list = null;
+		try {
+			list = server.getChartFieldNames();
+		} catch (RemoteException e) {
+	    	handleError(e, "getChartFieldNames()");
+		}
+		return list;
+	}
+
+    public List getXMLFields(PerfExplorerModel model) {
+		List results = null;
+		try {
+	    	results = server.getXMLFields(model);
+		} catch (RemoteException e) {
+	    	handleError(e, "getXMLFields(" + model.toString() + ")");
+		}
+		return results;
+    }
+
 }
