@@ -19,9 +19,12 @@ public class PerfExplorerJTree extends JTree {
 		putClientProperty("JTree.lineStyle", "Angled");
 		//getSelectionModel().setSelectionMode (
 			//TreeSelectionModel.SINGLE_TREE_SELECTION);
+		setShowsRootHandles(true);
+
 		PerfExplorerTreeCellRenderer renderer = 
 			new PerfExplorerTreeCellRenderer();
 		setCellRenderer(renderer);
+
 		addTreeSelectionListener (
 			new PerfExplorerTreeSelectionListener(this));
 		addTreeWillExpandListener (
@@ -33,19 +36,19 @@ public class PerfExplorerJTree extends JTree {
 			DefaultTreeModel model = new DefaultTreeModel(createNodes());
 			model.setAsksAllowsChildren(true);
 			theTree = new PerfExplorerJTree(model);
-			//theTree.setShowsRootHandles(true);
 			addTrialsForViews();
 		}
 		return theTree;
 	}
 
 	private static DefaultMutableTreeNode createNodes () {
-		DefaultMutableTreeNode root = new DefaultMutableTreeNode("Performance Data");
-		DefaultMutableTreeNode top = new DefaultMutableTreeNode("Database Profiles");
-		DefaultMutableTreeNode viewTop = new DefaultMutableTreeNode("Views");
-		addApplicationNodes(top, true);
+		DefaultMutableTreeNode root = new PerfExplorerTreeNode("Performance Data");
+		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
+		DefaultMutableTreeNode top = new PerfExplorerTreeNode(server.getConnectionString());
+		DefaultMutableTreeNode viewTop = new PerfExplorerTreeNode("Views");
+		//addApplicationNodes(top, true);
 		leafViews = new ArrayList();
-		addViewNodes(viewTop, "0");
+		//addViewNodes(viewTop, "0");
 		root.add(top);
 		root.add(viewTop);
 
@@ -59,17 +62,18 @@ public class PerfExplorerJTree extends JTree {
 		Iterator views = viewVector.iterator();
 		while (views.hasNext()) {
 			RMIView view = (RMIView) views.next();
-			DefaultMutableTreeNode node = new DefaultMutableTreeNode (view);
+			DefaultMutableTreeNode node = new PerfExplorerTreeNode (view);
 			addViewNodes(node, view.getField("ID"));
 			parentNode.add(node);
 		}
 		if (viewVector.size() == 0) {
 			leafViews.add(parentNode);
-			//addTrialsForView(parentNode);
+			addTrialsForView(parentNode);
 		}
 	}
 
 	public static void addApplicationNodes (DefaultMutableTreeNode parent, boolean getExperiments) {
+		//System.out.println("application nodes...");
 		DefaultMutableTreeNode node = null;
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		if (server != null) {
@@ -82,8 +86,8 @@ public class PerfExplorerJTree extends JTree {
 				while(applications.hasNext())
 				{
 					app = (Application) applications.next();
-					node = new DefaultMutableTreeNode (app);
-					addExperimentNodes(node, app, true);
+					node = new PerfExplorerTreeNode (app);
+					//addExperimentNodes(node, app, true);
 					parent.add(node);
 				}
 			}
@@ -92,6 +96,7 @@ public class PerfExplorerJTree extends JTree {
 	}
 
 	public static void addExperimentNodes (DefaultMutableTreeNode node, Application app, boolean getTrials) {
+		//System.out.println("experiment nodes...");
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the experiments
 		ListIterator experiments = server.getExperimentList(app.getID());
@@ -101,13 +106,14 @@ public class PerfExplorerJTree extends JTree {
 		while(experiments.hasNext())
 		{
 			exp = (Experiment) experiments.next();
-			expNode = new DefaultMutableTreeNode (exp);
-			if (getTrials) addTrialNodes(expNode, exp);
+			expNode = new PerfExplorerTreeNode (exp);
+			//if (getTrials) addTrialNodes(expNode, exp);
 			node.add(expNode);
 		}
 	}
 
 	public static void addTrialNodes (DefaultMutableTreeNode node, Experiment exp) {
+		//System.out.println("trial nodes...");
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the trials
 		ListIterator trials = server.getTrialList(exp.getID());
@@ -117,8 +123,8 @@ public class PerfExplorerJTree extends JTree {
 		while(trials.hasNext())
 		{
 			trial = (Trial) trials.next();
-			trialNode = new DefaultMutableTreeNode (trial);
-			addMetricNodes(trialNode, trial);
+			trialNode = new PerfExplorerTreeNode (trial);
+			//addMetricNodes(trialNode, trial);
 			node.add(trialNode);
 		}
 	}
@@ -126,12 +132,13 @@ public class PerfExplorerJTree extends JTree {
 	public static void addTrialsForViews () {
 		Iterator e = leafViews.iterator();
 		while (e.hasNext()) {
-			DefaultMutableTreeNode node = (DefaultMutableTreeNode) e.next();
+			PerfExplorerTreeNode node = (PerfExplorerTreeNode) e.next();
 			addTrialsForView(node);
 		}
 	}
 
 	public static void addTrialsForView (DefaultMutableTreeNode node) {
+		//System.out.println("trial nodes...");
 		Object[] objects = node.getUserObjectPath();
 		List views = new ArrayList();
 		for (int i = 0 ; i < objects.length ; i++) {
@@ -149,8 +156,8 @@ public class PerfExplorerJTree extends JTree {
 			while(trials.hasNext())
 			{
 				trial = (Trial) trials.next();
-				trialNode = new DefaultMutableTreeNode (trial);
-				addMetricNodes(trialNode, trial);
+				trialNode = new PerfExplorerTreeNode (trial);
+				//addMetricNodes(trialNode, trial);
 				node.add(trialNode);
 			}
 		}
@@ -158,8 +165,10 @@ public class PerfExplorerJTree extends JTree {
 
 
 	public static void addMetricNodes (DefaultMutableTreeNode node, Trial trial) {
+		//System.out.println("metric nodes...");
 		// get the metrics
 		List metricVector = trial.getMetrics();
+		int metricIndex = 0;
 		if (metricVector != null) {
 			ListIterator metrics = metricVector.listIterator();
 			Metric metric = null;
@@ -168,9 +177,26 @@ public class PerfExplorerJTree extends JTree {
 			while(metrics.hasNext())
 			{
 				metric = (Metric) metrics.next();
-				metricNode = new DefaultMutableTreeNode (metric);
+				metricNode = new PerfExplorerTreeNode (metric, true);
+				//addEventNodes(metricNode, trial, metricIndex++);
 				node.add(metricNode);
 			}
 		}
 	}
+
+	public static void addEventNodes (DefaultMutableTreeNode node, Trial trial, int metricIndex) {
+		//System.out.println("event nodes...");
+		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
+		// get the events
+		ListIterator events = server.getEventList(trial.getID(), metricIndex);
+		IntervalEvent event = null;
+		DefaultMutableTreeNode eventNode = null;
+		// loop through all the events, and print out some info
+		while(events.hasNext())
+		{
+			event = (IntervalEvent) events.next();
+			eventNode = new PerfExplorerTreeNode (event, false);
+			node.add(eventNode);
+		}
+	}
 }
