@@ -21,6 +21,18 @@ public class PerfExplorerMainJMenuBar extends JMenuBar {
 		JMenu fileMenu = new JMenu("File");
 		fileMenu.setMnemonic(KeyEvent.VK_F);
 
+		//Add a menu item.
+		JMenuItem scriptItem = new JMenuItem(
+				PerfExplorerActionListener.LOADSCRIPT);
+		scriptItem.addActionListener(listener);
+		fileMenu.add(scriptItem);
+
+		//Add a menu item.
+		JMenuItem rerunItem = new JMenuItem(
+				PerfExplorerActionListener.RERUNSCRIPT);
+		rerunItem.addActionListener(listener);
+		fileMenu.add(rerunItem);
+
 		//Add a menu item.
 		JMenuItem quitItem = new JMenuItem(
 				PerfExplorerActionListener.QUIT);
@@ -301,6 +313,11 @@ public class PerfExplorerMainJMenuBar extends JMenuBar {
 		createSubView.addActionListener(listener);
 		viewMenu.add(createSubView);
 
+		//Add a menu item.
+		JMenuItem deleteView = new JMenuItem(PerfExplorerActionListener.DELETE_CURRENT_VIEW);
+		deleteView.addActionListener(listener);
+		viewMenu.add(deleteView);
+
 		this.add(viewMenu);
 	}
 
