@@ -39,7 +39,7 @@ public class PerfExplorerTreeSelectionListener implements TreeSelectionListener
 			// don't allow heterogeneous selections
 			if (!PerfExplorerModel.getModel().setMultiSelection(multiSelection)) {
 				JOptionPane.showMessageDialog(null, 
-					"Please select only one type (Application, Experiment, Trial, Metric) of level.",
+					"Please select only one type (Application, Experiment, Trial, Metric, Event) of level.",
 					"Selection Error", JOptionPane.ERROR_MESSAGE);
 				// un-select the new ones
 				tree.clearSelection();
@@ -59,6 +59,10 @@ public class PerfExplorerTreeSelectionListener implements TreeSelectionListener
 			PerfExplorerTableModel model = (PerfExplorerTableModel)AnalysisManagementPane.getPane().getTable().getModel();
 			model.updateObject(object);
 			// update the managment view
+		} else if (index == 3) {
+			ChartPane.getPane().refreshDynamicControls(true, true, true);
+			ChartPane.getPane().drawChart();
+			// update the results view
 		} else {
 			PerformanceExplorerPane.getPane().updateImagePanel();
 			// update the results view
