@@ -8,7 +8,7 @@ import java.util.Hashtable;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import common.*;
-import edu.uoregon.tau.dms.dss.*;
+import edu.uoregon.tau.perfdmf.*;
 
 public class PerformanceExplorerPane extends JScrollPane implements ActionListener {
 
@@ -33,6 +33,8 @@ public class PerformanceExplorerPane extends JScrollPane implements ActionListen
 		super(imagePanel);
 		this.imagePanel = imagePanel;
 		this.resultsHash = new Hashtable();
+		JScrollBar jScrollBar = this.getVerticalScrollBar();
+		jScrollBar.setUnitIncrement(35);
 	}
 
 	public JPanel getImagePanel () {
@@ -45,11 +47,11 @@ public class PerformanceExplorerPane extends JScrollPane implements ActionListen
 		if ((model.getCurrentSelection() instanceof Metric) || 
 			(model.getCurrentSelection() instanceof Trial)) {
 			// check to see if we have these results already
-			//results = (RMIPerformanceResults)resultsHash.get(model.toString());
-			//if (results == null) {
+			results = (RMIPerformanceResults)resultsHash.get(model.toString());
+			if (results == null) {
 				PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 				results = server.getPerformanceResults(model);
-			//}
+			}
 			if (results.getResultCount() == 0) {
 				return;
 			}
@@ -68,6 +70,10 @@ public class PerformanceExplorerPane extends JScrollPane implements ActionListen
 				button.addActionListener(this);
 				imagePanel.add(button, BorderLayout.CENTER);
 				imagePanel2 = new JPanel(new GridLayout((results.getResultCount()-1)/imagesPerRow,imagesPerRow));
+			// if we have 5n images, then we have clustering of a trial.
+			} else if (results.getResultCount() % (imagesPerRow-1) == 0) {
+				imagePanel2 = new JPanel(new GridLayout(results.getResultCount()/(imagesPerRow-1),(imagesPerRow-1)));
+			// we have clustering of a metric.
 			} else {
 				imagePanel2 = new JPanel(new GridLayout(results.getResultCount()/imagesPerRow,imagesPerRow));
 			}
@@ -93,7 +99,7 @@ public class PerformanceExplorerPane extends JScrollPane implements ActionListen
 		//JOptionPane.showMessageDialog(PerfExplorerClient.getMainFrame(), null, description, JOptionPane.PLAIN_MESSAGE, icon);
 
         // Create and set up the window.
-        JFrame frame = new JFrame(description);
+        JFrame frame = new JFrame("TAU/PerfExplorer: " + description);
 
         //Window Stuff.
         int windowWidth = 500;
