@@ -69,7 +69,8 @@ public class ScriptFacade {
 	 * 
 	 * @param name
 	 */
-    public void setApplication(String name) {
+    public Application setApplication(String name) {
+        Application app = null;
         // check the argument
         if (name == null)
             throw new IllegalArgumentException("Application name cannot be null.");
@@ -78,7 +79,7 @@ public class ScriptFacade {
 
         boolean found = false;
         for (ListIterator apps = connection.getApplicationList(); apps.hasNext() && !found; ) {
-            Application app = (Application)apps.next();
+            app = (Application)apps.next();
             if (app.getName().equals(name)) {
                 model.setCurrentSelection(app);;
                 found = true;
@@ -86,6 +87,7 @@ public class ScriptFacade {
         }
         if (!found)
             throw new NoSuchElementException("Application '" + name + "' not found.");
+		return app;
     }
 
 	/**
@@ -93,7 +95,8 @@ public class ScriptFacade {
 	 * 
 	 * @param name
 	 */
-    public void setExperiment(String name) {
+    public Experiment setExperiment(String name) {
+		Experiment exp = null;
         // check the argument
         if (name == null)
             throw new IllegalArgumentException("Experiment name cannot be null.");
@@ -106,7 +109,7 @@ public class ScriptFacade {
         boolean found = false;
         for (ListIterator exps = connection.getExperimentList(app.getID());
              exps.hasNext() && !found;) {
-            Experiment exp = (Experiment)exps.next();
+            exp = (Experiment)exps.next();
             if (exp.getName().equals(name)) {
                 model.setCurrentSelection(exp);
                 found = true;
@@ -114,6 +117,7 @@ public class ScriptFacade {
         }
         if (!found)
             throw new NoSuchElementException("Experiment '" + name + "' not found.");
+		return exp;
     }
 
 	/**
@@ -121,7 +125,8 @@ public class ScriptFacade {
 	 * 
 	 * @param name
 	 */
-    public void setTrial(String name) {
+    public Trial setTrial(String name) {
+		Trial trial = null;
         // check the argument
         if (name == null)
             throw new IllegalArgumentException("Trial name cannot be null.");
@@ -134,7 +139,7 @@ public class ScriptFacade {
         boolean found = false;
         for (ListIterator trials = connection.getTrialList(exp.getID());
              trials.hasNext() && !found;) {
-            Trial trial = (Trial)trials.next();
+            trial = (Trial)trials.next();
             if (trial.getName().equals(name)) {
                 model.setCurrentSelection(trial);
                 found = true;
@@ -142,6 +147,7 @@ public class ScriptFacade {
         }
         if (!found)
             throw new NoSuchElementException("Trial '" + name + "' not found.");
+		return trial;
     }
 
 	/**
@@ -318,6 +324,31 @@ public class ScriptFacade {
 		PerfExplorerChart.doGeneralChart();
 	}
 
+	/**
+	 * Set the focus on the experiment specified.
+	 * 
+	 * @param name
+	 */
+    public void addApplication(String name) {
+        // check the argument
+        if (name == null)
+            throw new IllegalArgumentException("Application name cannot be null.");
+        if (name.equals(""))
+            throw new IllegalArgumentException("Application name cannot be an empty string.");
+
+        boolean found = false;
+        for (ListIterator apps = connection.getApplicationList();
+             apps.hasNext() && !found;) {
+            Application app = (Application)apps.next();
+            if (app.getName().equals(name)) {
+                model.addSelection(app);
+                found = true;
+            }
+        }
+        if (!found)
+            throw new NoSuchElementException("Application '" + name + "' not found.");
+    }
+
 	/**
 	 * Set the focus on the experiment specified.
 	 * 
@@ -354,10 +385,30 @@ public class ScriptFacade {
     	model.addEventName(eventName);
     }
 
-     public void setMetricName(String metricName) {
+    public void setGroupName(String groupName) {
+    	model.setGroupName(groupName);
+    }
+
+    public void addGroupName(String groupName) {
+    	model.addGroupName(groupName);
+    }
+
+    public void setMetricName(String metricName) {
     	model.setMetricName(metricName);
     }
+
+    //public void addMetricName(String metricName) {
+    	//model.addMetricName(metricName);
+    //}
     
+	public void setChartMetadataFieldName(String fieldName) {
+		model.setChartMetadataFieldName(fieldName);
+	}
+
+	public void setChartMetadataFieldValue(String fieldValue) {
+		model.setChartMetadataFieldValue(fieldValue);
+	}
+
 	public void setChartSeriesName(String seriesName) {
 		model.setChartSeriesName(seriesName);
 	}
@@ -374,6 +425,10 @@ public class ScriptFacade {
 		model.setChartTitle(title);
 	}
 
+	public void setChartUnits(String units) {
+		model.setChartUnits(units);
+	}
+
 	public void setChartMainEventOnly(int value) {
 		if (value == 0)
 			model.setMainEventOnly(false);
@@ -422,4 +477,49 @@ public class ScriptFacade {
 		else
 			model.setConstantProblem(true);
 	}
+
+	public void setChartHorizontal(int value) {
+		if (value == 0)
+			model.setChartHorizontal(false);
+		else
+			model.setChartHorizontal(true);
+	}
+
+	public void resetChartDefaults() {
+		//model.setCurrentSelection(model.getApplication());
+		model.setGroupName(null);
+		model.setMetricName(null);
+		model.setEventName(null);
+    	this.setDimensionReduction(TransformationType.NONE, null);
+		this.setChartMetadataFieldName(null);
+		this.setChartMetadataFieldValue(null);
+		this.setChartSeriesName(null);
+		this.setChartXAxisName(null, null);
+		this.setChartYAxisName(null, null);
+		this.setChartTitle(null);
+		this.setChartMainEventOnly(0);
+		this.setChartEventNoCallPath(0);
+		this.setChartEventExclusive100(0);
+		this.setChartLogYAxis(0);
+		this.setChartScalability(0);
+		this.setChartEfficiency(0);
+		this.setChartConstantProblem(0);
+		this.setChartHorizontal(0);
+	}
+
+	public ListIterator getApplicationList() {
+		return connection.getApplicationList();
+	}
+
+	public ListIterator getExperimentList() {
+		return connection.getExperimentList(model.getApplication().getID());
+	}
+
+	public ListIterator getTrialList() {
+		return connection.getTrialList(model.getExperiment().getID());
+	}
+
+	public ListIterator getEventList(Trial trial, int metricIndex) {
+		return connection.getEventList(trial.getID(), metricIndex);
+	}
 }
\ No newline at end of file
