@@ -9,7 +9,7 @@ import java.util.ArrayList;
  * data.  This data is usually correlation data.  It can reasonably have up 
  * to 4 dimensions (x,y,z,color).
  *
- * <P>CVS $Id: RMICubeData.java,v 1.1 2005/07/05 22:29:52 amorris Exp $</P>
+ * <P>CVS $Id: RMICubeData.java,v 1.3 2007/01/04 21:20:03 khuck Exp $</P>
  * @author khuck
  * @version 0.1
  * @since   0.1
@@ -86,10 +86,18 @@ public class RMICubeData implements Serializable {
 	 * Get the names for the dimensions.
 	 * 
 	 * @param dimension
-	 * @return
+	 * @return the names
 	 */
 	public String getNames(int dimension) { 
 		return names[dimension]; 
 	}
 
+	/**
+	 * Get the full list of names
+	 * @return the list of names
+	 */
+	public String[] getNames() { 
+		return names; 
+	}
+
 }
