@@ -13,7 +13,7 @@ import java.util.ArrayList;
  * This RMI object defines the state of the client model when an analysis
  * request is made.
  *
- * <P>CVS $Id: RMIPerfExplorerModel.java,v 1.25 2007/02/08 23:28:50 khuck Exp $</P>
+ * <P>CVS $Id: RMIPerfExplorerModel.java,v 1.29 2007/05/01 22:43:09 khuck Exp $</P>
  * @author khuck
  * @version 0.1
  * @since   0.1
@@ -36,6 +36,8 @@ public class RMIPerfExplorerModel implements Serializable {
 	protected boolean mainEventOnly = true;
 	protected boolean eventExclusive100 = false;
 	protected String chartSeriesName = null;
+	protected String chartMetadataFieldName = null;
+	protected String chartMetadataFieldValue = null;
 	protected String chartXAxisName = null;
 	protected String chartYAxisName = null;
 	protected String chartXAxisLabel = null;
@@ -44,6 +46,8 @@ public class RMIPerfExplorerModel implements Serializable {
 	protected boolean chartLogYAxis = false;
 	protected boolean chartScalability = false;
 	protected boolean chartEfficiency = false;
+	protected boolean chartHorizontal = false;
+	protected String chartUnits = null;
 
 	// more cluster settings
 	protected AnalysisType clusterMethod = null;
@@ -573,8 +577,12 @@ public class RMIPerfExplorerModel implements Serializable {
      * @param groupName
      */
 	public void setGroupName (String groupName) {
-		this.groupNames = new ArrayList();
-		this.groupNames.add(groupName);
+		if (groupName == null) {
+			this.groupNames = null;
+		} else {
+			this.groupNames = new ArrayList();
+			this.groupNames.add(groupName);
+		}
 	}
 
     /**
@@ -627,8 +635,12 @@ public class RMIPerfExplorerModel implements Serializable {
      * @param metricName
      */
 	public void setMetricName (String metricName) {
-		this.metricNames = new ArrayList();
-		this.metricNames.add(metricName);
+		if (metricName == null) {
+			this.metricNames = null;
+		} else {
+			this.metricNames = new ArrayList();
+			this.metricNames.add(metricName);
+		}
 	}
 
 	/**
@@ -705,8 +717,12 @@ public class RMIPerfExplorerModel implements Serializable {
      * @param eventNames
      */
 	public void setEventName (String eventName) {
-		this.eventNames = new ArrayList();
-		this.eventNames.add(eventName);
+		if (eventName == null) {
+			this.eventNames = null;
+		} else {
+			this.eventNames = new ArrayList();
+			this.eventNames.add(eventName);
+		}
 	}
 	
     /**
@@ -884,6 +900,42 @@ public class RMIPerfExplorerModel implements Serializable {
 		this.chartSeriesName = seriesName;
 	}
 
+    /**
+     * Get the XML field name
+     *
+     * @return
+     */
+	public String getChartMetadataFieldName() {
+		return this.chartMetadataFieldName;
+	}
+
+    /**
+     * Set the XML field name
+     *
+     * @param fieldName
+     */
+	public void setChartMetadataFieldName(String fieldName) {
+		this.chartMetadataFieldName = fieldName;
+	}
+
+    /**
+     * Get the XML field value
+     *
+     * @return
+     */
+	public String getChartMetadataFieldValue() {
+		return this.chartMetadataFieldValue;
+	}
+
+    /**
+     * Set the XML field value
+     *
+     * @param fieldValue
+     */
+	public void setChartMetadataFieldValue(String fieldValue) {
+		this.chartMetadataFieldValue = fieldValue;
+	}
+
     /**
      * Get the x axis column name
      *
@@ -949,15 +1001,33 @@ public class RMIPerfExplorerModel implements Serializable {
 		return this.chartTitle;
 	}
 
+    /**
+     * Get the chart units
+     *
+     * @return
+     */
+	public String getChartUnits() {
+		return this.chartUnits;
+	}
+
     /**
      * Set the chart title
      *
-     * @param seriesName
+     * @param title
      */
 	public void setChartTitle(String title) {
 		this.chartTitle = title;
 	}
 
+    /**
+     * Set the units
+     *
+     * @param units
+     */
+	public void setChartUnits(String units) {
+		this.chartUnits = units;
+	}
+
     /**
      * Get the log axis
      *
@@ -1012,4 +1082,22 @@ public class RMIPerfExplorerModel implements Serializable {
 		this.chartEfficiency = efficiency;
 	}
 
+    /**
+     * Set the horizontal chart option
+     *
+     * @param seriesName
+     */
+	public void setChartHorizontal(boolean horizontal) {
+		this.chartHorizontal = horizontal;
+	}
+
+    /**
+     * Get the horizontal chart option
+     *
+     * @return
+     */
+	public boolean getChartHorizontal() {
+		return this.chartHorizontal;
+	}
+
 }
