@@ -43,7 +43,7 @@ import clustering.ClusterException;
  * This server is accessed through RMI, and objects are passed back and forth
  * over the RMI link to the client.
  *
- * <P>CVS $Id: PerfExplorerServer.java,v 1.43 2007/02/05 22:59:04 khuck Exp $</P>
+ * <P>CVS $Id: PerfExplorerServer.java,v 1.48 2007/04/20 17:06:47 khuck Exp $</P>
  * @author  Kevin Huck
  * @version 0.1
  * @since   0.1
@@ -617,6 +617,17 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		return chartData;
 	}
 
+	/**
+	 * Make an interactive request for XML fields.
+	 * 
+	 * @param modelData
+	 * @return List
+	 */
+	public List getXMLFields(RMIPerfExplorerModel modelData) {
+		List chartData = GeneralChartData.getXMLFields(modelData);
+		return chartData;
+	}
+
 	/**
 	 * Get the groups defined in these profiles.  The client passes in a model
 	 * with one or more experiments selected, and the code will get all the
@@ -633,24 +644,56 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 			StringBuffer buf;
 			buf = new StringBuffer("select distinct ie.group_name ");
 			buf.append(" from interval_event ie inner join trial t on ie.trial = t.id ");
+			buf.append(" inner join experiment e on t.experiment = e.id ");
 			Object object = modelData.getCurrentSelection();
 			if (object instanceof RMIView) {
 				buf.append(modelData.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append(" where t.experiment in (");
 				List selections = modelData.getMultiSelection();
 				if (selections == null) {
 					// just one selection
-					buf.append (modelData.getExperiment().getID());
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application = ");
+						buf.append(modelData.getApplication().getID());
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment = ");
+						buf.append(modelData.getExperiment().getID());
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id = ");
+						buf.append(modelData.getTrial().getID());
+					}
 				} else {
-					for (int i = 0 ; i < selections.size() ; i++) {
-						Experiment exp = (Experiment)selections.get(i);
-						if (i > 0)
-							buf.append(",");
-						buf.append(exp.getID());
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Application app = (Application)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(app.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Experiment exp = (Experiment)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(exp.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Trial trial = (Trial)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(trial.getID());
+						}
+						buf.append(")");
 					}
 				}
-				buf.append(")");
 			}
 			PreparedStatement statement = db.prepareStatement(buf.toString());
 			ResultSet results = statement.executeQuery();
@@ -687,24 +730,56 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				buf.append("select distinct count(m.name), m.name ");
 			}
 			buf.append(" from metric m inner join trial t on m.trial = t.id ");
+			buf.append(" inner join experiment e on t.experiment = e.id ");
 			Object object = modelData.getCurrentSelection();
 			if (object instanceof RMIView) {
 				buf.append(modelData.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append(" where t.experiment in (");
 				List selections = modelData.getMultiSelection();
 				if (selections == null) {
 					// just one selection
-					buf.append (modelData.getExperiment().getID());
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application = ");
+						buf.append(modelData.getApplication().getID());
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment = ");
+						buf.append(modelData.getExperiment().getID());
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id = ");
+						buf.append(modelData.getTrial().getID());
+					}
 				} else {
-					for (int i = 0 ; i < selections.size() ; i++) {
-						Experiment exp = (Experiment)selections.get(i);
-						if (i > 0)
-							buf.append(",");
-						buf.append(exp.getID());
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Application app = (Application)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(app.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Experiment exp = (Experiment)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(exp.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Trial trial = (Trial)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(trial.getID());
+						}
+						buf.append(")");
 					}
 				}
-				buf.append(")");
 			}
 			if (db.getDBType().compareTo("db2") == 0) {
 				buf.append(" group by cast (m.name as VARCHAR(256)) order by 1 desc");
@@ -752,24 +827,56 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				buf.append("select distinct ie.name ");
 			}
 			buf.append(" from interval_event ie inner join trial t on ie.trial = t.id ");
+			buf.append(" inner join experiment e on t.experiment = e.id ");
 			Object object = modelData.getCurrentSelection();
 			if (object instanceof RMIView) {
 				buf.append(modelData.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append(" where t.experiment in (");
 				List selections = modelData.getMultiSelection();
 				if (selections == null) {
 					// just one selection
-					buf.append (modelData.getExperiment().getID());
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application = ");
+						buf.append(modelData.getApplication().getID());
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment = ");
+						buf.append(modelData.getExperiment().getID());
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id = ");
+						buf.append(modelData.getTrial().getID());
+					}
 				} else {
-					for (int i = 0 ; i < selections.size() ; i++) {
-						Experiment exp = (Experiment)selections.get(i);
-						if (i > 0)
-							buf.append(",");
-						buf.append(exp.getID());
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Application app = (Application)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(app.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Experiment exp = (Experiment)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(exp.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Trial trial = (Trial)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(trial.getID());
+						}
+						buf.append(")");
 					}
 				}
-				buf.append(")");
 			}
 			PreparedStatement statement = db.prepareStatement(buf.toString());
 			//PerfExplorerOutput.println(statement.toString());
@@ -823,7 +930,7 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 	 * @return List
 	 */
 	public List getPossibleValues (String tableName, String columnName) {
-		PerfExplorerOutput.println("getPossibleValues()...");
+		//PerfExplorerOutput.println("getPossibleValues()...");
 		List values = new ArrayList();
 		try {
 			DB db = this.getDB();
@@ -905,6 +1012,29 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		return viewID;
 	}
 
+	/**
+	 * This method deletes a view for the PerfExplorerClient application.
+	 * The id is the id of the view to be deleted.  All sub-views will
+	 * be deleted as well.
+	 * 
+	 * @param id
+	 */
+	public void deleteView(String id) {
+		//PerfExplorerOutput.println("createNewView()...");
+		try {
+			DB db = this.getDB();
+			PreparedStatement statement = null;
+			statement = db.prepareStatement("delete from trial_view where id = ?");
+			statement.setString(1, id);
+			statement.execute();
+			statement.close();
+		} catch (Exception e) {
+			String error = "ERROR: Couldn't delete the view from the database!";
+			System.err.println(error);
+			e.printStackTrace();
+		}
+	}
+
 	/**
 	 * Get the subviews for this parent.  If the parent is 0, get all top-level
 	 * views.
@@ -1340,6 +1470,49 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		return QueryManager.getTrialList(criteria);
 	}
 
+	/**
+	 * Requests a TrialList object from the PerfDMF database,
+	 * based on the application id which is passed in.
+	 * 
+	 * @param criteria a formatted string specifying the 
+	 *		  criteria for selecting the trial
+	 * @return List of PerfDMF Trial objects.
+	 */
+	public List getChartFieldNames() {
+		DB db = this.getDB();
+		List list = new ArrayList();
+		String[] app = Application.getFieldNames(db);
+		list.add ("application.id");
+		list.add ("application.name");
+		for (int i = 0 ; i < app.length ; i++) {
+			list.add ("application." + app[i]);
+		}
+		list.add ("experiment.id");
+		list.add ("experiment.name");
+		list.add ("experiment.applciation");
+		String[] exp = Experiment.getFieldNames(db);
+		for (int i = 0 ; i < exp.length ; i++) {
+			list.add ("experiment." + exp[i]);
+		}
+		list.add ("trial.id");
+		list.add ("trial.name");
+		list.add ("trial.experiment");
+		String[] trial = Trial.getFieldNames(db);
+		for (int i = 0 ; i < trial.length ; i++) {
+			if (trial[i].equalsIgnoreCase(Trial.XML_METADATA_GZ)) {
+				// don't add it
+			} else if (trial[i].equalsIgnoreCase("node_count") ||
+					   trial[i].equalsIgnoreCase("contexts_per_node")) {
+				// don't add it
+			} else if (trial[i].equalsIgnoreCase("threads_per_context")) {
+				list.add ("trial.threads_of_execution");
+			} else {
+				list.add ("trial." + trial[i]);
+			}
+		}
+		return list;
+	}
+
 	/**
 	 * The main method to create the PerfExplorerServer.
 	 * 
