@@ -5,13 +5,14 @@ import org.jfree.data.xy.XYDataset;
 
 import clustering.RawDataInterface;
 
+
 /**
  * Dataset to store scatterplot data.
  * The JFreeChart API requires that client applications extend the 
  * AbstractXYDataset class to implement the data to be plotted in a scatterplot.
  * This is essentially a wrapper class around the RawDataInterface class.
  *
- * <P>CVS $Id: ScatterPlotDataset.java,v 1.1 2005/07/05 22:29:54 amorris Exp $</P>
+ * <P>CVS $Id: ScatterPlotDataset.java,v 1.5 2007/01/23 22:57:03 khuck Exp $</P>
  * @author  Kevin Huck
  * @version 0.1
  * @since   0.1
@@ -22,6 +23,8 @@ public class ScatterPlotDataset extends AbstractXYDataset implements XYDataset {
 	private String seriesName = null;
 	private int x = 0;
 	private int y = 1;
+	private boolean useMainValue = false;
+	private String debug = null;
 	
 	/**
 	 * Constructor.
@@ -31,12 +34,14 @@ public class ScatterPlotDataset extends AbstractXYDataset implements XYDataset {
 	 * @param x
 	 * @param y
 	 */
-	public ScatterPlotDataset(RawDataInterface data, String seriesName, int x, int y) {
+	public ScatterPlotDataset(RawDataInterface data, String seriesName,
+	int x, int y, boolean useMainValue) {
 		super();
 		this.data = data;
 		this.seriesName = seriesName;
 		this.x = x;
 		this.y = y;
+		this.useMainValue = useMainValue;
 	}
 
 	/* (non-Javadoc)
@@ -64,6 +69,8 @@ public class ScatterPlotDataset extends AbstractXYDataset implements XYDataset {
 	 * @see org.jfree.data.xy.XYDataset#getX(int, int)
 	 */
 	public Number getX(int arg0, int arg1) {
+		//if (x == 0) 
+			//debug = new String ("Value [" + arg0 + "/" + arg1 + "]: " + data.getValue(arg1,x));
 		return new Double(data.getValue(arg1, x));
 	}
 
@@ -71,7 +78,14 @@ public class ScatterPlotDataset extends AbstractXYDataset implements XYDataset {
 	 * @see org.jfree.data.xy.XYDataset#getY(int, int)
 	 */
 	public Number getY(int arg0, int arg1) {
-		return new Double(data.getValue(arg1, y));
+		//if (y == 0 && debug != null) {
+			//String debug2 = new String ("Value [" + arg0 + "/" + arg1 + "]: " + data.getValue(arg1,y));
+			//PerfExplorerOutput.println(debug + ", " + debug2);
+		//}
+		if (useMainValue)
+			return new Double(data.getMainValue(arg1));
+		else
+			return new Double(data.getValue(arg1, y));
 	}
 
 }
