@@ -1,5 +1,7 @@
 package server;
 
+import common.EngineType;
+import edu.uoregon.tau.perfdmf.DatabaseAPI;
 import java.util.Timer;
 
 
@@ -8,7 +10,7 @@ import java.util.Timer;
  * requests.  It is created by the PerfExplorerServer object, and 
  * checks the queue every 1 seconds to see if there are any new requests.
  *
- * <P>CVS $Id: TimerThread.java,v 1.1 2005/07/05 22:29:54 amorris Exp $</P>
+ * <P>CVS $Id: TimerThread.java,v 1.6 2007/01/23 18:46:29 khuck Exp $</P>
  * @author  Kevin Huck
  * @version 0.1
  * @since   0.1
@@ -20,13 +22,15 @@ public class TimerThread extends Timer implements Runnable {
 	 *  reference to the server which created this thread
 	 */
 	private PerfExplorerServer server = null;
+	private DatabaseAPI workerSession = null;
 
 	/**
 	 * Constructor.  Expects a reference to a PerfExplorerServer.
 	 * @param server
 	 */
-	public TimerThread (PerfExplorerServer server, int analysisEngine) {
+	TimerThread (PerfExplorerServer server, DatabaseAPI workerSession) {
 		this.server = server;
+		this.workerSession = workerSession;
 	}
 
 	/**
@@ -37,12 +41,8 @@ public class TimerThread extends Timer implements Runnable {
 	 * the analysisTask returns immediately.
 	 */
 	public void run() {
-		// use this line for the new processing
-		AnalysisTaskWrapper analysisTask = new AnalysisTaskWrapper(this.server, AnalysisTaskWrapper.WEKA_ENGINE);
-		// use this line for the old processing
-		//AnalysisTask analysisTask = new AnalysisTask(this.server);
-
-		// 
+		AnalysisTask analysisTask = new
+		AnalysisTask(this.server, this.workerSession);
 		schedule(analysisTask, 1000, 1000);
 	}
 }
