@@ -11,5 +11,5 @@ then
 fi
 
 echo "BEGIN_EXCLUDE_LIST" > throttle.tau
-cat $*  | grep Throttle | awk '{print $4 $5 $6 $7 $8 $9;}' | sort | uniq >>throttle.tau 
+cat $*  | awk '/TAU<[0-9]*>:\ Throttle:/ {print $4 " " $5 " " $6 " " $7 " " $8 " " $9;}' | sort | uniq | sed -e s/[.\>A-Z0-9:\ ]*Throttle:// -e s/\\[.*//  >>throttle.tau
 echo "END_EXCLUDE_LIST" >> throttle.tau
