@@ -1,30 +1,39 @@
 /*
  * Axes.java
  *
- * Copyright 2005                                                 
- * Department of Computer and Information Science, University of Oregon
+ * Copyright 2005-2006                                
+ * Performance Research Laboratory, University of Oregon
  */
 package edu.uoregon.tau.vis;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import javax.swing.*;
+import javax.media.opengl.GL;
+import javax.media.opengl.GLAutoDrawable;
+import javax.swing.BorderFactory;
+import javax.swing.ButtonGroup;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JRadioButton;
 
-import net.java.games.jogl.GL;
-import net.java.games.jogl.GLDrawable;
-import net.java.games.jogl.util.GLUT;
+import com.sun.opengl.util.GLUT;
 
 /**
  * Draws axes with labels.
  *
- * <P>CVS $Id: Axes.java,v 1.2 2005/07/16 00:21:07 amorris Exp $</P>
- * @author	Alan Morris
- * @version	$Revision: 1.2 $
+ * <P>CVS $Id: Axes.java,v 1.6 2007/02/01 03:43:10 amorris Exp $</P>
+ * @author  Alan Morris
+ * @version $Revision: 1.6 $
  */
 public class Axes implements Shape {
 
@@ -63,10 +72,14 @@ public class Axes implements Shape {
     private Color minorColor = new Color(0.5f,0.5f,0.5f);
 
 
+    // until I add a proper event interface, each component will just keep track of the old values
+    // and check on each render if it needs to recreate it's display lists
+    
     // this is to keep track of the old reverseVideo value
     // I need to come up with a better way of tracking the settings
     // we have to know whether to recreate the display list or not
     private boolean oldReverseVideo;
+    private boolean oldAntiAlias;
     
     /**
      * Typesafe enum for axes orientation
@@ -346,14 +359,19 @@ public class Axes implements Shape {
     }
 
     public void render(VisRenderer visRenderer) {
-        GLDrawable glDrawable = visRenderer.getGLDrawable();
+        GLAutoDrawable glDrawable = visRenderer.getGLAutoDrawable();
 
+        // If the reverse video setting has changed, we must redraw
         if (oldReverseVideo != visRenderer.getReverseVideo()) {
             dirty = true;
         }
-        
         oldReverseVideo = visRenderer.getReverseVideo();
         
+        if (oldAntiAlias != visRenderer.getAntiAliasedLines()) {
+            dirty = true;
+        }
+        oldAntiAlias = visRenderer.getAntiAliasedLines();
+        
         if (!enabled)
             return;
 
@@ -426,7 +444,7 @@ public class Axes implements Shape {
     }
 
     private void drawGrid(VisRenderer visRenderer, int numx, int numy, float xSize, float ySize, int xLabelSkip, int yLabelSkip) {
-        GL gl = visRenderer.getGLDrawable().getGL();
+        GL gl = visRenderer.getGLAutoDrawable().getGL();
         applyMinorColor(visRenderer);
 
         gl.glBegin(GL.GL_LINES);
@@ -472,7 +490,7 @@ public class Axes implements Shape {
         if (!enabled)
             return;
 
-        GL gl = visRenderer.getGLDrawable().getGL();
+        GL gl = visRenderer.getGLAutoDrawable().getGL();
 
         // don't highlight on if they're not both on
         if (selectedRow < 0 || selectedCol < 0) {
@@ -496,16 +514,18 @@ public class Axes implements Shape {
         int zOffset = 0;
 
         gl.glDisable(GL.GL_LIGHTING);
-
-        //  gl.glColor3f(0.5f, 0.5f, 0.5f);
-
-        //        gl.glEnable(GL.GL_LINE_SMOOTH);
-        //        gl.glBlendFunc(GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA);
-        //        gl.glHint(GL.GL_LINE_SMOOTH_HINT, GL.GL_NICEST);
-        //        gl.glEnable(GL.GL_BLEND);
-
+        
+        if (visRenderer.getAntiAliasedLines()) {
+            gl.glEnable(GL.GL_LINE_SMOOTH);
+            gl.glEnable(GL.GL_BLEND);   
+            gl.glBlendFunc(GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA);
+            gl.glHint(GL.GL_LINE_SMOOTH_HINT, GL.GL_NICEST);
+        } else {
+            gl.glDisable(GL.GL_LINE_SMOOTH);
+            gl.glDisable(GL.GL_BLEND);   
+        }                
+                
         gl.glLineWidth(1.0f);
-        gl.glDisable(GL.GL_LINE_SMOOTH);
 
         // grid for x-y plane
         drawGrid(visRenderer, numx, numy, xSize, ySize, this.xLabelSkip, this.yLabelSkip);
@@ -629,7 +649,7 @@ public class Axes implements Shape {
             boolean leftJustified, int selected) {
         // Draw the strings for an axis
 
-        GL gl = visRenderer.getGLDrawable().getGL();
+        GL gl = visRenderer.getGLAutoDrawable().getGL();
         double maxPoint = 0;
 
         applyTextColor(visRenderer);
@@ -676,7 +696,7 @@ public class Axes implements Shape {
                 // Render The Text
                 for (int c = 0; c < string.length(); c++) {
                     char ch = string.charAt(c);
-                    glut.glutStrokeCharacter(gl, font, ch);
+                    glut.glutStrokeCharacter(font, ch);
                 }
                 gl.glPopMatrix();
             } else {
@@ -720,7 +740,7 @@ public class Axes implements Shape {
                 // Render The Text
                 for (int c = 0; c < line.length(); c++) {
                     char ch = line.charAt(c);
-                    glut.glutStrokeCharacter(gl, font, ch);
+                    glut.glutStrokeCharacter(font, ch);
                 }
 
                 gl.glTranslatef(-width / 2, 0, 0);
@@ -742,7 +762,7 @@ public class Axes implements Shape {
                 // Render The Text
                 for (int c = 0; c < line.length(); c++) {
                     char ch = line.charAt(c);
-                    glut.glutStrokeCharacter(gl, font, ch);
+                    glut.glutStrokeCharacter(font, ch);
                 }
 
                 gl.glTranslatef(-width / 2, 0, 0);
@@ -764,7 +784,7 @@ public class Axes implements Shape {
         // Render The Text
         for (int i = 0; i < string.length(); i++) {
             char c = string.charAt(i);
-            glut.glutStrokeCharacter(gl, font, c);
+            glut.glutStrokeCharacter(font, c);
         }
     }
 
