@@ -1,32 +1,45 @@
 /*
  * BarPlot.java
  *
- * Copyright 2005                                                 
- * Department of Computer and Information Science, University of Oregon
+ * Copyright 2005-2006                                
+ * Performance Research Laboratory, University of Oregon
  */
 package edu.uoregon.tau.vis;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Observable;
 
-import javax.swing.*;
+import javax.media.opengl.GL;
+import javax.media.opengl.GLAutoDrawable;
+import javax.media.opengl.GLAutoDrawable;
+import javax.swing.BorderFactory;
+import javax.swing.JCheckBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JSlider;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
-import net.java.games.jogl.GL;
-import net.java.games.jogl.GLDrawable;
-import net.java.games.jogl.util.GLUT;
+import com.sun.opengl.util.GLUT;
+
+
+
+
 
 /**
  * Draws a 3d bar plot.
  *
- * <P>CVS $Id: BarPlot.java,v 1.2 2005/07/16 00:21:07 amorris Exp $</P>
+ * <P>CVS $Id: BarPlot.java,v 1.5 2007/02/01 03:43:10 amorris Exp $</P>
  * @author	Alan Morris
- * @version	$Revision: 1.2 $
+ * @version	$Revision: 1.5 $
  */
 public class BarPlot implements Plot {
 
@@ -106,7 +119,11 @@ public class BarPlot implements Plot {
 
     public void setValues(float xSize, float ySize, float zSize, float heightValues[][], float colorValues[][]) {
         this.nrows = heightValues.length;
-        this.ncols = heightValues[0].length;
+        if (heightValues.length > 0) {
+            this.ncols = heightValues[0].length;
+        } else {
+            this.ncols = 0;
+        }
         this.heightValues = heightValues;
         this.colorValues = colorValues;
         this.xSize = xSize;
@@ -381,7 +398,7 @@ public class BarPlot implements Plot {
         }
     }
 
-    private void renderOpaque(GLDrawable glDrawable) {
+    private void renderOpaque(GLAutoDrawable glDrawable) {
         GL gl = glDrawable.getGL();
 
         if (dirty || displayLists == null) {
@@ -530,7 +547,7 @@ public class BarPlot implements Plot {
 
     }
 
-    private void renderTranslucent(GLDrawable glDrawable, Vec direction) {
+    private void renderTranslucent(GLAutoDrawable glDrawable, Vec direction) {
         GL gl = glDrawable.getGL();
         gl.glEnable(GL.GL_DEPTH_TEST);
 
@@ -561,7 +578,7 @@ public class BarPlot implements Plot {
     }
 
     public void render(VisRenderer visRenderer) {
-        GLDrawable glDrawable = visRenderer.getGLDrawable();
+        GLAutoDrawable glDrawable = visRenderer.getGLAutoDrawable();
         Vec direction = visRenderer.getViewDirection();
 
         axes.render(visRenderer);
