@@ -1,21 +1,35 @@
 /*
  * ColorScale.java
  *
- * Copyright 2005                                                 
- * Department of Computer and Information Science, University of Oregon
+ * Copyright 2005-2006                                
+ * Performance Research Laboratory, University of Oregon
  */
 package edu.uoregon.tau.vis;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.util.*;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Observable;
+import java.util.StringTokenizer;
 
-import javax.swing.*;
+import javax.media.opengl.GL;
+import javax.media.opengl.GLAutoDrawable;
+import javax.swing.BorderFactory;
+import javax.swing.ButtonGroup;
+import javax.swing.JCheckBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JRadioButton;
+import javax.swing.JSlider;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
 
-import net.java.games.jogl.GL;
-import net.java.games.jogl.GLDrawable;
-import net.java.games.jogl.util.GLUT;
+import com.sun.opengl.util.GLUT;
 
 /**
  * Draws a colorscale and also provides services to other vis components.
@@ -24,9 +38,9 @@ import net.java.games.jogl.util.GLUT;
  * allowing them to query values (0..1) and get colors in the current
  * color set. 
  *    
- * <P>CVS $Id: ColorScale.java,v 1.2 2005/07/16 00:21:07 amorris Exp $</P>
+ * <P>CVS $Id: ColorScale.java,v 1.7 2006/11/16 17:50:36 amorris Exp $</P>
  * @author	Alan Morris
- * @version	$Revision: 1.2 $
+ * @version	$Revision: 1.7 $
  */
 
 /* TODO: Provide control over font size perhaps? */
@@ -79,9 +93,27 @@ public class ColorScale extends Observable implements Shape {
     private boolean enabled = true;
     private ColorSet colorSet = ColorSet.RAINBOW;
     private String lowString, highString, label;
-    private double fontScale = 0.10;
+    private double fontScale = 0.12;
+    private float leftMargin = 25; // distance between left side and colorscale
+    private float leftTextMargin = 5; // minimum distance between the left side and text labels (high and low)
+    
     private int displayList;
+    
+    
+    private int width = 25;
+    private int height = 300;
+    private int topBottomMargin = 60;
+    
+    // this is to keep track of the old reverseVideo value
+    // I need to come up with a better way of tracking the settings
+    // we have to know whether to recreate the display list or not
+    private boolean oldReverseVideo;
+    // need to mark as dirty when size has changed
+    private int oldWidth;
+    private int oldHeight;
 
+    private boolean oldAntiAlias;
+    
     public ColorScale() {
     }
 
@@ -95,6 +127,7 @@ public class ColorScale extends Observable implements Shape {
         this.lowString = low;
         this.highString = high;
         this.label = label;
+        this.dirty = true;
     }
 
     /**
@@ -173,14 +206,32 @@ public class ColorScale extends Observable implements Shape {
                 visRenderer.redraw();
             }
         });
+        
+        final JSlider fontScaleSlider = new JSlider(0,100,(int)(getFontScale()*100));
+        fontScaleSlider.addChangeListener(new ChangeListener() {
+            public void stateChanged(ChangeEvent event) {
+                try {
+                    ColorScale.this.setFontScale(fontScaleSlider.getValue()/(double)100);
+                    visRenderer.redraw();
+                } catch (Exception e) {
+                    VisTools.handleException(e);
+                }
+            }
+        });    
 
+        VisTools.addCompItem(controlPanel, new JLabel("Font Size"),gbc,0,1,1,1);
+        gbc.fill = GridBagConstraints.BOTH;
+        VisTools.addCompItem(controlPanel, fontScaleSlider,gbc,1,1,1,1);
+        gbc.fill = GridBagConstraints.NONE;
+        
+        
         //        VisTools.addCompItem(controlPanel, new JLabel("ColorScale Selection"), gbc, 0, 1, 1, 1);
         ButtonGroup group = new ButtonGroup();
 
         final Map colorScaleMap = new HashMap();
 
         int x = 0;
-        int y = 1;
+        int y = 2;
         for (int i = 0; i < ColorSet.VALUES.length; i++) {
             ColorSet colorSet = ColorSet.VALUES[i];
             JRadioButton jrb = new JRadioButton(colorSet.toString(), this.colorSet == colorSet);
@@ -212,40 +263,90 @@ public class ColorScale extends Observable implements Shape {
         return controlPanel;
     }
 
-    private void drawText(GL gl, double x, double y, String text) {
+    
+    private float getTextWidth(GL gl, String text) {
+        StringTokenizer st = new StringTokenizer(text, "\n");
+        float maxWidth = 0;
+        while (st.hasMoreTokens()) {
+            String line = st.nextToken();
+            float width = glut.glutStrokeLength(font, line);
+            maxWidth = Math.max(maxWidth, width);
+        }
+        return (float)(maxWidth * fontScale);
+    }
+    
+    private void drawText(GL gl, double x, double y, String text, boolean growDown) {
         if (text == null)
             return;
 
         gl.glPushMatrix();
 
+        int numlines = 0;
         StringTokenizer st = new StringTokenizer(text, "\n");
+        numlines = st.countTokens();
+        
+        
+        double ascent = VisTools.fontAscent * fontScale;
+        double descent = VisTools.fontDescent * fontScale;
+        
+                
+        float rowHeight = (float)(VisTools.fontHeight * fontScale);
+        
+        // 10% extra spacing between rows
+        rowHeight = (float)((ascent+descent)*1.10);
+        
+        if (growDown) {
+            y = y - ascent - 5;
+        } else {
+            y = y + (rowHeight*(numlines-1)) + descent + 3;
+        }
+        
         while (st.hasMoreTokens()) {
-            double thisX = x;
+            String line = st.nextToken();
+            double startX = x;
             gl.glPushMatrix();
 
-            String line = st.nextToken();
+            
             float width = glut.glutStrokeLength(font, line);
+            
+     
+            
+            startX -= (width * fontScale / 2);
+//            thisX = Math.max(thisX, -20);
 
-            double fontScale = 0.10;
+//            gl.glBegin(GL.GL_LINES);
+//            gl.glVertex2f(0,0);
+//            gl.glVertex2f((float)x,(float)y);
+//            gl.glVertex2f((float)x,(float)y);
+//            gl.glVertex2f((float)startX,(float)y);
+//            gl.glEnd();
+//            
+            gl.glTranslated(startX, y, 0);
+
+//            // 112 seems to be the actual height
+//            float value = (float)(VisTools.fontHeight * fontScale);
+//            gl.glBegin(GL.GL_QUADS);
+//            gl.glVertex3f(0.0f,0.0f,0.0f);
+//            gl.glVertex3f(0.0f,value,0.0f);
+//            gl.glVertex3f(value,value,0.0f);
+//            gl.glVertex3f(value,0.0f,0.0f);
+//            gl.glEnd();
 
-            thisX -= (width * fontScale / 2);
-            thisX = Math.max(thisX, -20);
 
-            gl.glTranslated(thisX, y, 0);
             gl.glScaled(fontScale, fontScale, fontScale);
 
+
+            
+
             // Render The Text
             for (int c = 0; c < line.length(); c++) {
                 char ch = line.charAt(c);
-                glut.glutStrokeCharacter(gl, font, ch);
+                glut.glutStrokeCharacter(font, ch);
             }
 
-            gl.glTranslatef(-width / 2, 0, 0);
-            gl.glTranslated(0, -250.0f, 0);
-
             gl.glPopMatrix();
 
-            gl.glTranslated(0, -25.0f, 0);
+            gl.glTranslated(0, -rowHeight, 0);
 
         }
 
@@ -258,15 +359,39 @@ public class ColorScale extends Observable implements Shape {
      * @param visRenderer the associated control panel
      */
     public void render(VisRenderer visRenderer) {
-        GLDrawable glDrawable = visRenderer.getGLDrawable();
+        GLAutoDrawable glDrawable = visRenderer.getGLAutoDrawable();
 
-        if (!enabled)
+        // If the reverse video setting has changed, we must redraw
+        if (oldReverseVideo != visRenderer.getReverseVideo()) {
+            dirty = true;
+        }
+        oldReverseVideo = visRenderer.getReverseVideo();
+
+        if (oldAntiAlias != visRenderer.getAntiAliasedLines()) {
+            dirty = true;
+        }
+        oldAntiAlias = visRenderer.getAntiAliasedLines();
+        
+        
+        if (!enabled) {
             return;
+        }
 
-        dirty = true;
+        
+        int width = (int) glDrawable.getWidth();
+        int height = (int) glDrawable.getHeight();
+        if (width != oldWidth || height != oldHeight) {
+            dirty = true;
+            oldWidth = width;
+            oldHeight = height;
+        }
+        
         GL gl = glDrawable.getGL();
 
         if (dirty || displayList == 0) {
+            if (displayList != 0) {
+                gl.glDeleteLists(displayList, 1);
+            }
             displayList = gl.glGenLists(1);
             gl.glNewList(displayList, GL.GL_COMPILE);
             privateRender(visRenderer);
@@ -277,18 +402,18 @@ public class ColorScale extends Observable implements Shape {
     }
 
     private void privateRender(VisRenderer visRenderer) {
-        GLDrawable glDrawable = visRenderer.getGLDrawable();
+        GLAutoDrawable glDrawable = visRenderer.getGLAutoDrawable();
 
         GL gl = glDrawable.getGL();
         if (enabled == false)
             return;
 
-        int width = (int) glDrawable.getSize().getWidth();
-        int height = (int) glDrawable.getSize().getHeight();
+        int glWidth = (int) glDrawable.getWidth();
+        int glHeight = (int) glDrawable.getHeight();
         gl.glMatrixMode(GL.GL_PROJECTION);
         gl.glPushMatrix();
         gl.glLoadIdentity();
-        gl.glOrtho(0, width, 0, height, -1.0f, 1.0f);
+        gl.glOrtho(0, glWidth, 0, glHeight, -1.0f, 1.0f);
 
         gl.glMatrixMode(GL.GL_MODELVIEW);
         gl.glPushMatrix();
@@ -297,18 +422,27 @@ public class ColorScale extends Observable implements Shape {
 
         gl.glDisable(GL.GL_LIGHTING);
         gl.glDisable(GL.GL_DEPTH_TEST);
-        gl.glDisable(GL.GL_LINE_SMOOTH);
-        gl.glDisable(GL.GL_BLEND);
         gl.glLineWidth(1.0f);
+        
+        if (visRenderer.getAntiAliasedLines()) {
+            gl.glEnable(GL.GL_LINE_SMOOTH);
+            gl.glEnable(GL.GL_BLEND);   
+            gl.glBlendFunc(GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA);
+            gl.glHint(GL.GL_LINE_SMOOTH_HINT, GL.GL_NICEST);
+        } else {
+            gl.glDisable(GL.GL_LINE_SMOOTH);
+            gl.glDisable(GL.GL_BLEND);   
+        }
 
-        int pixelHeight = Math.min(300, height - 60);
-        int pixelWidth = 25;
-        gl.glTranslated(25, (height / 2) - (pixelHeight / 2), 0);
+        int pixelHeight = Math.min(height, height - topBottomMargin);
+        int pixelWidth = width;
+        
+        gl.glTranslated(leftMargin, (glHeight / 2) - (pixelHeight / 2), 0);
 
+
+        // draw the actual scale as a set of 10 blended quads
         gl.glShadeModel(GL.GL_SMOOTH);
-
         gl.glFrontFace(GL.GL_CW);
-
         gl.glBegin(GL.GL_QUADS);
 
         int nBlocks = 10;
@@ -337,13 +471,37 @@ public class ColorScale extends Observable implements Shape {
             VisTools.glSetColor(gl, textColor);
         }
 
-        drawText(gl, pixelWidth / 2, pixelHeight + 10, highString);
-        drawText(gl, pixelWidth / 2, -15.0, lowString);
+        
+        // draw the upper string
+        float stringwidth;
+        float startx;
+        float bump;
+        
+        bump = 0;
+        stringwidth = getTextWidth(gl, highString);
+        startx = (pixelWidth / 2) - (stringwidth / 2);
+        if (startx < -leftMargin + leftTextMargin) {
+            bump = - startx - leftMargin + leftTextMargin;
+        }
+        drawText(gl, bump + pixelWidth / 2, pixelHeight, highString, false);
+        
 
+
+        // draw the lower string
+        bump = 0;
+        stringwidth = getTextWidth(gl, lowString);
+        startx = (pixelWidth / 2) - (stringwidth / 2);
+        if (startx < -leftMargin + leftTextMargin) {
+            bump = - startx - leftMargin + leftTextMargin;
+        }
+
+        drawText(gl, bump + pixelWidth / 2, 0, lowString, true);
+
+        // rotate and draw the label
         gl.glRotatef(90, 0, 0, 1);
-
-        drawText(gl, pixelHeight / 2, -pixelWidth - 15, label);
-
+        drawText(gl, pixelHeight / 2, -pixelWidth, label, true);
+        
+        
         gl.glPopMatrix();
 
         gl.glMatrixMode(GL.GL_PROJECTION);
@@ -355,4 +513,13 @@ public class ColorScale extends Observable implements Shape {
 
     }
 
+    public double getFontScale() {
+        return fontScale;
+    }
+
+    public void setFontScale(double fontScale) {
+        this.fontScale = fontScale;
+        this.dirty = true;
+    }
+
 }
