@@ -1,20 +1,19 @@
 /*
  * Shape.java
  *
- * Copyright 2005                                                 
- * Department of Computer and Information Science, University of Oregon
+ * Copyright 2005-2006                                
+ * Performance Research Laboratory, University of Oregon
  */
 package edu.uoregon.tau.vis;
 
-import net.java.games.jogl.*;
 
 
 /**
  * This interface is implemented by anything that the visRenderer draws.
  *    
- * <P>CVS $Id: Shape.java,v 1.2 2005/07/16 00:21:07 amorris Exp $</P>
+ * <P>CVS $Id: Shape.java,v 1.4 2006/11/16 17:50:36 amorris Exp $</P>
  * @author	Alan Morris
- * @version	$Revision: 1.2 $
+ * @version	$Revision: 1.4 $
  */
 public interface Shape {
 
