@@ -1,34 +1,42 @@
 /*
  * TriangleMeshPlot.java
  *
- * Copyright 2005                                                 
- * Department of Computer and Information Science, University of Oregon
+ * Copyright 2005-2006                                
+ * Performance Research Laboratory, University of Oregon
  */
 package edu.uoregon.tau.vis;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Observable;
 
-import javax.swing.*;
+import javax.media.opengl.GL;
+import javax.media.opengl.GLAutoDrawable;
+import javax.swing.BorderFactory;
+import javax.swing.JCheckBox;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JSlider;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
-import net.java.games.jogl.GL;
-import net.java.games.jogl.GLDrawable;
-import net.java.games.jogl.util.GLUT;
+import com.sun.opengl.util.GLUT;
 
 /**
  * Draws a 3d triangle mesh.
  * 
  * TODO: Back to front drawing (utilize 'direction') for correct blending.
  *
- * <P>CVS $Id: TriangleMeshPlot.java,v 1.2 2005/07/16 00:21:07 amorris Exp $</P>
+ * <P>CVS $Id: TriangleMeshPlot.java,v 1.5 2007/02/01 03:43:10 amorris Exp $</P>
  * @author	Alan Morris
- * @version	$Revision: 1.2 $
+ * @version	$Revision: 1.5 $
  */
 public class TriangleMeshPlot implements Plot {
 
@@ -100,7 +108,11 @@ public class TriangleMeshPlot implements Plot {
 
     public void setValues(float xSize, float ySize, float zSize, float heightValues[][], float colorValues[][]) {
         this.nrows = heightValues.length;
-        this.ncols = heightValues[0].length;
+        if (heightValues.length > 0) {
+            this.ncols = heightValues[0].length;
+        } else {
+            this.ncols = 0;
+        }
         this.heightValues = heightValues;
         this.colorValues = colorValues;
 
@@ -226,10 +238,10 @@ public class TriangleMeshPlot implements Plot {
     }
 
     public void render(VisRenderer visRenderer) {
-        GLDrawable glDrawable = visRenderer.getGLDrawable();
+        GLAutoDrawable glDrawable = visRenderer.getGLAutoDrawable();
         Vec direction = visRenderer.getViewDirection();
 
-//    public void render(GLDrawable glDrawable, Vec direction) {
+//    public void render(GLAutoDrawable glDrawable, Vec direction) {
 
         GL gl = glDrawable.getGL();
         if (gl == null)
