@@ -1,31 +1,51 @@
 /*
  * VisRenderer.java
  *
- * Copyright 2005                                                 
- * Department of Computer and Information Science, University of Oregon
+ * Copyright 2005-2006                                
+ * Performance Research Laboratory, University of Oregon
  */
 package edu.uoregon.tau.vis;
 
-import java.awt.*;
-import java.awt.event.*;
+import java.awt.Color;
+import java.awt.Dimension;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.InputEvent;
+import java.awt.event.MouseEvent;
+import java.awt.event.MouseListener;
+import java.awt.event.MouseMotionListener;
+import java.awt.event.MouseWheelEvent;
+import java.awt.event.MouseWheelListener;
 import java.awt.image.BufferedImage;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.swing.*;
+import javax.media.opengl.GL;
+import javax.media.opengl.GLAutoDrawable;
+import javax.media.opengl.GLEventListener;
+import javax.media.opengl.glu.GLU;
+import javax.swing.BorderFactory;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
+import javax.swing.JLabel;
+import javax.swing.JOptionPane;
+import javax.swing.JPanel;
+import javax.swing.JSlider;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
-import net.java.games.jogl.*;
-import net.java.games.jogl.util.BufferUtils;
+import com.sun.opengl.util.BufferUtil;
 
 /**
  * This object manages the JOGL interface.
  *    
- * <P>CVS $Id: VisRenderer.java,v 1.2 2005/07/16 00:21:08 amorris Exp $</P>
+ * <P>CVS $Id: VisRenderer.java,v 1.7 2006/11/16 17:50:36 amorris Exp $</P>
  * @author	Alan Morris
- * @version	$Revision: 1.2 $
+ * @version	$Revision: 1.7 $
  */
 public class VisRenderer implements GLEventListener, MouseListener, MouseMotionListener, MouseWheelListener {
 
@@ -59,11 +79,11 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
 
     private GL gl;
     private GLU glu;
-    private GLDrawable glDrawable;
+    private GLAutoDrawable glDrawable;
 
-    private Vec eye;                            // The location of the eye
-    private Vec aim = new Vec(0, 0, 0);         // Where the eye is focused at
-    private Vec vup;                            // The canonical V-up vector
+    private Vec eye; // The location of the eye
+    private Vec aim = new Vec(0, 0, 0); // Where the eye is focused at
+    private Vec vup; // The canonical V-up vector
 
     private Vec viewDirection;
 
@@ -71,19 +91,18 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
     final static private float lateralSense = 1 * rad;
     final static private float verticalSense = 1 * rad;
 
-    private double viewAltitude = -30 * rad;    // The angle from the x-y plane that the eye is placed 
-    private double viewAzimuth = -135 * rad;    // The angle on the x-y plane that the eye is placed
-    private double viewDistance = 50.0;         // The distance from the eye to the aim
-    private float fovy = 45.0f;                 // Field of view (y direction)
+    private double viewAltitude = -30 * rad; // The angle from the x-y plane that the eye is placed 
+    private double viewAzimuth = -135 * rad; // The angle on the x-y plane that the eye is placed
+    private double viewDistance = 50.0; // The distance from the eye to the aim
 
     private boolean reverseVideo = false;
 
     private Color backColor = Color.white;
     private Color foreColor = Color.black;
 
-    private List shapes = new ArrayList();      // The list of shapes to draw
+    private List shapes = new ArrayList(); // The list of shapes to draw
 
-    private float fps;                          // Frames per Second
+    private float fps; // Frames per Second
     private int framesRendered;
 
     private int width, height;
@@ -96,6 +115,24 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
     private VisAnimator visAnimator;
     private volatile float rotateSpeed = 0.5f;
 
+    private boolean antiAliasedLines = false;
+
+    private String glInfo_Vendor;
+    private String glInfo_Renderer;
+    private String glInfo_Version;
+    private boolean stereo_available;
+    private boolean stereo;
+
+    private JCheckBox stereoCheckBox;
+
+    private float camera_aperture = 45.0f;
+    private float camera_near = 1.0f;
+    private float camera_far = 500.0f;
+    private float camera_focallength = 50.0f;
+
+    private float DTOR = 0.0174532925f;
+    private float RTOD = 57.2957795f;
+
     public VisRenderer() {
     }
 
@@ -131,10 +168,10 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         //      float mat_shininess[] = { 50.0f };
         //    float mat_specular[] = { 1.0f, 1.0f, 1.0f, 1.0f };
 
-        gl.glLightfv(GL.GL_LIGHT0, GL.GL_POSITION, lightPosition);
-        gl.glLightfv(GL.GL_LIGHT0, GL.GL_DIFFUSE, whiteLight);
+        gl.glLightfv(GL.GL_LIGHT0, GL.GL_POSITION, lightPosition,0);
+        gl.glLightfv(GL.GL_LIGHT0, GL.GL_DIFFUSE, whiteLight,0);
         //        gl.glLightfv(GL.GL_LIGHT0, GL.GL_SPECULAR, whiteLight);
-        gl.glLightfv(GL.GL_LIGHT0, GL.GL_AMBIENT, ambientLight);
+        gl.glLightfv(GL.GL_LIGHT0, GL.GL_AMBIENT, ambientLight,0);
 
         //        gl.glMaterialfv(GL.GL_FRONT, GL.GL_SHININESS, mat_shininess);
         //        gl.glMaterialfv(GL.GL_FRONT, GL.GL_SPECULAR, mat_specular);
@@ -144,7 +181,7 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         //gl.glLightfv(GL.GL_LIGHT0, GL.GL_SPECULAR, whiteLight);
         //   gl.glLightfv(GL.GL_LIGHT1, GL.GL_AMBIENT, ambientLight);
 
-        gl.glLightModelfv(GL.GL_LIGHT_MODEL_AMBIENT, ambientLight);
+        gl.glLightModelfv(GL.GL_LIGHT_MODEL_AMBIENT, ambientLight,0);
         gl.glEnable(GL.GL_COLOR_MATERIAL);
         gl.glShadeModel(GL.GL_FLAT);
         gl.glEnable(GL.GL_LIGHTING);
@@ -157,20 +194,37 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
     /**
      * This method is called by JOGL, do not use.
      *
-     * @see net.java.games.jogl.GLEventListener#init(net.java.games.jogl.GLDrawable)
+     * @see net.java.games.jogl.GLEventListener#init(net.java.games.jogl.GLAutoDrawable)
      * 
      * @param drawable	The drawable provided by JOGL
      */
-    public void init(GLDrawable drawable) {
+    public void init(GLAutoDrawable drawable) {
         gl = drawable.getGL();
-        glu = drawable.getGLU();
+        glu = new GLU();
         this.glDrawable = drawable;
 
         VisTools.verr(this, "Initializing OpenGL (JOGL)");
-        VisTools.verr(this, "INIT GL IS: " + gl.getClass().getName());
+        VisTools.verr(this, "JOGL Class: " + gl.getClass().getName());
         VisTools.verr(this, "GL_VENDOR: " + gl.glGetString(GL.GL_VENDOR));
         VisTools.verr(this, "GL_RENDERER: " + gl.glGetString(GL.GL_RENDERER));
         VisTools.verr(this, "GL_VERSION: " + gl.glGetString(GL.GL_VERSION));
+        glInfo_Vendor = gl.glGetString(GL.GL_VENDOR);
+        glInfo_Renderer = gl.glGetString(GL.GL_RENDERER);
+        glInfo_Version = gl.glGetString(GL.GL_VERSION);
+
+        byte[] bytes = new byte[1];
+        gl.glGetBooleanv(GL.GL_STEREO, bytes,0);
+        if (bytes[0] != 0) {
+            stereo_available = true;
+            VisTools.verr(this, "OpenGL Stereo is available");
+        } else {
+            stereo_available = false;
+            VisTools.verr(this, "OpenGL Stereo is not available");
+        }
+
+        if (stereoCheckBox != null) {
+            stereoCheckBox.setEnabled(stereo_available);
+        }
 
         gl.glEnable(GL.GL_CULL_FACE);
         gl.glEnable(GL.GL_DEPTH_TEST);
@@ -202,18 +256,18 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         if (aim == null)
             return;
 
-        //System.out.println ("viewAngle now " + viewAngle);
-        //System.out.println ("viewDirection now " + viewDirection);
+        //System.out.println ("viewAltitude now " + viewAltitude);
+        //System.out.println ("viewAzimuth now " + viewAzimuth);
 
-        eye = new Vec((float) Math.cos(viewAltitude), 0.0f, (float) Math.sin(viewAltitude));
-
-        eye.sety(eye.x() * Math.sin(viewAzimuth));
-        eye.setx(eye.x() * Math.cos(viewAzimuth));
+        Matrix rotateY = Matrix.createRotateY(-viewAltitude);
+        Matrix rotateZ = Matrix.createRotateZ(viewAzimuth);
 
+        eye = rotateZ.transform(rotateY.transform(new Vec(1, 0, 0)));
         eye.normalize();
 
-        vup = new Vec(0.0, 0.0, 1.0);
-        vup = vup.subtract(eye);
+        // set the canonical v-up vector
+        vup = rotateZ.transform(rotateY.transform(new Vec(0, 0, 1)));
+
         eye.setx(eye.x() * viewDistance);
         eye.sety(eye.y() * viewDistance);
         eye.setz(eye.z() * viewDistance);
@@ -321,14 +375,19 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
 
     /**
      * This method is called by JOGL, do not use.
-     * @see net.java.games.jogl.GLEventListener#reshape(net.java.games.jogl.GLDrawable, int, int, int, int)
+     * @see net.java.games.jogl.GLEventListener#reshape(net.java.games.jogl.GLAutoDrawable, int, int, int, int)
      */
-    public void reshape(GLDrawable drawable, int x, int y, int width, int height) {
+    public void reshape(GLAutoDrawable drawable, int x, int y, int width, int height) {
         this.width = width;
         this.height = height;
+
+        //camera_aperture = 45.0f;
+        camera_near = 1.0f;
+        camera_far = 500.0f;
+
         gl.glMatrixMode(GL.GL_PROJECTION);
         gl.glLoadIdentity();
-        glu.gluPerspective(45, (float) width / (float) height, 1.0f, 500.0f);
+        glu.gluPerspective(camera_aperture, (float) width / (float) height, camera_near, camera_far);
         gl.glMatrixMode(GL.GL_MODELVIEW);
         gl.glLoadIdentity();
     }
@@ -337,47 +396,118 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
      * This method is called by JOGL, do not use.
      * To force a redraw, use VisRenderer.redraw()
      *
-     * @see net.java.games.jogl.GLEventListener#display(net.java.games.jogl.GLDrawable)
+     * @see net.java.games.jogl.GLEventListener#display(net.java.games.jogl.GLAutoDrawable)
      */
-    public void display(GLDrawable drawable) {
+    public void display(GLAutoDrawable drawable) {
 
         reshape(drawable, 0, 0, this.getWidth(), this.getHeight());
 
-        //        gl = new DebugGL(drawable.getGL());
-
-        //        gl.glClearColor(1.0f, 1.0f, 1.0f, 1.0f);
-
-        if (reverseVideo) {
-            //gl.glClearColor(0.75f, 0.75f, 0.75f, 1.0f);
-            gl.glClearColor(238 / 255.0f, 238 / 255.0f, 238 / 255.0f, 1.0f);
-        } else {
-            gl.glClearColor(0, 0, 0, 0);
-        }
-        gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
-
-        gl.glPushMatrix();
-        gl.glTranslated(0, 0, -viewDistance);
-
-        setLighting();
-
-        if (aim == null) {
-            aim = new Vec(0, 0, 0);
-        }
-        glu.gluLookAt(aim.x(), aim.y(), aim.z(), eye.x(), eye.y(), eye.z(), vup.x(), vup.y(), vup.z());
-
-        viewDirection = eye.subtract(aim);
-
-        for (int i = 0; i < shapes.size(); i++) {
-            Shape shape = (Shape) shapes.get(i);
-            shape.render(this);
+        int n = 1;
+        if (stereo) {
+            n = 2;
         }
 
-        //        int err = gl.glGetError();
-        //        if (err != GL.GL_NO_ERROR)
-        //            System.out.println("err = " + glu.gluErrorString(err));
+        for (int frame = 0; frame < n; frame++) {
 
-        gl.glPopMatrix();
-        framesRendered++;
+            if (stereo) {
+                if (frame == 0) {
+                    gl.glDrawBuffer(GL.GL_BACK_LEFT);
+                } else {
+                    gl.glDrawBuffer(GL.GL_BACK_RIGHT);
+                }
+            } else {
+                gl.glDrawBuffer(GL.GL_BACK);
+            }
+            //        gl = new DebugGL(drawable.getGL());
+            //        gl.glClearColor(1.0f, 1.0f, 1.0f, 1.0f);
+
+            if (reverseVideo) {
+                //gl.glClearColor(0.75f, 0.75f, 0.75f, 1.0f);
+                gl.glClearColor(238 / 255.0f, 238 / 255.0f, 238 / 255.0f, 1.0f);
+            } else {
+                gl.glClearColor(0, 0, 0, 0);
+            }
+            gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
+
+            gl.glPushMatrix();
+            gl.glTranslated(0, 0, -viewDistance);
+
+            setLighting();
+
+            if (aim == null) {
+                aim = new Vec(0, 0, 0);
+            }
+
+            if (stereo) {
+
+                float eyesep, wd2, ratio, radians;
+
+                //camera_focallength = 50.0f;
+                //camera_aperture = 45.0f;
+                camera_near = 1.0f;
+                camera_far = 500.0f;
+
+                eyesep = camera_focallength / 20;
+
+                ratio = (float) this.width / (float) this.height;
+                radians = DTOR * camera_aperture / 2;
+                wd2 = (float) (camera_near * Math.tan(radians));
+
+                // direction vector
+                Vec direction = eye.subtract(aim);
+
+                // cross product of v-up and the view direction will give us the normal, which is the axis the eyes are on
+                // we will add and subtract this vector to move to the left and right eye
+                Vec crossRight = direction.cross(vup);
+                crossRight.normalize();
+                crossRight.scale((float) (eyesep / 2.0));
+
+                float leftRightFrustumShift;
+
+                if (frame == 0) {
+                    leftRightFrustumShift = 0.5f;
+                } else {
+                    leftRightFrustumShift = -0.5f;
+                }
+
+                // create a parallel axis asymmetric frustum perspective projection
+                float left, right, top, bottom;
+                gl.glMatrixMode(GL.GL_PROJECTION);
+                gl.glLoadIdentity();
+                float ndfl = camera_near / camera_focallength;
+                left = (float) (-ratio * wd2 + leftRightFrustumShift * eyesep * ndfl);
+                right = (float) (ratio * wd2 + leftRightFrustumShift * eyesep * ndfl);
+                top = wd2;
+                bottom = -wd2;
+                gl.glFrustum(left, right, bottom, top, camera_near, camera_far);
+                gl.glMatrixMode(GL.GL_MODELVIEW);
+
+                if (frame == 0) {
+                    glu.gluLookAt(aim.x() - crossRight.x(), aim.y() - crossRight.y(), aim.z() - crossRight.z(), eye.x()
+                            - crossRight.x(), eye.y() - crossRight.y(), eye.z() - crossRight.z(), vup.x(), vup.y(), vup.z());
+                } else {
+                    glu.gluLookAt(aim.x() + crossRight.x(), aim.y() + crossRight.y(), aim.z() + crossRight.z(), eye.x()
+                            + crossRight.x(), eye.y() + crossRight.y(), eye.z() + crossRight.z(), vup.x(), vup.y(), vup.z());
+                }
+            } else {
+                glu.gluLookAt(aim.x(), aim.y(), aim.z(), eye.x(), eye.y(), eye.z(), vup.x(), vup.y(), vup.z());
+            }
+
+            viewDirection = eye.subtract(aim);
+
+            for (int i = 0; i < shapes.size(); i++) {
+                Shape shape = (Shape) shapes.get(i);
+                shape.render(this);
+            }
+
+            //        int err = gl.glGetError();
+            //        if (err != GL.GL_NO_ERROR)
+            //            System.out.println("err = " + glu.gluErrorString(err));
+
+            gl.glPopMatrix();
+            framesRendered++;
+
+        }
 
         // if screenshot was requested since last draw
         if (makeScreenShot) {
@@ -386,12 +516,13 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         }
 
     }
+    
+    private void makeScreenShot(GLAutoDrawable drawable) {
+    	
+        int width = drawable.getWidth();
+        int height = drawable.getHeight();
 
-    private void makeScreenShot(GLDrawable drawable) {
-        int width = drawable.getSize().width;
-        int height = drawable.getSize().height;
-
-        ByteBuffer pixelsRGB = BufferUtils.newByteBuffer(width * height * 3);
+        ByteBuffer pixelsRGB = BufferUtil.newByteBuffer(width * height * 3);
 
         GL gl = drawable.getGL();
 
@@ -433,7 +564,7 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         screenShot.setRGB(0, 0, width, height, pixelInts, 0, width);
     }
 
-    public void displayChanged(GLDrawable drawable, boolean modeChanged, boolean deviceChanged) {
+    public void displayChanged(GLAutoDrawable drawable, boolean modeChanged, boolean deviceChanged) {
     }
 
     // Methods required for the implementation of MouseListener
@@ -505,7 +636,6 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         glDrawable.display();
     }
 
-    
     /**
      * Zooms the camera out by multiplying the distance between the <tt>aim</tt> and <tt>eye</tt> by <tt>1.1</tt>.
      */
@@ -563,7 +693,6 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         return width;
     }
 
-    
     /**
      * Returns the point (as a <tt>Vec</tt>) that the camera is located.
      * @return the point (as a <tt>Vec</tt>) that the camera is located.
@@ -605,7 +734,7 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         panel.setBorder(BorderFactory.createLoweredBevelBorder());
         panel.setLayout(new GridBagLayout());
 
-        final JCheckBox rotateCheckBox = new JCheckBox("Rotate", visAnimator != null);
+        final JCheckBox rotateCheckBox = new JCheckBox("Auto-Rotate", visAnimator != null);
         rotateCheckBox.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent evt) {
                 try {
@@ -634,8 +763,44 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
             }
         });
 
-        final JSlider speedSlider = new JSlider(0, 200, (int) (Math.sqrt(rotateSpeed) * 100));
+        final JCheckBox antialiasCheckBox = new JCheckBox("Anti-Aliased Lines", antiAliasedLines);
+        antialiasCheckBox.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                try {
+                    setAntiAliasedLines(antialiasCheckBox.isSelected());
+                } catch (Exception e) {
+                    VisTools.handleException(e);
+                }
+            }
+        });
 
+        stereoCheckBox = new JCheckBox("Stereo", stereo);
+        stereoCheckBox.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                try {
+                    setStereo(stereoCheckBox.isSelected());
+                } catch (Exception e) {
+                    VisTools.handleException(e);
+                }
+            }
+        });
+        stereoCheckBox.setEnabled(stereo_available);
+
+        final JSlider focalLengthSlider = new JSlider(0, 200, (int) camera_focallength);
+        focalLengthSlider.addChangeListener(new ChangeListener() {
+            public void stateChanged(ChangeEvent event) {
+                setCamera_focallength(focalLengthSlider.getValue());
+            }
+        });
+
+        final JSlider apertureSlider = new JSlider(0, 90, (int) camera_aperture);
+        apertureSlider.addChangeListener(new ChangeListener() {
+            public void stateChanged(ChangeEvent event) {
+                setCamera_aperture(apertureSlider.getValue());
+            }
+        });
+
+        final JSlider speedSlider = new JSlider(0, 200, (int) (Math.sqrt(rotateSpeed) * 100));
         speedSlider.addChangeListener(new ChangeListener() {
             public void stateChanged(ChangeEvent event) {
                 try {
@@ -647,23 +812,50 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
             }
         });
 
+        final JButton glInfoButton = new JButton("GL Info");
+        glInfoButton.addActionListener(new ActionListener() {
+
+            public void actionPerformed(ActionEvent e) {
+                String message = "JOGL Class: " + gl.getClass().getName() + "\n" + "GL_VENDOR: " + glInfo_Vendor + "\n"
+                        + "GL_RENDERER: " + glInfo_Renderer + "\n" + "GL_VERSION: " + glInfo_Version;
+
+                JOptionPane.showMessageDialog(glInfoButton, message);
+            }
+
+        });
+
         GridBagConstraints gbc = new GridBagConstraints();
         gbc.insets = new Insets(5, 5, 5, 5);
         gbc.weighty = 0.2;
-        gbc.weightx = 0.1;
+        gbc.weightx = 0.5;
 
         gbc.fill = GridBagConstraints.NONE;
         gbc.anchor = GridBagConstraints.WEST;
-        VisTools.addCompItem(panel, rotateCheckBox, gbc, 0, 0, 1, 2);
+        VisTools.addCompItem(panel, rotateCheckBox, gbc, 0, 0, 2, 2);
 
         gbc.anchor = GridBagConstraints.CENTER;
-        gbc.weightx = 0.9;
+        gbc.weightx = 0.5;
         gbc.fill = GridBagConstraints.NONE;
-        VisTools.addCompItem(panel, new JLabel("Speed"), gbc, 1, 0, 1, 1);
+        VisTools.addCompItem(panel, new JLabel("Speed"), gbc, 2, 0, 1, 1);
         gbc.fill = GridBagConstraints.HORIZONTAL;
-        VisTools.addCompItem(panel, speedSlider, gbc, 1, 1, 1, 1);
+        VisTools.addCompItem(panel, speedSlider, gbc, 2, 1, 1, 1);
 
-        VisTools.addCompItem(panel, reverseCheckBox, gbc, 0, 2, 2, 1);
+        VisTools.addCompItem(panel, reverseCheckBox, gbc, 0, 2, 3, 1);
+        VisTools.addCompItem(panel, antialiasCheckBox, gbc, 0, 3, 3, 1);
+        VisTools.addCompItem(panel, stereoCheckBox, gbc, 0, 4, 3, 1);
+        gbc.weightx = 0.1;
+        VisTools.addCompItem(panel, new JLabel("Separation"), gbc, 0, 5, 1, 1);
+        VisTools.addCompItem(panel, new JLabel("Aperture"), gbc, 0, 6, 1, 1);
+        gbc.fill = GridBagConstraints.BOTH;
+        gbc.weightx = 0.9;
+        
+        gbc.anchor = GridBagConstraints.CENTER;
+        VisTools.addCompItem(panel, focalLengthSlider, gbc, 1, 5, 2, 1);
+        VisTools.addCompItem(panel, apertureSlider, gbc, 1, 6, 2, 1);
+
+        gbc.fill = GridBagConstraints.NONE;
+        gbc.anchor = GridBagConstraints.CENTER;
+        VisTools.addCompItem(panel, glInfoButton, gbc, 0, 7, 3, 1);
 
         return panel;
     }
@@ -686,10 +878,10 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
     }
 
     /**
-     * Returns the <tt>GLDrawable</tt> for this <tt>VisRenderer</tt>.
-     * @return the <tt>GLDrawable</tt> for this <tt>VisRenderer</tt>.
+     * Returns the <tt>GLAutoDrawable</tt> for this <tt>VisRenderer</tt>.
+     * @return the <tt>GLAutoDrawable</tt> for this <tt>VisRenderer</tt>.
      */
-    public GLDrawable getGLDrawable() {
+    public GLAutoDrawable getGLAutoDrawable() {
         return glDrawable;
     }
 
@@ -702,4 +894,40 @@ public class VisRenderer implements GLEventListener, MouseListener, MouseMotionL
         return viewDirection;
     }
 
+    public boolean getAntiAliasedLines() {
+        return antiAliasedLines;
+    }
+
+    public void setAntiAliasedLines(boolean antiAliasedLines) {
+        this.antiAliasedLines = antiAliasedLines;
+        this.redraw();
+    }
+
+    public boolean getStereo() {
+        return stereo;
+    }
+
+    public void setStereo(boolean stereo) {
+        this.stereo = stereo;
+        this.redraw();
+    }
+
+    public float getCamera_focallength() {
+        return camera_focallength;
+    }
+
+    public void setCamera_focallength(float camera_focallength) {
+        this.camera_focallength = Math.max(1.0f, camera_focallength);
+        this.redraw();
+    }
+
+    public float getCamera_aperture() {
+        return camera_aperture;
+    }
+
+    public void setCamera_aperture(float camera_aperture) {
+        this.camera_aperture = camera_aperture;
+        this.redraw();
+    }
+
 }
\ No newline at end of file
