@@ -1,26 +1,35 @@
 /*
  * VisTools.java
  *
- * Copyright 2005                                                 
- * Department of Computer and Information Science, University of Oregon
+ * Copyright 2005-2006                                
+ * Performance Research Laboratory, University of Oregon
  */
 package edu.uoregon.tau.vis;
 
-import java.awt.*;
-import net.java.games.jogl.GL;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.Container;
+import java.awt.GridBagConstraints;
+
+import javax.media.opengl.GL;
 
 /**
  * Various utility methods for the vis package.
  * 
- * <P>CVS $Id: VisTools.java,v 1.2 2005/07/16 00:21:08 amorris Exp $</P>
+ * <P>CVS $Id: VisTools.java,v 1.4 2006/11/16 17:50:36 amorris Exp $</P>
  * @author  Alan Morris
- * @version $Revision: 1.2 $
+ * @version $Revision: 1.4 $
  */
 public class VisTools {
-
+    
     // Exception handler for Swing elements
     private static ExceptionHandler exceptionHandler;
 
+    public static final double fontHeight = 105+34;
+    public static final double fontAscent = 105;
+    public static final double fontDescent = 34;
+    
+    
     /**
      * Helper function to call glColor3f.
      * @param gl GL object to use.
@@ -39,9 +48,9 @@ public class VisTools {
      */
     public static void glApplyInvertableColor(VisRenderer visRenderer, Color c) {
         if (visRenderer.getReverseVideo()) {
-            glSetColor(visRenderer.getGLDrawable().getGL(), invert(c));
+            glSetColor(visRenderer.getGLAutoDrawable().getGL(), invert(c));
         } else {
-            glSetColor(visRenderer.getGLDrawable().getGL(), c);
+            glSetColor(visRenderer.getGLAutoDrawable().getGL(), c);
         }
     }
 
