@@ -232,14 +232,18 @@ public class RunTauJava implements IObjectActionDelegate {
 
 			appMap.put("PATH",lpath);
 		}
-		else{
+		else{//not windows... presumibly *ix
 		//wc.setAttribute(IJavaLaunchConfigurationConstants.ATTR_VM_ARGUMENTS,"-XrunTAU:nomethods -Djava.library.path="+lpath);///home/wspear/tau2/i386_linux/lib");
 		appMap.put("LD_LIBRARY_PATH",lpath);
 		
-		pdir=tdir=new File(builddir+ftime);
-		predir=tredir=new File(pdir.getPath()+File.separator+"Re-Run");
+		pdir=new File(builddir+"profile"+File.separator+ftime);
+		tdir=new File(builddir+"trace"+File.separator+ftime);
+		predir=new File(pdir.getPath()+File.separator+"Re-Run");
+		tredir=new File(tdir.getPath()+File.separator+"Re-Run");
 		pdir.mkdirs();
 		predir.mkdirs();
+		tdir.mkdirs();
+		tredir.mkdirs();
 		appMap.put("TRACEDIR",tdir.getPath());
 		appMap.put("PROFILEDIR",pdir.getPath());
 		toutput=4;
@@ -249,8 +253,10 @@ public class RunTauJava implements IObjectActionDelegate {
 		ILaunchConfiguration config = wc.doSave();   
 		//System.out.println(lm.getEnvironment(config));
 		//ILaunch taurun = 
+		
 			ILaunch x = config.launch(ILaunchManager.RUN_MODE, null);
-			
+		
+			//Once the program is run once set all subsequent runs to tbe placed in the Re-Run folder
 			switch(toutput){
 			case 1: appMap.put("TRACEDIR",tredir.getPath()); break;
 			case 2: appMap.put("PROFILEDIR",predir.getPath()); break;
@@ -264,21 +270,37 @@ public class RunTauJava implements IObjectActionDelegate {
 				appMap.put("TRACEDIR",tredir.getPath());
 				break;
 			}
-			
 			wc.setAttribute(ILaunchManager.ATTR_ENVIRONMENT_VARIABLES,appMap);
 			config = wc.doSave();
 			
-			
+			//wait for it...
 			try {
 				while(!x.isTerminated())
 				{Thread.sleep(1000);}//Thread.sleep(1000);
 			} catch (InterruptedException e1) {
-				// TODO Auto-generated catch block
+				// TO DO Auto-generated catch block
 				e1.printStackTrace();
 			}
 			
+			//If on a unix system delete any output folder that contains no output
+			//(We only create used output folders on windows)
+			if(!iswin){
+				File[] plist = pdir.listFiles();
+				File[] tlist = tdir.listFiles();
+				
+				if(plist.length==1){
+					plist[0].delete();
+					pdir.delete();
+				}
+				
+				if(tlist.length==1){
+					tlist[0].delete();
+					tdir.delete();
+				}				
+			}
 			
 			boolean para = pstore.getBoolean("runParaProf");
+			//If use of paraprof is specefied and a profile file has been produced, proceed
 			if(para && toutput > 1)
 			{
 			if(iswin){
@@ -292,7 +314,7 @@ public class RunTauJava implements IObjectActionDelegate {
 					//System.out.println(prun); exec(prun);//"."+File.separator+
 					Runtime.getRuntime().exec("cmd /c start paraprof.bat \""+pdir.getPath()+"\"", null, taubin);
 				} catch (IOException e) {
-					// TODO Auto-generated catch block
+					// TO DO Auto-generated catch block
 					e.printStackTrace();
 				}
 			}
@@ -305,7 +327,7 @@ public class RunTauJava implements IObjectActionDelegate {
 					
 					Runtime.getRuntime().exec(paracmd+pdir.getPath());
 				} catch (IOException e) {
-					// TODO Auto-generated catch block
+					// TO DO Auto-generated catch block
 					e.printStackTrace();
 				}
 			}
