@@ -1,7 +1,5 @@
 package edu.uoregon.tau.taujava.preferences;
 
-
-
 import edu.uoregon.tau.taujava.TaujavaPlugin;
 import org.eclipse.jface.preference.*;
 import org.eclipse.ui.IWorkbenchPreferencePage;
@@ -40,7 +38,9 @@ public class TauJavaPrefs
 	public static final String TWIN_DLL = "tauWinDLLPreference";
 //	Used to indicate if paraprof should be run on profile output
 	public static final String PARA_BOOL = "runParaProf";
-
+//	Used to indicate which tau-jdk library to use.
+	public static final String TIX_LIB = "tauIxLibPref";
+	
 	public TauJavaPrefs() {
 		super(GRID);
 		setPreferenceStore(TaujavaPlugin.getDefault().getPreferenceStore());
@@ -64,17 +64,22 @@ public class TauJavaPrefs
  */
 
 	public void createFieldEditors() {
-		addField(new FileFieldEditor(EX_PATH, 
-				"&Selective Instrumentation File:", getFieldEditorParent()));
-		addField(
-			new BooleanFieldEditor(
-				EX_BOOLEAN,
-				"&Enable Selective Instrumentation.",
-				getFieldEditorParent()));
+		
+		
 		//addField(new FileFieldEditor(TLIB_PATH, "&Jar file containing TAU definitions:", getFieldEditorParent()));
 		addField(new DirectoryFieldEditor(TDIR_PATH, 
 				"&TAU Library Directory:", getFieldEditorParent()));
 
+		addField(
+				new BooleanFieldEditor(
+					EX_BOOLEAN,
+					"&Enable Selective Instrumentation?",
+					getFieldEditorParent()));
+		addField(new FileFieldEditor(EX_PATH, 
+				"&Selective Instrumentation File:", getFieldEditorParent()));
+
+
+
 		addField(new BooleanFieldEditor(DEF_OUT,"&Use Alternative TAU Output Directory?",getFieldEditorParent()));
 		addField(new DirectoryFieldEditor(USR_OUT, "&Alternate TAU Output Directory:", getFieldEditorParent()));
 		addField(new BooleanFieldEditor(PARA_BOOL,"&Automatically run ParaProf on profile output?",getFieldEditorParent()));
@@ -82,13 +87,19 @@ public class TauJavaPrefs
 		//Only check for .dlls in windows
 		if((System.getProperty("os.name","").toLowerCase()).indexOf("windows")!=-1)
 		{
-			
 			addField(new RadioGroupFieldEditor(TWIN_DLL, 
 					"&TAU Analysis Method:",1, 
 					new String[][]{
 					{"Profile","tau-profile.dll"},{"Callpath","tau-callpath.dll"},{"Trace","tau-trace.dll"}}, 
 			getFieldEditorParent()));
 		}
+		else
+		{
+			/*addField(new RadioGroupFieldEditor(TIX_LIB, 
+					"&TAU Analysis Method:",1,
+					new String[][]{},
+					getFieldEditorParent()));*/
+		}
 		
 	}
 	
