@@ -27,6 +27,7 @@
 #define DRAW_TRUE    1
 #define DRAW_FALSE   0
 
+
 #define  MAX_LEGEND_LEN  128
 #define  MAX_LABEL_LEN   512
 #define  MAX_LINE_LEN    1024
@@ -149,6 +150,8 @@ int maxidx = 0;
 
 /*/Contains one element for each node, with each element holding the number of threads at that node*/
 int *countthreads = NULL;
+/*size of countthreads*/
+int sizectds = 0;
 
 /* FIX GlobalID so it takes into account numthreads */
 /* utilities*/
@@ -392,23 +395,11 @@ int rows = 0;
 int DefThread(void *userData, unsigned int nodeToken, unsigned int threadToken,
 const char *threadName )
 {
-	int i;
- dprintf("DefThread nid %d tid %d, thread name %s\n", 
+	dprintf("DefThread nid %d tid %d, thread name %s\n", 
 		  nodeToken, threadToken, threadName);
-    numthreads++;/*/Increment the total number of threads*/
-  /*/If this is the first thread entry we see*/
-  if(countthreads == NULL)
-  {/*/Create a new int array for count threads*/
-	countthreads = (int *) malloc((nodeToken+1)*sizeof(int));
-	/*/Set the thread count for this node*/
-	countthreads[nodeToken] = threadToken;
-
-	for(i = 0; i<nodeToken;i++)
-		countthreads[i] = 0;
-  }
-  else
-  {/*/Otherwise expand the size of the array and increase the thread counts as necessary*/
-	if(nodeToken<maxnode)
+	numthreads++;/*/Increment the total number of threads*/
+/*/Otherwise expand the size of the array and increase the thread counts as necessary*/
+	if(nodeToken<sizectds)
 	{
 		if(countthreads[nodeToken] < threadToken)
 			countthreads[nodeToken] = threadToken;
@@ -416,32 +407,30 @@ const char *threadName )
 	else
 	{
 		int i;
-		int *temp = (int *) malloc((nodeToken+1)*sizeof(int));
-		for(i  = 0; i<nodeToken; i++)
+		int tempsize = sizectds;
+		sizectds=nodeToken*2;
+		countthreads=realloc(countthreads,sizectds*sizeof(int));
+		for(i=tempsize;i<sizectds;i++)
 		{
-			temp[i] = countthreads[i];
-		}
-		temp[nodeToken] = threadToken;
-		free(countthreads);
-		countthreads = NULL;
-		countthreads = temp;
-		temp = NULL;
-		}
-  }
+			countthreads[i]=0;
+		}		
+		countthreads[nodeToken] = threadToken;
+	}
   /*/Set the maximum and minimum node size observed (Unused?!)*/
-  if(nodeToken > maxnode)
-	maxnode = nodeToken;
-	
+	if(nodeToken > maxnode)
+		maxnode = nodeToken;
+
 	if(threadToken > maxthrd)
 		maxthrd = threadToken;
 		/*/If we have any threads this is a threaded program*/
-    
 
-  if (threadToken > 0) multiThreaded = 1; 
-  
-  rows++;/*/Redundant with numthreaeds?!*/
-
-  
+	if (threadToken > 0) multiThreaded = 1; 
+	rows++;/*/Redundant with numthreaeds?!*/
+/*printf("%d X %d\n",nodeToken, threadToken);
+int x;
+for(x=0;x<sizectds;x++)
+	printf("%d: %d\n",x,countthreads[x]);
+printf("%d - %d\n",maxnode, sizectds);*/
   return 0;
 }
 
@@ -455,7 +444,7 @@ int EndTrace( void *userData, unsigned int nodeToken, unsigned int threadToken)
 {
   dprintf("EndTrace nid %d tid %d\n", nodeToken, threadToken);
   countstops += 1; /*/Count the total number of eof markers (first pass)*/
-  numstops -= 1;  /*//Count down through all eof markers (second pass)*/
+  numstops -= 1;  /*Count down through all eof markers (second pass)*/
   if(numstops <= 0)
   {
 	currentkind = (int)TRACE_EOF; 
@@ -890,7 +879,7 @@ int DefState( void *userData, unsigned int stateToken, const char *stateName,
     TRACE_Category_head_t *hdr;
 
     int             type_idx = stateToken;
-    int             line_pos;
+    //int             line_pos;
 
     char           *newline;
     
@@ -924,7 +913,7 @@ int DefState( void *userData, unsigned int stateToken, const char *stateName,
 
 	memcpy(legend,  name, strlen(name)+1);
     legend_len  = strlen( legend );
-    newline     = (char *) (((TRACE_file)userData)->line + line_pos);
+    newline     = (char *) (((TRACE_file)userData)->line);// + line_pos
 
         label_len = 0;
 #if defined( DEBUG )
@@ -1194,9 +1183,10 @@ int LeaveState(void *userData, double time, unsigned int nid, unsigned int tid,
 	       unsigned int stateid)
 {
   
-  //printf("I\n");
+
   
 	struct event_stack *temp = top;
+	struct event_stack *prev = NULL;
 	int found = 0;
 	DRAW_Category  *type;
     DRAW_Primitive *prime;
@@ -1212,26 +1202,33 @@ enters--;
 
 	while(found == 0)
 	{
-		if(temp == NULL){dprintf("BROKE!\n"); break;}
+		if(temp == NULL){printf("Fault: Exit Without Enter.\n"); break;}
 		
 		if((nid == temp->nid) && (tid == temp->tid))
 		{
 			found = 1;
+
+			if (prev) {
+			  prev->next = temp->next;
+			} else {
+			  top = top->next;
+			}
 			
-			if(temp->next != NULL)
-				temp->next->last = temp->last;
+/* 			if(temp->next != NULL) */
+/* 				temp->next->last = temp->last; */
 			
-			if(temp->last != NULL && temp->next != NULL)
-				temp->last->next = temp->next; 
+/* 			if(temp->last != NULL && temp->next != NULL) */
+/* 				temp->last->next = temp->next; */
 				
-			if(temp->last == NULL)
-				top = temp->next;
+/* 			if(temp->last == NULL) */
+/* 				top = temp->next; */
 				
 			
 			((TRACE_file)userData)->event_count--;
 		}
 		else
 		{
+			prev = temp;
 			temp = temp->next;
 		}
 		
@@ -1285,7 +1282,7 @@ enters--;
   
   currentkind = (int)TRACE_PRIMITIVE_DRAWABLE;
   thispeak = 1;
-  //dprintf("Left!\n");
+
   return 0;
 }
 
@@ -1817,9 +1814,10 @@ int TRACE_Open( const char filespec[], TRACE_file *fp )
 	offset = (int *)malloc((numnodes+1)*sizeof(int));
 	
 	offset[0] = 0;
+	//if(maxnode>0)
 	for(i = 0; i<=maxnode; i++)
 	{
-		offset[i+1] = offset[i] + countthreads[i];
+		offset[i+1] = offset[i] + countthreads[i]+1;
 	}
   }
   
@@ -1912,11 +1910,11 @@ int TRACE_Peek_next_kind( const TRACE_file fp, TRACE_Rec_Kind_t *next_kind )
 		thispeak = 0;
 		while(thispeak == 0)
 		{
-			//printf("Goodie!:%d\n",next_kind);
 			recs_read = Ttf_ReadNumEvents(fp->fd,cb, 1);
 			if(recs_read==0){break;}
 		}
 		thispeak = 0;
+//printf("Upper: %d\n",currentkind);
 		if(currentkind==(int)TRACE_EOF){posteof=1;}
 		else{
 			*next_kind = (TRACE_Rec_Kind_t)currentkind;
@@ -1927,10 +1925,10 @@ int TRACE_Peek_next_kind( const TRACE_file fp, TRACE_Rec_Kind_t *next_kind )
 	/*If the trace ends with unresolved enters call LeaveState directly so
 	the events are shown.   */
 	if(enters>0&&posteof==1){
-		//debugPrint = 1;
-		//dprintf("Enter %d.  nid:%d tid:%d time:%d\n",enters,top->nid,top->tid,finexit);
-		LeaveState(fp,finexit,top->nid,top->tid,0);
+
+		LeaveState(fp,finexit,top->nid,top->tid,top->sid);//top->sid was 0
 		*next_kind = (TRACE_Rec_Kind_t)currentkind;
+		//printf("Batt: %d\n",currentkind);
 		return 0;
 	}
 	
@@ -1943,14 +1941,14 @@ int TRACE_Peek_next_kind( const TRACE_file fp, TRACE_Rec_Kind_t *next_kind )
 	
 	if(posteof==1)
 	{
-		*next_kind = (int)TRACE_EOF;//(TRACE_Rec_Kind_t)currentkind;
-
+		*next_kind = (int)TRACE_EOF;
+		//printf("Done: %d\n",currentkind);
 		return 0;
 	}
 
 	
 	*next_kind = (TRACE_Rec_Kind_t)currentkind;
-
+printf("Out: %d\n",currentkind);
 	return 0;
 }
 
@@ -2557,41 +2555,7 @@ int TRACE_Peek_next_ycoordmap( TRACE_file fp,
 		}
 	}	
 	
-    /*    sscanf( newline, "( %d %n", &map_elems[ idx++ ], &line_pos ); 
-        //newline = (char *) (newline+line_pos);
-#if defined( DEBUG )
-        printf( "%d -> ", map_elems[ idx-1 ] );
-#endif
-        for ( icol = 1; icol < Ncols-1; icol++ ) {
-            sscanf( newline, "%d %n", &map_elems[ idx++ ], &line_pos );
-            //newline = (char *) (newline+line_pos);
-#if defined( DEBUG )
-            printf( "%d ", map_elems[ idx-1] );
-#endif
-        }
-        sscanf( newline, "%d ) %n", &map_elems[ idx++ ], &line_pos ); 
-        //newline = (char *) (newline+line_pos);
-#if defined( DEBUG )
-        printf( "%d\n", map_elems[ idx-1 ] );
-#endif*/
-    
-
-    /* Set Methods 
-    info_A = NULL;
-    info_B = NULL;
-    if (    ( info_A = strstr( newline, "{ " ) ) != NULL
-         && ( info_B = strstr( info_A, " }" ) ) != NULL ) {
-        info_A = (char *) (info_A + 2);
-        sprintf( info_B, "%c", '\0' );
-        strncpy( str4methods, info_A, MAX_LABEL_LEN );
-#if defined( DEBUG )
-        printf( "{%s}", str4methods );
-#endif
-        newline = (char *) (info_B + 2);
-        // Assume only 1 method ID 
-        methods_len = 1;
-    }
-    else*/
+ 
         methods_len = 0;
 #if defined( DEBUG )
     printf( "\n" );
