@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1999  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -15,6 +15,7 @@
 
 #include "BPatch.h"
 #include "BPatch_Vector.h"
+#include "BPatch_function.h"
 #include "BPatch_thread.h"
 #include "BPatch_snippet.h" 
 
@@ -189,7 +190,9 @@ void checkCost(BPatch_snippet snippet){
 }//checkCost()
 
 int errorPrint = 0; // external "dyninst" tracing
-void errorFunc1(BPatchErrorLevel level, int num, const char **params){
+/* OLD void errorFunc1(BPatchErrorLevel level, int num, const char **params) */
+void errorFunc1(BPatchErrorLevel level, int num,  const char* const* params)
+{
     if (num == 0) {
       // conditional reporting of warnings and informational messages
       if (errorPrint) {
@@ -216,7 +219,9 @@ void errorFunc1(BPatchErrorLevel level, int num, const char **params){
 }//errorFunc1()
 
 // We've a null error function when we don't want to display an error
-void errorFuncNull(BPatchErrorLevel level, int num, const char **params){
+/* OLD void errorFuncNull(BPatchErrorLevel level, int num, const char **params) */
+void errorFuncNull(BPatchErrorLevel level, int num,  const char* const* params)
+{
   // It does nothing.
 }//errorFuncNull()
  
@@ -269,7 +274,8 @@ int routineConstraint(char *fname){ // fname is the function name
             (strncmp(fname, "RtsLayer", 8) == 0) ||
             (strncmp(fname, "DYNINST", 7) == 0) ||
             (strncmp(fname, "PthreadLayer", 12) == 0) ||
-            (strncmp(fname, "threaded_func", 13) == 0) ||
+	    (strncmp(fname, "threaded_func", 13) == 0) ||
+            (strncmp(fname, "targ8", 5) == 0) ||
             (strncmp(fname, "The", 3) == 0)){
     return true; // Don't instrument 
   }//if
@@ -417,7 +423,7 @@ int main(int argc, char **argv){
 #ifdef __SP1__
   if (loadlib==true) {
 #else /* SP1 */
-  if ((loadlib == true) && (binaryRewrite == 0)) {
+  if (loadlib == true) {
 #endif /* SP1 */
     //try and load the library
     if (appThread->loadLibrary(libname, true) == true){  
