@@ -121,13 +121,17 @@ int processInstrumentationRequests(char *fname)
 	if (strcmp(inbuf, END_INSTRUMENT_SECTION) == 0)
 	  break; /* Found the end of file exclude list. */  
         if ((inbuf[0] == '#') || (inbuf[0] == '\0')) continue;
+#ifndef TAU_DYNINST
         parseInstrumentationCommand(inbuf, lineno);    
+#endif /* TAU_DYNINST */
       }
     }
     /* next token */
   }
   input.close();
+#ifndef TAU_DYNINST
   printInstrumentList();
+#endif /* TAU_DYNINST */
   return 0;
 }
 
@@ -218,14 +222,13 @@ bool matchName(const string& str1, const string& str2)
 /* -------------------------------------------------------------------------- */
 bool instrumentEntity(const string& function_name)
 {
-
+  list<string>::iterator it;
 #ifdef DEBUG
   cout <<"instrument "<<function_name<<" ?"<<endl;
 #endif /* DEBUG */
   if (!excludelist.empty())
   { /* if exclude list has entries */
-    for (list<string>::iterator it = excludelist.begin();
-        it != excludelist.end(); it++)
+    for (it = excludelist.begin(); it != excludelist.end(); it++)
     { /* iterate through the entries and see if the names match */
       if (matchName(*it, function_name)) 
       {
@@ -253,8 +256,7 @@ bool instrumentEntity(const string& function_name)
     /* wait! The include list is not empty. We must see if the given name
        appears in the list of routines that should be instrumented 
        For this, we need to iterate through the include list.  */
-    for (list<string>::iterator it = includelist.begin();
-        it != includelist.end(); it++)
+    for (it = includelist.begin(); it != includelist.end(); it++)
     { /* iterate through the entries and see if the names match */
       if (matchName(*it, function_name)) 
       {
@@ -286,6 +288,13 @@ bool wildcardCompare(char *wild, char *string, char kleenestar)
 {
   char *cp, *mp;
 
+  // if the wildcard does not contain path information, strip it from the other string
+  if (!strchr(wild,TAU_DIR_CHARACTER)) {
+    while (strchr(string,TAU_DIR_CHARACTER)) { // remove path
+      string = strchr(string,TAU_DIR_CHARACTER)+1;
+    }
+  }
+
   /* check if it is not a ? */
   while ((*string) && (*wild != kleenestar)) {
     if ((*wild != *string) && (*wild != '?')) {
@@ -331,11 +340,11 @@ bool wildcardCompare(char *wild, char *string, char kleenestar)
 /* -------------------------------------------------------------------------- */
 bool processFileForInstrumentation(const string& file_name)
 {
+  list<string>::iterator it;
 
   if (!fileexcludelist.empty())
   { /* if exclude list has entries */
-    for (list<string>::iterator it = fileexcludelist.begin();
-        it != fileexcludelist.end(); it++)
+    for (it = fileexcludelist.begin(); it != fileexcludelist.end(); it++)
     { /* iterate through the entries and see if the names match. Use '*' as 
        the kleene star operator */
       if (wildcardCompare((char *)((*it).c_str()), (char *) (file_name.c_str()), '*'))
@@ -364,8 +373,7 @@ bool processFileForInstrumentation(const string& file_name)
     /* wait! The file include list is not empty. We must see if the given name
        appears in the list of routines that should be instrumented 
        For this, we need to iterate through the include list.  */
-    for (list<string>::iterator it = fileincludelist.begin();
-        it != fileincludelist.end(); it++)
+    for (it = fileincludelist.begin(); it != fileincludelist.end(); it++)
     { /* iterate through the entries and see if the names match */
       if (wildcardCompare((char *)((*it).c_str()), (char *)(file_name.c_str()), '*')) 
       {
@@ -393,6 +401,6 @@ bool processFileForInstrumentation(const string& file_name)
 
 /***************************************************************************
  * $RCSfile: tau_selective.cpp,v $   $Author: amorris $
- * $Revision: 1.10 $   $Date: 2005/11/11 03:46:51 $
- * VERSION_ID: $Id: tau_selective.cpp,v 1.10 2005/11/11 03:46:51 amorris Exp $
+ * $Revision: 1.13 $   $Date: 2006/11/09 00:13:15 $
+ * VERSION_ID: $Id: tau_selective.cpp,v 1.13 2006/11/09 00:13:15 amorris Exp $
  ***************************************************************************/
